@@ -31,8 +31,9 @@ public class FieldCoveragePercentage extends AbstractPercentageDrawerField imple
     @Override
     public String getValue(Object obj) {
         float f = getPercentage(obj);
-        if (f < 0)
+        if (f < 0) {
             f = 0.0f;
+        }
         return nf.format(f);
     }
 
@@ -94,8 +95,9 @@ public class FieldCoveragePercentage extends AbstractPercentageDrawerField imple
         if (e.getClass() == CovRootTreeElement.class)
             return 0;
         else {
-            if (f < 0)
+            if (f < 0) {
                 f = 0.0f;
+            }
             return f;
         }
     }
