@@ -14,11 +14,18 @@ import org.eclipse.osgi.util.NLS;
 
 public class GcovLaunchMessages extends NLS {
 
-	public static String GcovCompilerOptions_msg;
-	public static String GcovCompileAgain_msg;;
+    public static String GcovCompilerOptions_msg;
+    public static String GcovCompileAgain_msg;
 
-	static {
-		NLS.initializeMessages(GcovLaunchMessages.class.getName(), GcovLaunchMessages.class);
-	}
+    public static String
+    GcovMissingFlag_Title,
+    GcovMissingFlag_MainMsg,
+    GcovMissingFlag_CDTInfo,
+    GcovMissingFlag_AutotoolsInfo,
+    GcovMissingFlag_PostQuestion;
+
+    static {
+        NLS.initializeMessages(GcovLaunchMessages.class.getName(), GcovLaunchMessages.class);
+    }
 
 }
