@@ -30,44 +30,41 @@ import org.eclipse.swt.widgets.TreeColumn;
  */
 public class SwitchSampleTimeAction extends Action {
 
-	private final AbstractSTDataView view;
-	
-	/**
-	 * Constructor
-	 * @param name name of the action
-	 * @param view the Gmon viewer
-	 */
-	public SwitchSampleTimeAction(AbstractSTDataView view) {
-		super(Messages.SwitchSampleTimeAction_SWITCH_SAMPLE_TIME, SWT.TOGGLE);
-		this.setImageDescriptor(Activator.getImageDescriptor("icons/datetime_obj.gif")); //$NON-NLS-1$
-		this.setToolTipText(Messages.SwitchSampleTimeAction_SWITCH_SAMPLE_TIME);
-		this.view = view;
-	}
+    private final AbstractSTDataView view;
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jface.action.Action#run()
-	 */
-	@Override
-	public void run() {
-		AbstractSTTreeViewer gmonViewer = (AbstractSTTreeViewer)view.getSTViewer();
-		GmonDecoder decoder = (GmonDecoder) gmonViewer.getInput();
-		if(decoder != null){
-			int prof_rate = decoder.getHistogramDecoder().getProf_rate();
+    /**
+     * Constructor
+     * @param name name of the action
+     * @param view the Gmon viewer
+     */
+    public SwitchSampleTimeAction(AbstractSTDataView view) {
+        super(Messages.SwitchSampleTimeAction_SWITCH_SAMPLE_TIME, SWT.TOGGLE);
+        this.setImageDescriptor(Activator.getImageDescriptor("icons/datetime_obj.gif")); //$NON-NLS-1$
+        this.setToolTipText(Messages.SwitchSampleTimeAction_SWITCH_SAMPLE_TIME);
+        this.view = view;
+    }
+
+    @Override
+    public void run() {
+        AbstractSTTreeViewer gmonViewer = (AbstractSTTreeViewer)view.getSTViewer();
+        GmonDecoder decoder = (GmonDecoder) gmonViewer.getInput();
+        if(decoder != null){
+            int prof_rate = decoder.getHistogramDecoder().getProfRate();
+
+            if (prof_rate == 0) {
+                MessageDialog.openError(view.getSite().getShell(),
+                        Messages.SwitchSampleTimeAction_GMON_PROF_RATE_IS_NULL,
+                Messages.SwitchSampleTimeAction_GMON_PROF_RATE_IS_NULL_LONG_MSG);
+                return;
+            }
+
+            TreeColumn tc = gmonViewer.getViewer().getTree().getColumn(1);
+            SampleProfField spf = (SampleProfField) tc.getData();
+            spf.toggle();
+            tc.setText(spf.getColumnHeaderText());
+            gmonViewer.getViewer().refresh();
+        }
+    }
 
-			if (prof_rate == 0) {
-				MessageDialog.openError(view.getSite().getShell(),
-						Messages.SwitchSampleTimeAction_GMON_PROF_RATE_IS_NULL,
-				Messages.SwitchSampleTimeAction_GMON_PROF_RATE_IS_NULL_LONG_MSG);
-				return;
-			}
 
-			TreeColumn tc = gmonViewer.getViewer().getTree().getColumn(1);
-			SampleProfField spf = (SampleProfField) tc.getData();
-			spf.toggle();
-			tc.setText(spf.getColumnHeaderText());
-			gmonViewer.getViewer().refresh();
-		}
-	}
-	
-	
 }
