@@ -24,12 +24,13 @@ import org.junit.runners.Suite;
  */
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
-    CtfCorePluginTest.class,
-    org.eclipse.linuxtools.ctf.core.tests.event.TestAll.class,
-    org.eclipse.linuxtools.ctf.core.tests.io.TestAll.class,
-    org.eclipse.linuxtools.ctf.core.tests.trace.TestAll.class,
-    org.eclipse.linuxtools.ctf.core.tests.types.TestAll.class
+        CtfCorePluginTest.class,
+        org.eclipse.linuxtools.ctf.core.tests.ctftestsuite.TestAll.class,
+        org.eclipse.linuxtools.ctf.core.tests.event.TestAll.class,
+        org.eclipse.linuxtools.ctf.core.tests.io.TestAll.class,
+        org.eclipse.linuxtools.ctf.core.tests.scope.TestAll.class,
+        org.eclipse.linuxtools.ctf.core.tests.trace.TestAll.class,
+        org.eclipse.linuxtools.ctf.core.tests.types.TestAll.class
 })
 public class AllCtfCoreTests {
-
 }
