@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013 Ericsson
+ * Copyright (c) 2013-2014 Ericsson
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -19,7 +19,7 @@ import org.junit.runners.Suite;
  * the tests within its package as well as within any subpackages of its
  * package.
  *
- * @author ematkho
+ * @author Matthew Khouzam
  * @version $Revision: 1.0 $
  */
 @RunWith(Suite.class)
@@ -27,15 +27,15 @@ import org.junit.runners.Suite;
     CTFTraceCallsitePerformanceTest.class,
     CTFTraceReaderTest.class,
     CTFTraceTest.class,
+    CTFTraceGrowingTest.class,
     IOstructgenTest.class,
     MetadataTest.class,
-    StreamInputPacketIndexEntryTest.class,
-    StreamInputPacketIndexTest.class,
-    StreamInputReaderComparatorTest.class,
-    StreamInputReaderTest.class,
-    StreamInputReaderTimestampComparatorTest.class,
-    StreamInputTest.class,
-    StreamTest.class,
+    CTFStreamInputPacketIndexEntryTest.class,
+    CTFStreamInputPacketIndexTest.class,
+    CTFStreamInputReaderTest.class,
+    CTFStreamInputReaderTimestampComparatorTest.class,
+    CTFStreamInputTest.class,
+    CTFStreamTest.class,
     UtilsTest.class
 })
 public class TestAll {
