@@ -1,3 +1,14 @@
+/*******************************************************************************
+ * Copyright (c) 2013 Ericsson
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ *     Matthew Khouzam - Initial API and implementation
+ *******************************************************************************/
+
 package org.eclipse.linuxtools.ctf.core.tests.types;
 
 import static org.junit.Assert.assertEquals;
@@ -24,8 +35,8 @@ public class FloatDeclarationTest {
 
     @Test
     public void getterTest() {
-        fixture = new FloatDeclaration(8, 24, ByteOrder.nativeOrder(), 0);
-        assertEquals( fixture.getAlignment(), 0);
+        fixture = new FloatDeclaration(8, 24, ByteOrder.nativeOrder(), 1);
+        assertEquals( fixture.getAlignment(), 1);
         assertEquals( fixture.getByteOrder(), ByteOrder.nativeOrder());
         assertEquals( fixture.getExponent(), 8);
         assertEquals( fixture.getMantissa(), 24);
@@ -34,6 +45,6 @@ public class FloatDeclarationTest {
     @Test
     public void toStringTest() {
         fixture = new FloatDeclaration(8, 24, ByteOrder.nativeOrder(), 0);
-        assertTrue(fixture.toString().contains("float")); //$NON-NLS-1$
+        assertTrue(fixture.toString().contains("float"));
     }
 }
