@@ -1,26 +1,32 @@
 /*******************************************************************************.
- * Copyright (c) 2011-2012 Ericsson, Ecole Polytechnique de Montreal and others
+ * Copyright (c) 2011, 2014 Ericsson, Ecole Polytechnique de Montreal and others
  *
  * All rights reserved. This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License v1.0 which
  * accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: Matthew Khouzam - Initial Design and implementation
- * Contributors: Francis Giraldeau - Initial API and implementation
- * Contributors: Philippe Proulx - Some refinement and optimization
+ * Contributors:
+ *  Matthew Khouzam - Initial Design and implementation + overhaul
+ *  Francis Giraldeau - Initial API and implementation
+ *  Philippe Proulx - Some refinement and optimization
+ *  Etienne Bergeron <Etienne.Bergeron@gmail.com> - fix zero size read + cleanup
  *******************************************************************************/
 
 package org.eclipse.linuxtools.ctf.core.event.io;
 
-import java.nio.BufferOverflowException;
+import java.nio.BufferUnderflowException;
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
 
+import org.eclipse.jdt.annotation.NonNull;
+import org.eclipse.linuxtools.ctf.core.trace.CTFReaderException;
+
 /**
  * <b><u>BitBuffer</u></b>
  * <p>
  * A bitwise buffer capable of accessing fields with bit offsets.
+ *
  * @since 2.0
  */
 public final class BitBuffer {
@@ -45,42 +51,53 @@ public final class BitBuffer {
     // Attributes
     // ------------------------------------------------------------------------
 
-    private ByteBuffer buf;
-    private int pos;
-    private ByteOrder byteOrder;
+    private final @NonNull ByteBuffer fBuffer;
+    private final long fBitCapacity;
+
+    /**
+     * Bit-buffer's position, maximum value = Integer.MAX_VALUE * 8
+     */
+    private long fPosition;
+    private ByteOrder fByteOrder;
 
     // ------------------------------------------------------------------------
     // Constructors
     // ------------------------------------------------------------------------
     /**
-     * Default constructor, makes a bigendian buffer
+     * Default constructor, makes a big-endian buffer
      */
+    @SuppressWarnings("null")
     public BitBuffer() {
-        this(null, ByteOrder.BIG_ENDIAN);
+        this(ByteBuffer.allocateDirect(0), ByteOrder.BIG_ENDIAN);
     }
 
     /**
-     * Constructor, makes a bigendian buffer
+     * Constructor, makes a big-endian buffer
      *
      * @param buf
      *            the bytebuffer to read
      */
-    public BitBuffer(ByteBuffer buf) {
+    public BitBuffer(@NonNull ByteBuffer buf) {
         this(buf, ByteOrder.BIG_ENDIAN);
     }
 
     /**
-     * Constructor that is fully parametrisable
+     * Constructor that is fully parameterizable
      *
      * @param buf
      *            the buffer to read
      * @param order
-     *            the byte order (big endian, little endian, network?)
+     *            the byte order (big-endian, little-endian, network?)
      */
-    public BitBuffer(ByteBuffer buf, ByteOrder order) {
-        setByteBuffer(buf);
+    public BitBuffer(@NonNull ByteBuffer buf, ByteOrder order) {
+        fBuffer = buf;
         setByteOrder(order);
-        position(0);
+        resetPosition();
+        fBitCapacity = fBuffer.capacity() * BIT_CHAR;
+    }
+
+    private void resetPosition() {
+        fPosition = 0;
     }
 
     // ------------------------------------------------------------------------
@@ -93,12 +110,96 @@ public final class BitBuffer {
      * Reads next four bytes from the current bit position according to current
      * byte order.
      *
-     * @return The int value read from the buffer
+     * @return The int value (signed) read from the buffer
+     * @throws CTFReaderException
+     *             An error occurred reading the long. This exception can be
+     *             raised if the buffer tries to read out of bounds
      */
-    public int getInt() {
+    public int getInt() throws CTFReaderException {
         return getInt(BIT_INT, true);
     }
 
+    /**
+     * Relative <i>get</i> method for reading 64-bit integer.
+     *
+     * Reads next eight bytes from the current bit position according to current
+     * byte order.
+     *
+     * @return The long value (signed) read from the buffer
+     * @throws CTFReaderException
+     *             An error occurred reading the long. This exception can be
+     *             raised if the buffer tries to read out of bounds
+     * @since 3.0
+     */
+    public long getLong() throws CTFReaderException {
+        return get(BIT_LONG, true);
+    }
+
+    /**
+     * Relative <i>get</i> method for reading long of <i>length</i> bits.
+     *
+     * Reads <i>length</i> bits starting at the current position. The result is
+     * signed extended if <i>signed</i> is true. The current position is
+     * increased of <i>length</i> bits.
+     *
+     * @param length
+     *            The length in bits of this integer
+     * @param signed
+     *            The sign extended flag
+     * @return The long value read from the buffer
+     * @throws CTFReaderException
+     *             An error occurred reading the data. If more than 64 bits at a
+     *             time are read, or the buffer is read beyond its end, this
+     *             exception will be raised.
+     * @since 3.0
+     */
+    public long get(int length, boolean signed) throws CTFReaderException {
+        if (length > BIT_LONG) {
+            throw new CTFReaderException("Cannot read a long longer than 64 bits. Rquested: " + length); //$NON-NLS-1$
+        }
+        if (length > BIT_INT) {
+            final int highShift = length - BIT_INT;
+            long a = getInt();
+            long b = getInt(highShift, false);
+            long retVal;
+            /* Cast the signed-extended int into a unsigned int. */
+            a &= 0xFFFFFFFFL;
+            b &= (1L << highShift) - 1L;
+
+            retVal = (fByteOrder == ByteOrder.BIG_ENDIAN) ? ((a << highShift) | b) : ((b << BIT_INT) | a);
+            /* sign extend */
+            if (signed) {
+                int signExtendBits = BIT_LONG - length;
+                retVal = (retVal << signExtendBits) >> signExtendBits;
+            }
+            return retVal;
+        }
+        long retVal = getInt(length, signed);
+        return (signed ? retVal : (retVal & 0xFFFFFFFFL));
+    }
+
+    /**
+     * Relative bulk <i>get</i> method.
+     *
+     * <p>
+     * This method transfers <strong>bytes</strong> from this buffer into the
+     * given destination array. This method currently only supports reads
+     * aligned to 8 bytes. It is up to the developer to shift the bits in
+     * post-processing to do unaligned reads.
+     *
+     * @param dst
+     *            the bytes to write to
+     * @throws BufferUnderflowException
+     *             - If there are fewer than length bytes remaining in this
+     *             buffer
+     * @since 3.1
+     */
+    public void get(@NonNull byte[] dst) {
+        fBuffer.position((int) (fPosition / 8));
+        fBuffer.get(dst);
+        fPosition += dst.length * 8;
+    }
+
     /**
      * Relative <i>get</i> method for reading integer of <i>length</i> bits.
      *
@@ -111,44 +212,59 @@ public final class BitBuffer {
      * @param signed
      *            The sign extended flag
      * @return The int value read from the buffer
+     * @throws CTFReaderException
+     *             An error occurred reading the data. When the buffer is read
+     *             beyond its end, this exception will be raised.
      */
-    public int getInt(int length, boolean signed) {
-        int val = 0;
-        if (!canRead(length)) {
-            throw new BufferOverflowException();
-        }
+    private int getInt(int length, boolean signed) throws CTFReaderException {
+
+        /* Nothing to read. */
         if (length == 0) {
             return 0;
         }
+
+        /* Validate that the buffer has enough bits. */
+        if (!canRead(length)) {
+            throw new CTFReaderException("Cannot read the integer, " + //$NON-NLS-1$
+                    "the buffer does not have enough remaining space. " + //$NON-NLS-1$
+                    "Requested:" + length); //$NON-NLS-1$
+        }
+
+        /* Get the value from the byte buffer. */
+        int val = 0;
         boolean gotIt = false;
 
-        // Fall back to fast ByteBuffer reader if we want to read byte-aligned bytes
-        if (this.pos % BitBuffer.BIT_CHAR == 0) {
+        /*
+         * Try a fast read when the position is byte-aligned by using
+         * java.nio.ByteBuffer's native methods
+         */
+        /*
+         * A faster alignment detection as the compiler cannot guaranty that pos
+         * is always positive.
+         */
+        if ((fPosition & (BitBuffer.BIT_CHAR - 1)) == 0) {
             switch (length) {
             case BitBuffer.BIT_CHAR:
                 // Byte
-                if (signed) {
-                    val = this.buf.get(this.pos / 8);
-                } else {
-                    val = (this.buf.get(this.pos / 8)) & 0xff;
+                val = fBuffer.get((int) (fPosition / 8));
+                if (!signed) {
+                    val = val & 0xff;
                 }
                 gotIt = true;
                 break;
 
             case BitBuffer.BIT_SHORT:
                 // Word
-                if (signed) {
-                    val = this.buf.getShort(this.pos / 8);
-                } else {
-                    short a = this.buf.getShort(this.pos / 8);
-                    val = a & 0xffff;
+                val = fBuffer.getShort((int) (fPosition / 8));
+                if (!signed) {
+                    val = val & 0xffff;
                 }
                 gotIt = true;
                 break;
 
             case BitBuffer.BIT_INT:
                 // Double word
-                val = this.buf.getInt(this.pos / 8);
+                val = fBuffer.getInt((int) (fPosition / 8));
                 gotIt = true;
                 break;
 
@@ -156,29 +272,33 @@ public final class BitBuffer {
                 break;
             }
         }
+
+        /* When not byte-aligned, fall-back to a general decoder. */
         if (!gotIt) {
             // Nothing read yet: use longer methods
-            if (this.byteOrder == ByteOrder.LITTLE_ENDIAN) {
-                val = getIntLE(this.pos, length, signed);
+            if (fByteOrder == ByteOrder.LITTLE_ENDIAN) {
+                val = getIntLE(fPosition, length, signed);
             } else {
-                val = getIntBE(this.pos, length, signed);
+                val = getIntBE(fPosition, length, signed);
             }
         }
-        this.pos += length;
+        fPosition += length;
 
         return val;
     }
 
-    private int getIntBE(int index, int length, boolean signed) {
-        assert ((length > 0) && (length <= BIT_INT));
-        int end = index + length;
-        int startByte = index / BIT_CHAR;
-        int endByte = (end + (BIT_CHAR - 1)) / BIT_CHAR;
+    private int getIntBE(long index, int length, boolean signed) {
+        if ((length <= 0) || (length > BIT_INT)) {
+            throw new IllegalArgumentException("Length must be between 1-32 bits"); //$NON-NLS-1$
+        }
+        long end = index + length;
+        int startByte = (int) (index / BIT_CHAR);
+        int endByte = (int) ((end + (BIT_CHAR - 1)) / BIT_CHAR);
         int currByte, lshift, cshift, mask, cmask, cache;
         int value = 0;
 
         currByte = startByte;
-        cache = this.buf.get(currByte) & 0xFF;
+        cache = fBuffer.get(currByte) & 0xFF;
         boolean isNeg = (cache & (1 << (BIT_CHAR - (index % BIT_CHAR) - 1))) != 0;
         if (signed && isNeg) {
             value = ~0;
@@ -193,7 +313,7 @@ public final class BitBuffer {
             value |= cmask;
             return value;
         }
-        cshift = index % BIT_CHAR;
+        cshift = (int) (index % BIT_CHAR);
         if (cshift > 0) {
             mask = ~((~0) << (BIT_CHAR - cshift));
             cmask = cache & mask;
@@ -204,34 +324,36 @@ public final class BitBuffer {
         }
         for (; currByte < (endByte - 1); currByte++) {
             value <<= BIT_CHAR;
-            value |= this.buf.get(currByte) & 0xFF;
+            value |= fBuffer.get(currByte) & 0xFF;
         }
-        lshift = end % BIT_CHAR;
+        lshift = (int) (end % BIT_CHAR);
         if (lshift > 0) {
             mask = ~((~0) << lshift);
-            cmask = this.buf.get(currByte) & 0xFF;
+            cmask = fBuffer.get(currByte) & 0xFF;
             cmask >>>= BIT_CHAR - lshift;
             cmask &= mask;
             value <<= lshift;
             value |= cmask;
         } else {
             value <<= BIT_CHAR;
-            value |= this.buf.get(currByte) & 0xFF;
+            value |= fBuffer.get(currByte) & 0xFF;
         }
         return value;
     }
 
-    private int getIntLE(int index, int length, boolean signed) {
-        assert ((length > 0) && (length <= BIT_INT));
-        int end = index + length;
-        int startByte = index / BIT_CHAR;
-        int endByte = (end + (BIT_CHAR - 1)) / BIT_CHAR;
+    private int getIntLE(long index, int length, boolean signed) {
+        if ((length <= 0) || (length > BIT_INT)) {
+            throw new IllegalArgumentException("Length must be between 1-32 bits"); //$NON-NLS-1$
+        }
+        long end = index + length;
+        int startByte = (int) (index / BIT_CHAR);
+        int endByte = (int) ((end + (BIT_CHAR - 1)) / BIT_CHAR);
         int currByte, lshift, cshift, mask, cmask, cache, mod;
         int value = 0;
 
         currByte = endByte - 1;
-        cache = buf.get(currByte) & 0xFF;
-        mod = end % BIT_CHAR;
+        cache = fBuffer.get(currByte) & 0xFF;
+        mod = (int) (end % BIT_CHAR);
         lshift = (mod > 0) ? mod : BIT_CHAR;
         boolean isNeg = (cache & (1 << (lshift - 1))) != 0;
         if (signed && isNeg) {
@@ -247,7 +369,7 @@ public final class BitBuffer {
             value |= cmask;
             return value;
         }
-        cshift = end % BIT_CHAR;
+        cshift = (int) (end % BIT_CHAR);
         if (cshift > 0) {
             mask = ~((~0) << cshift);
             cmask = cache & mask;
@@ -257,19 +379,19 @@ public final class BitBuffer {
         }
         for (; currByte >= (startByte + 1); currByte--) {
             value <<= BIT_CHAR;
-            value |= buf.get(currByte) & 0xFF;
+            value |= fBuffer.get(currByte) & 0xFF;
         }
-        lshift = index % BIT_CHAR;
+        lshift = (int) (index % BIT_CHAR);
         if (lshift > 0) {
             mask = ~((~0) << (BIT_CHAR - lshift));
-            cmask = buf.get(currByte) & 0xFF;
+            cmask = fBuffer.get(currByte) & 0xFF;
             cmask >>>= lshift;
             cmask &= mask;
             value <<= (BIT_CHAR - lshift);
             value |= cmask;
         } else {
             value <<= BIT_CHAR;
-            value |= buf.get(currByte) & 0xFF;
+            value |= fBuffer.get(currByte) & 0xFF;
         }
         return value;
     }
@@ -287,8 +409,11 @@ public final class BitBuffer {
      *
      * @param value
      *            The int value to write
+     * @throws CTFReaderException
+     *             An error occurred writing the data. If the buffer is written
+     *             beyond its end, this exception will be raised.
      */
-    public void putInt(int value) {
+    public void putInt(int value) throws CTFReaderException {
         putInt(BIT_INT, value);
     }
 
@@ -305,29 +430,35 @@ public final class BitBuffer {
      *            The number of bits to write
      * @param value
      *            The value to write
+     * @throws CTFReaderException
+     *             An error occurred writing the data. If the buffer is written
+     *             beyond its end, this exception will be raised.
      */
-    public void putInt(int length, int value) {
-        final int curPos = this.pos;
+    public void putInt(int length, int value) throws CTFReaderException {
+        final long curPos = fPosition;
 
         if (!canRead(length)) {
-            throw new BufferOverflowException();
+            throw new CTFReaderException("Cannot write to bitbuffer, " //$NON-NLS-1$
+                    + "insufficient space. Requested: " + length); //$NON-NLS-1$
         }
         if (length == 0) {
             return;
         }
-        if (this.byteOrder == ByteOrder.LITTLE_ENDIAN) {
+        if (fByteOrder == ByteOrder.LITTLE_ENDIAN) {
             putIntLE(curPos, length, value);
         } else {
             putIntBE(curPos, length, value);
         }
-        this.pos += length;
+        fPosition += length;
     }
 
-    private void putIntBE(int index, int length, int value) {
-        assert ((length > 0) && (length <= BIT_INT));
-        int end = index + length;
-        int startByte = index / BIT_CHAR;
-        int endByte = (end + (BIT_CHAR - 1)) / BIT_CHAR;
+    private void putIntBE(long index, int length, int value) {
+        if ((length <= 0) || (length > BIT_INT)) {
+            throw new IllegalArgumentException("Length must be between 1-32 bits"); //$NON-NLS-1$
+        }
+        long end = index + length;
+        int startByte = (int) (index / BIT_CHAR);
+        int endByte = (int) ((end + (BIT_CHAR - 1)) / BIT_CHAR);
         int currByte, lshift, cshift, mask, cmask;
         int correctedValue = value;
 
@@ -342,57 +473,59 @@ public final class BitBuffer {
 
         /* sub byte */
         if (startByte == (endByte - 1)) {
-            lshift = (BIT_CHAR - (end % BIT_CHAR)) % BIT_CHAR;
+            lshift = (int) ((BIT_CHAR - (end % BIT_CHAR)) % BIT_CHAR);
             mask = ~((~0) << lshift);
             if ((index % BIT_CHAR) > 0) {
                 mask |= (~(0)) << (BIT_CHAR - (index % BIT_CHAR));
             }
             cmask = correctedValue << lshift;
             /*
-             * low bits are cleared because of lshift and high bits are already
-             * cleared
+             * low bits are cleared because of left-shift and high bits are
+             * already cleared
              */
             cmask &= ~mask;
-            int b = this.buf.get(startByte) & 0xFF;
-            this.buf.put(startByte, (byte) ((b & mask) | cmask));
+            int b = fBuffer.get(startByte) & 0xFF;
+            fBuffer.put(startByte, (byte) ((b & mask) | cmask));
             return;
         }
 
         /* head byte contains MSB */
         currByte = endByte - 1;
-        cshift = end % BIT_CHAR;
+        cshift = (int) (end % BIT_CHAR);
         if (cshift > 0) {
             lshift = BIT_CHAR - cshift;
             mask = ~((~0) << lshift);
             cmask = correctedValue << lshift;
             cmask &= ~mask;
-            int b = this.buf.get(currByte) & 0xFF;
-            this.buf.put(currByte, (byte) ((b & mask) | cmask));
+            int b = fBuffer.get(currByte) & 0xFF;
+            fBuffer.put(currByte, (byte) ((b & mask) | cmask));
             correctedValue >>>= cshift;
             currByte--;
         }
 
         /* middle byte(s) */
         for (; currByte >= (startByte + 1); currByte--) {
-            this.buf.put(currByte, (byte) correctedValue);
+            fBuffer.put(currByte, (byte) correctedValue);
             correctedValue >>>= BIT_CHAR;
         }
         /* end byte contains LSB */
         if ((index % BIT_CHAR) > 0) {
             mask = (~0) << (BIT_CHAR - (index % BIT_CHAR));
             cmask = correctedValue & ~mask;
-            int b = this.buf.get(currByte) & 0xFF;
-            this.buf.put(currByte, (byte) ((b & mask) | cmask));
+            int b = fBuffer.get(currByte) & 0xFF;
+            fBuffer.put(currByte, (byte) ((b & mask) | cmask));
         } else {
-            this.buf.put(currByte, (byte) correctedValue);
+            fBuffer.put(currByte, (byte) correctedValue);
         }
     }
 
-    private void putIntLE(int index, int length, int value) {
-        assert ((length > 0) && (length <= BIT_INT));
-        int end = index + length;
-        int startByte = index / BIT_CHAR;
-        int endByte = (end + (BIT_CHAR - 1)) / BIT_CHAR;
+    private void putIntLE(long index, int length, int value) {
+        if ((length <= 0) || (length > BIT_INT)) {
+            throw new IllegalArgumentException("Length must be between 1-32 bits"); //$NON-NLS-1$
+        }
+        long end = index + length;
+        int startByte = (int) (index / BIT_CHAR);
+        int endByte = (int) ((end + (BIT_CHAR - 1)) / BIT_CHAR);
         int currByte, lshift, cshift, mask, cmask;
         int correctedValue = value;
 
@@ -407,48 +540,48 @@ public final class BitBuffer {
 
         /* sub byte */
         if (startByte == (endByte - 1)) {
-            lshift = index % BIT_CHAR;
+            lshift = (int) (index % BIT_CHAR);
             mask = ~((~0) << lshift);
             if ((end % BIT_CHAR) > 0) {
                 mask |= (~(0)) << (end % BIT_CHAR);
             }
             cmask = correctedValue << lshift;
             /*
-             * low bits are cleared because of lshift and high bits are already
-             * cleared
+             * low bits are cleared because of left-shift and high bits are
+             * already cleared
              */
             cmask &= ~mask;
-            int b = this.buf.get(startByte) & 0xFF;
-            this.buf.put(startByte, (byte) ((b & mask) | cmask));
+            int b = fBuffer.get(startByte) & 0xFF;
+            fBuffer.put(startByte, (byte) ((b & mask) | cmask));
             return;
         }
 
         /* head byte */
         currByte = startByte;
-        cshift = index % BIT_CHAR;
+        cshift = (int) (index % BIT_CHAR);
         if (cshift > 0) {
             mask = ~((~0) << cshift);
             cmask = correctedValue << cshift;
             cmask &= ~mask;
-            int b = this.buf.get(currByte) & 0xFF;
-            this.buf.put(currByte, (byte) ((b & mask) | cmask));
+            int b = fBuffer.get(currByte) & 0xFF;
+            fBuffer.put(currByte, (byte) ((b & mask) | cmask));
             correctedValue >>>= BIT_CHAR - cshift;
             currByte++;
         }
 
         /* middle byte(s) */
         for (; currByte < (endByte - 1); currByte++) {
-            this.buf.put(currByte, (byte) correctedValue);
+            fBuffer.put(currByte, (byte) correctedValue);
             correctedValue >>>= BIT_CHAR;
         }
         /* end byte */
         if ((end % BIT_CHAR) > 0) {
             mask = (~0) << (end % BIT_CHAR);
             cmask = correctedValue & ~mask;
-            int b = this.buf.get(currByte) & 0xFF;
-            this.buf.put(currByte, (byte) ((b & mask) | cmask));
+            int b = fBuffer.get(currByte) & 0xFF;
+            fBuffer.put(currByte, (byte) ((b & mask) | cmask));
         } else {
-            this.buf.put(currByte, (byte) correctedValue);
+            fBuffer.put(currByte, (byte) correctedValue);
         }
     }
 
@@ -464,14 +597,7 @@ public final class BitBuffer {
      * @return does the buffer have enough room to read the next "length"
      */
     public boolean canRead(int length) {
-        if (this.buf == null) {
-            return false;
-        }
-
-        if ((this.pos + length) > (this.buf.capacity() * BIT_CHAR)) {
-            return false;
-        }
-        return true;
+        return ((fPosition + length) <= fBitCapacity);
     }
 
     /**
@@ -481,10 +607,8 @@ public final class BitBuffer {
      *            The order of the buffer.
      */
     public void setByteOrder(ByteOrder order) {
-        this.byteOrder = order;
-        if (this.buf != null) {
-            this.buf.order(order);
-        }
+        fByteOrder = order;
+        fBuffer.order(order);
     }
 
     /**
@@ -493,7 +617,7 @@ public final class BitBuffer {
      * @return The order of the buffer.
      */
     public ByteOrder getByteOrder() {
-        return this.byteOrder;
+        return fByteOrder;
     }
 
     /**
@@ -501,9 +625,17 @@ public final class BitBuffer {
      *
      * @param newPosition
      *            The new position of the buffer.
+     * @throws CTFReaderException
+     *             Thrown on out of bounds exceptions
+     * @since 3.0
      */
-    public void position(int newPosition) {
-        this.pos = newPosition;
+    public void position(long newPosition) throws CTFReaderException {
+
+
+        if (newPosition > fBitCapacity) {
+            throw new CTFReaderException("Out of bounds exception on a position move, attempting to access position: " + newPosition); //$NON-NLS-1$
+        }
+        fPosition = newPosition;
     }
 
     /**
@@ -511,9 +643,10 @@ public final class BitBuffer {
      * Sets the position in the buffer.
      *
      * @return order The position of the buffer.
+     * @since 3.0
      */
-    public int position() {
-        return this.pos;
+    public long position() {
+        return fPosition;
     }
 
     /**
@@ -522,12 +655,16 @@ public final class BitBuffer {
      * @param buf
      *            the byte buffer
      */
+    @Deprecated
     public void setByteBuffer(ByteBuffer buf) {
-        this.buf = buf;
-        if (buf != null) {
-            this.buf.order(this.byteOrder);
-        }
-        clear();
+        /*
+         * to avoid "The method setByteBuffer(ByteBuffer) from the type
+         * BitBuffer can be declared as static"
+         */
+        long data = fPosition;
+        fPosition = data;
+        throw new UnsupportedOperationException("Bytebuffers are now final"); //$NON-NLS-1$
+
     }
 
     /**
@@ -536,19 +673,15 @@ public final class BitBuffer {
      * @return The byte buffer
      */
     public ByteBuffer getByteBuffer() {
-        return this.buf;
+        return fBuffer;
     }
 
     /**
-     * resets the bitbuffer.
+     * Resets the bitbuffer.
      */
     public void clear() {
-        position(0);
-
-        if (this.buf == null) {
-            return;
-        }
-        this.buf.clear();
+        resetPosition();
+        fBuffer.clear();
     }
 
 }
