@@ -12,6 +12,8 @@
 
 package org.eclipse.linuxtools.ctf.core.event.types;
 
+import org.eclipse.jdt.annotation.NonNullByDefault;
+
 /**
  * CTF encoding types
  *
@@ -19,6 +21,7 @@ package org.eclipse.linuxtools.ctf.core.event.types;
  * @author Matthew Khouzam
  * @author Simon Marchi
  */
+@NonNullByDefault
 public enum Encoding {
     /** UTF-8 encoding */
     UTF8,
