@@ -12,29 +12,28 @@
 
 package org.eclipse.linuxtools.ctf.core.event.types;
 
-import org.eclipse.linuxtools.ctf.core.event.io.BitBuffer;
+import org.eclipse.jdt.annotation.NonNull;
+import org.eclipse.linuxtools.ctf.core.event.scope.IDefinitionScope;
 
 /**
  * A CTF enum definition.
  *
- * The definition of a enum point basic data type. It will take the data
- * from a trace and store it (and make it fit) as an integer and a string.
+ * The definition of a enum point basic data type. It will take the data from a
+ * trace and store it (and make it fit) as an integer and a string.
  *
  * @version 1.0
  * @author Matthew Khouzam
  * @author Simon Marchi
  */
-public class EnumDefinition extends SimpleDatatypeDefinition {
+public final class EnumDefinition extends SimpleDatatypeDefinition {
 
     // ------------------------------------------------------------------------
     // Attributes
     // ------------------------------------------------------------------------
 
-    private final EnumDeclaration declaration;
+    private final long fIntegerValue;
 
-    private final IntegerDefinition integerValue;
-
-    private String value;
+    private final String fValue;
 
     // ------------------------------------------------------------------------
     // Constructors
@@ -42,19 +41,23 @@ public class EnumDefinition extends SimpleDatatypeDefinition {
 
     /**
      * Constructor
-     * @param declaration the parent declaration
-     * @param definitionScope the parent scope
-     * @param fieldName the field name
+     *
+     * @param declaration
+     *            the parent declaration
+     * @param definitionScope
+     *            the parent scope
+     * @param fieldName
+     *            the field name
+     * @param intValue
+     *            the value of the enum
+     * @since 3.0
      */
-    public EnumDefinition(EnumDeclaration declaration,
-            IDefinitionScope definitionScope, String fieldName) {
-        super(definitionScope, fieldName);
+    public EnumDefinition(@NonNull EnumDeclaration declaration,
+            IDefinitionScope definitionScope, @NonNull String fieldName, IntegerDefinition intValue) {
+        super(declaration, definitionScope, fieldName);
 
-        this.declaration = declaration;
-
-        integerValue = declaration.getContainerType().createDefinition(
-                definitionScope, fieldName);
-        value = declaration.query(integerValue.getValue());
+        fIntegerValue = intValue.getValue();
+        fValue = declaration.query(fIntegerValue);
     }
 
     // ------------------------------------------------------------------------
@@ -62,60 +65,44 @@ public class EnumDefinition extends SimpleDatatypeDefinition {
     // ------------------------------------------------------------------------
 
     /**
-     * Gets the value of the enum in string format so "Enum a{DAY="0", NIGHT="1"}; will return "DAY"
+     * Gets the value of the enum in string format so
+     * "Enum a{DAY="0", NIGHT="1"}; will return "DAY"
+     *
      * @return the value of the enum.
      */
     public String getValue() {
-        return value;
+        return fValue;
     }
 
     @Override
-    public String getStringValue(){
+    public String getStringValue() {
         return getValue();
     }
 
     /**
-     * Gets the value of the enum in string format so "Enum a{DAY="0", NIGHT="1"}; will return 0
+     * Gets the value of the enum in string format so
+     * "Enum a{DAY="0", NIGHT="1"}; will return 0
+     *
      * @return the value of the enum.
      */
     @Override
     public Long getIntegerValue() {
-        return integerValue.getValue();
-    }
-
-    /**
-     * Sets the value of the enum in string format so "Enum a{DAY="0", NIGHT="1"}; will set 0
-     * @param value The value of the enum.
-     */
-    public void setIntegerValue(long value) {
-        integerValue.setValue(value);
-        this.value = declaration.query(value);
+        return fIntegerValue;
     }
 
     @Override
     public EnumDeclaration getDeclaration() {
-        return declaration;
+        return (EnumDeclaration) super.getDeclaration();
     }
 
     // ------------------------------------------------------------------------
     // Operations
     // ------------------------------------------------------------------------
 
-    @Override
-    public void read(BitBuffer input) {
-        alignRead(input, this.declaration);
-        integerValue.read(input);
-        long val = integerValue.getValue();
-
-        // TODO: what to do if the integer value maps to no string for this
-        // integer ?
-        value = declaration.query(val);
-    }
-
     @Override
     public String toString() {
         return "{ value = " + getValue() + //$NON-NLS-1$
-                ", container = " + integerValue.toString() + //$NON-NLS-1$
+                ", container = " + fIntegerValue + //$NON-NLS-1$
                 " }"; //$NON-NLS-1$
     }
 }
