@@ -30,7 +30,7 @@ public class ParseException extends Exception {
     /**
      * Constructor
      *
-     * @param message (to be sent to logs
+     * @param message to be sent to logs
      */
     public ParseException(String message) {
         super(message);
@@ -43,4 +43,21 @@ public class ParseException extends Exception {
     public ParseException(Exception e) {
         super(e);
     }
+
+    /**
+     * Constructs a new exception with the specified detail message and
+     * cause.  <p>Note that the detail message associated with
+     * {@code cause} is <i>not</i> automatically incorporated in
+     * this exception's detail message.
+     *
+     * @param  message the detail message (which is saved for later retrieval
+     *         by the {@link #getMessage()} method).
+     * @param  cause the cause (which is saved for later retrieval by the
+     *         {@link #getCause()} method).  (A <tt>null</tt> value is
+     *         permitted, and indicates that the cause is nonexistent or
+     *         unknown.)
+     */
+    public ParseException(String message, Exception cause) {
+        super(message, cause);
+    }
 }
