@@ -21,6 +21,8 @@ import org.junit.runners.Suite;
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
     ActivatorTest.class,
-    org.eclipse.linuxtools.lttng2.kernel.core.tests.stateprovider.TestAll.class
+    org.eclipse.linuxtools.lttng2.kernel.core.tests.analysis.AllTests.class,
+    org.eclipse.linuxtools.lttng2.kernel.core.tests.stateprovider.TestAll.class,
+    org.eclipse.linuxtools.lttng2.kernel.core.tests.event.matchandsync.AllTests.class
 })
 public class AllTests { }
