@@ -1,41 +1,30 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson
- * 
+ * Copyright (c) 2012, 2013 Ericsson
+ *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
  * accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
- * 
+ *
  * Contributors:
  *   Alexandre Montplaisir - Initial implementation
  ******************************************************************************/
 
 package org.eclipse.linuxtools.lttng2.kernel.core.tests.stateprovider;
 
-import org.junit.runner.JUnitCore;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
 /**
- * The class <code>TestAll</code> builds a suite that can be used to run all of
- * the tests within its package as well as within any subpackages of its
- * package.
- * 
- * @author ematkho
- * @version $Revision: 1.0 $
+ * Runner for the LTTng kernel state system tests.
  */
 @RunWith(Suite.class)
-@Suite.SuiteClasses({ CtfKernelStateInputTest.class,
-    StateSystemFullHistoryTest.class})
+@Suite.SuiteClasses({
+    LttngKernelStateProviderTest.class,
+    PartialStateSystemTest.class,
+    StateSystemFullHistoryTest.class,
+    StateSystemInMemoryTest.class
+})
 public class TestAll {
 
-    /**
-     * Launch the test.
-     * 
-     * @param args
-     *            the command line arguments
-     */
-    public static void main(String[] args) {
-        JUnitCore.runClasses(new Class[] { TestAll.class });
-    }
 }
