@@ -21,11 +21,8 @@ import org.junit.runners.Suite;
  */
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
-    TmfCoalescedDataRequestTest.class,
     TmfCoalescedEventRequestTest.class,
-    TmfDataRequestTest.class,
     TmfEventRequestTest.class,
-    TmfSchedulerTest.class
 })
 public class AllTests {
 
