@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2013 Ericsson
+ * Copyright (c) 2012, 2014 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -8,8 +8,7 @@
  *
  * Contributors:
  *   Alexandre Montplaisir - Initial API and implementation
- *   Alexandre Montplaisir - Port to JUnit4
- ******************************************************************************/
+ *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.core.tests.statesystem;
 
@@ -17,12 +16,13 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
 /**
- * Test suite for org.eclipse.linuxtools.tmf.core.statesystem
+ * Test suite for org.eclipse.linuxtools.tmf.core.tests.statesystem
  */
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
-    StateSystemPushPopTest.class
+    ExperimentStateSystemModuleTest.class,
+    StateSystemAnalysisModuleTest.class
 })
 public class AllTests {
 
-}
\ No newline at end of file
+}
