@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2010 Ericsson
+ * Copyright (c) 2009, 2012 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -12,6 +12,7 @@
 
 package org.eclipse.linuxtools.tmf.tests.stubs.event;
 
+import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
 import org.eclipse.linuxtools.tmf.core.event.TmfEvent;
 
 /**
@@ -23,7 +24,7 @@ import org.eclipse.linuxtools.tmf.core.event.TmfEvent;
 public class TmfSyntheticEventStub extends TmfEvent {
 
 
-    public TmfSyntheticEventStub(final TmfEvent event) {
+    public TmfSyntheticEventStub(final ITmfEvent event) {
         super(event);
     }
     public TmfSyntheticEventStub(final TmfSyntheticEventStub other) {
