@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson
+ * Copyright (c) 2012, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -12,11 +12,9 @@
 
 package org.eclipse.linuxtools.tmf.tests.stubs.trace;
 
-import java.util.List;
-
-import org.eclipse.linuxtools.tmf.core.trace.ITmfCheckpoint;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
-import org.eclipse.linuxtools.tmf.core.trace.TmfCheckpointIndexer;
+import org.eclipse.linuxtools.tmf.core.trace.indexer.checkpoint.ITmfCheckpointIndex;
+import org.eclipse.linuxtools.tmf.core.trace.indexer.checkpoint.TmfCheckpointIndexer;
 
 /**
  * <b><u>TmfIndexerStub</u></b>
@@ -31,7 +29,7 @@ public class TmfIndexerStub extends TmfCheckpointIndexer {
         super(trace, blockSize);
     }
 
-    public List<ITmfCheckpoint> getCheckpoints() {
+    public ITmfCheckpointIndex getCheckpoints() {
         return getTraceIndex();
     }
 
