@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2012 Ericsson
+ * Copyright (c) 2009, 2014 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -8,6 +8,7 @@
  *
  * Contributors:
  *   Francois Chouinard - Initial API and implementation
+ *   Bernd Hufmann - Add interface for broadcasting signals asynchronously
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.core.component;
@@ -37,10 +38,19 @@ public interface ITmfComponent {
     void dispose();
 
     /**
-     * Propagate a signal to all the interested listeners.
+     * Propagate a signal to all the interested listeners in
+     * the same thread of execution.
      *
      * @param signal the signal to broadcast
      */
     void broadcast(TmfSignal signal);
 
+    /**
+     * Propagate a signal to all the interested listeners
+     * in a separate thread.
+     *
+     * @param signal the signal to broadcast
+     * @since 3.0
+     */
+    void broadcastAsync(TmfSignal signal);
 }
