@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011 Ericsson
+ * Copyright (c) 2011, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -8,26 +8,21 @@
  *
  * Contributors:
  *   Bernd Hufmann - Initial API and implementation
+ *   Alexandre Montplaisir - Port to JUnit4
  *******************************************************************************/
+
 package org.eclipse.linuxtools.tmf.ui.tests.views.uml2sd.load;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 /**
  *  Test suite for testing loader manager of UML2SD extension point.
  */
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+    LoadersManagerTest.class
+})
 public class AllTests {
 
-    /**
-     * @return the test suite.
-     */
-    public static Test suite() {
-
-        TestSuite suite = new TestSuite(AllTests.class.getName());
-        //$JUnit-BEGIN$
-        suite.addTestSuite(LoadersManagerTest.class);
-        //$JUnit-END$
-        return suite;
-    }
 }
