@@ -23,32 +23,32 @@ import org.eclipse.linuxtools.tmf.ui.widgets.timegraph.test.stub.model.EventImpl
  */
 public class TsfImplProvider extends TimeGraphPresentationProvider {
 
-	// ========================================================================
-	// Methods
-	// ========================================================================
-	@Override
-	public int getStateTableIndex(ITimeEvent event) {
-	    return 0;
-	}
+    // ========================================================================
+    // Methods
+    // ========================================================================
+    @Override
+    public int getStateTableIndex(ITimeEvent event) {
+        return 0;
+    }
 
-	@Override
-	public Map<String, String> getEventHoverToolTipInfo(ITimeEvent revent) {
-		Map<String, String> toolTipEventMsgs = new HashMap<String, String>();
-		if (revent instanceof EventImpl) {
-			toolTipEventMsgs.put("Test Tip1", "Test Value tip1");
-			toolTipEventMsgs.put("Test Tip2", "Test Value tip2");
-		}
+    @Override
+    public Map<String, String> getEventHoverToolTipInfo(ITimeEvent revent) {
+        Map<String, String> toolTipEventMsgs = new HashMap<>();
+        if (revent instanceof EventImpl) {
+            toolTipEventMsgs.put("Test Tip1", "Test Value tip1");
+            toolTipEventMsgs.put("Test Tip2", "Test Value tip2");
+        }
 
-		return toolTipEventMsgs;
-	}
+        return toolTipEventMsgs;
+    }
 
-	@Override
-	public String getEventName(ITimeEvent event) {
-		String name = "Unknown";
-		if (event instanceof EventImpl) {
-			EventImpl devent = (EventImpl) event;
-			name = devent.getType().toString();
-		}
-		return name;
-	}
+    @Override
+    public String getEventName(ITimeEvent event) {
+        String name = "Unknown";
+        if (event instanceof EventImpl) {
+            EventImpl devent = (EventImpl) event;
+            name = devent.getType().toString();
+        }
+        return name;
+    }
 }
