@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2013 Ericsson
+ * Copyright (c) 2012, 2014 Ericsson
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -34,46 +34,17 @@ public class Messages extends NLS {
     public static String ManageCustomParsersDialog_TextButtonLabel;
     public static String ManageCustomParsersDialog_TraceSelection;
 
-    public static String CustomTraceDefinition_messageTag;
-    public static String CustomTraceDefinition_otherTag;
-    public static String CustomTraceDefinition_timestampTag;
-    public static String CustomTxtTraceDefinition_action;
-    public static String CustomTxtTraceDefinition_cardinality;
-    public static String CustomTxtTraceDefinition_definition;
-    public static String CustomTxtTraceDefinition_definitionRootElement;
-    public static String CustomTxtTraceDefinition_format;
-    public static String CustomTxtTraceDefinition_inputData;
-    public static String CustomTxtTraceDefinition_inputLine;
-    public static String CustomTxtTraceDefinition_max;
-    public static String CustomTxtTraceDefinition_min;
-    public static String CustomTxtTraceDefinition_name;
-    public static String CustomTxtTraceDefinition_outputColumn;
-    public static String CustomTxtTraceDefinition_regEx;
-    public static String CustomTxtTraceDefinition_timestampOutputFormat;
-    public static String CustomXmlTraceDefinition_action;
-    public static String CustomXmlTraceDefinition_attribute;
-    public static String CustomXmlTraceDefinition_definition;
-    public static String CustomXmlTraceDefinition_definitionRootElement;
-    public static String CustomXmlTraceDefinition_format;
-    public static String CustomXmlTraceDefinition_ignoreTag;
-    public static String CustomXmlTraceDefinition_inputData;
-    public static String CustomXmlTraceDefinition_inputElement;
-    public static String CustomXmlTraceDefinition_logEntry;
-    public static String CustomXmlTraceDefinition_name;
-    public static String CustomXmlTraceDefinition_outputColumn;
-    public static String CustomXmlTraceDefinition_timestampOutputFormat;
-
     public static String TmfEventsTable_AddBookmarkActionText;
     public static String TmfEventsTable_AddBookmarkDialogMessage;
     public static String TmfEventsTable_AddBookmarkDialogTitle;
     public static String TmfEventsTable_ApplyPresetFilterMenuName;
     public static String TmfEventsTable_ClearFiltersActionText;
     public static String TmfEventsTable_ContentColumnHeader;
-
     public static String TmfEventsTable_Export_to_text;
     public static String TmfEventsTable_FilterHint;
     public static String TmfEventsTable_HideRawActionText;
     public static String TmfEventsTable_HideTableActionText;
+    public static String TmfEventsTable_MultipleBookmarksToolTip;
     public static String TmfEventsTable_OpenSourceCodeActionText;
     public static String TmfEventsTable_OpenSourceCodeNotFound;
     public static String TmfEventsTable_OpenSourceCodeSelectFileDialogTitle;
@@ -167,7 +138,6 @@ public class Messages extends NLS {
     public static String CustomTxtParserInputWizardPage_appendWith;
     public static String CustomTxtParserInputWizardPage_capturedGroup;
     public static String CustomTxtParserInputWizardPage_cardinality;
-    public static String CustomTxtParserInputWizardPage_dateFormatHelp;
     public static String CustomTxtParserInputWizardPage_desccriptionEdit;
     public static String CustomTxtParserInputWizardPage_descriptionNew;
     public static String CustomTxtParserInputWizardPage_format;
@@ -199,6 +169,7 @@ public class Messages extends NLS {
     public static String CustomTxtParserInputWizardPage_removeLine;
     public static String CustomTxtParserInputWizardPage_set;
     public static String CustomTxtParserInputWizardPage_timestampFormat;
+    public static String CustomTxtParserInputWizardPage_timestampFormatHelp;
     public static String CustomTxtParserInputWizardPage_uncapturedText;
     public static String CustomTxtParserInputWizardPage_unidentifiedCaptureGroup;
     public static String CustomTxtParserInputWizardPage_windowTitleEdit;
@@ -234,7 +205,6 @@ public class Messages extends NLS {
     public static String CustomXmlParserInputWizardPage_append;
     public static String CustomXmlParserInputWizardPage_appendWith;
     public static String CustomXmlParserInputWizardPage_attibute;
-    public static String CustomXmlParserInputWizardPage_dateFormatHelp;
     public static String CustomXmlParserInputWizardPage_descriptionEdit;
     public static String CustomXmlParserInputWizardPage_descriptionNew;
     public static String CustomXmlParserInputWizardPage_elementName;
@@ -256,6 +226,7 @@ public class Messages extends NLS {
     public static String CustomXmlParserInputWizardPage_set;
     public static String CustomXmlParserInputWizardPage_tagName;
     public static String CustomXmlParserInputWizardPage_timestampFormat;
+    public static String CustomXmlParserInputWizardPage_timestampFormatHelp;
     public static String CustomXmlParserInputWizardPage_titleEdit;
     public static String CustomXmlParserInputWizardPage_titleNew;
     public static String CustomXmlParserOutputWizardPage_description;
@@ -273,7 +244,6 @@ public class Messages extends NLS {
     public static String FilterViewer_EmptyTreeHintText;
     public static String FilterViewer_CommonCategory;
     public static String FilterViewer_AlphaButtonText;
-    public static String FilterViewer_DeleteActionText;
     public static String FilterViewer_FieldLabel;
     public static String FilterViewer_FilterNameHint;
     public static String FilterViewer_IgnoreCaseButtonText;
@@ -284,6 +254,7 @@ public class Messages extends NLS {
     public static String FilterViewer_RegexHint;
     public static String FilterViewer_RegexLabel;
     public static String FilterViewer_ResultLabel;
+    public static String FilterViewer_Subfilter_ToolTip;
     public static String FilterViewer_TimestampButtonText;
     public static String FilterViewer_TypeLabel;
     public static String FilterViewer_ValueHint;
@@ -292,12 +263,24 @@ public class Messages extends NLS {
     public static String TmfView_PinActionNameText;
     public static String TmfView_PinActionToolTipText;
 
+    public static String CallStackPresentationProvider_Thread;
     public static String CallStackView_FunctionColumn;
     public static String CallStackView_DepthColumn;
     public static String CallStackView_EntryTimeColumn;
     public static String CallStackView_ExitTimeColumn;
     public static String CallStackView_DurationColumn;
     public static String CallStackView_StackInfoNotAvailable;
+    public static String CallStackView_SortByThreadName;
+    public static String CallStackView_SortByThreadId;
+    public static String CallStackView_SortByThreadTime;
+    public static String CallStackView_ImportMappingButtonText;
+    public static String CallStackView_ImportMappingButtonTooltip;
+    public static String CallStackView_ImportMappingDialogTitle;
+    public static String CallStackView_ImportMappingJobName;
+
+    public static String CallStackView_ImportBinaryFileButtonText;
+    public static String CallStackView_ImportBinaryFileButtonTooltip;
+    public static String CallStackView_ImportBinaryFileDialogTitle;
 
     public static String ExportToTextJob_Export_to;
     public static String ExportToTextJob_Export_trace_to;
