@@ -1,3 +1,15 @@
+/*******************************************************************************
+ * Copyright (c) 2010, 2014 Ericsson
+ *
+ * All rights reserved. This program and the accompanying materials are
+ * made available under the terms of the Eclipse Public License v1.0 which
+ * accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ *   Patrick Tasse - Initial API and implementation
+ *******************************************************************************/
+
 package org.eclipse.linuxtools.internal.tmf.ui.parsers.wizards;
 
 import java.io.BufferedReader;
@@ -5,10 +17,9 @@ import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.net.URL;
 import java.text.ParseException;
-import java.text.SimpleDateFormat;
 import java.util.ArrayList;
-import java.util.Date;
 import java.util.List;
 
 import javax.xml.parsers.DocumentBuilder;
@@ -17,6 +28,10 @@ import javax.xml.parsers.ParserConfigurationException;
 
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.FileLocator;
+import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.Path;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.viewers.AbstractTreeViewer;
 import org.eclipse.jface.viewers.ColumnLabelProvider;
 import org.eclipse.jface.viewers.ISelection;
@@ -30,11 +45,12 @@ import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.jface.wizard.WizardPage;
 import org.eclipse.linuxtools.internal.tmf.ui.Activator;
 import org.eclipse.linuxtools.internal.tmf.ui.Messages;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTraceDefinition;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTrace;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTraceDefinition;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTraceDefinition.InputAttribute;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTraceDefinition.InputElement;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTraceDefinition;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTrace;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTraceDefinition;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTraceDefinition.InputAttribute;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTraceDefinition.InputElement;
+import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimestampFormat;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.browser.Browser;
 import org.eclipse.swt.browser.TitleEvent;
@@ -52,6 +68,8 @@ import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.graphics.Image;
+import org.eclipse.swt.graphics.Point;
+import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -63,6 +81,7 @@ import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
+import org.osgi.framework.Bundle;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;
@@ -74,22 +93,28 @@ import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
 
+/**
+ * Input wizard page for custom XML trace parsers.
+ *
+ * @author Patrick Tasse
+ */
 public class CustomXmlParserInputWizardPage extends WizardPage {
 
     private static final String DEFAULT_TIMESTAMP_FORMAT = "yyyy-MM-dd HH:mm:ss.SSS"; //$NON-NLS-1$
-    private static final String SIMPLE_DATE_FORMAT_URL = "http://java.sun.com/javase/6/docs/api/java/text/SimpleDateFormat.html#skip-navbar_top"; //$NON-NLS-1$
-    private static final Image elementImage = Activator.getDefault().getImageFromPath("/icons/elcl16/element_icon.gif"); //$NON-NLS-1$
-    private static final Image addImage = Activator.getDefault().getImageFromPath("/icons/elcl16/add_button.gif"); //$NON-NLS-1$
-    private static final Image addNextImage = Activator.getDefault().getImageFromPath("/icons/elcl16/addnext_button.gif"); //$NON-NLS-1$
-    private static final Image addChildImage = Activator.getDefault().getImageFromPath("/icons/elcl16/addchild_button.gif"); //$NON-NLS-1$
-    private static final Image addManyImage = Activator.getDefault().getImageFromPath("/icons/elcl16/addmany_button.gif"); //$NON-NLS-1$
-    private static final Image deleteImage = Activator.getDefault().getImageFromPath("/icons/elcl16/delete_button.gif"); //$NON-NLS-1$
-    private static final Image moveUpImage = Activator.getDefault().getImageFromPath("/icons/elcl16/moveup_button.gif"); //$NON-NLS-1$
-    private static final Image moveDownImage = Activator.getDefault().getImageFromPath("/icons/elcl16/movedown_button.gif"); //$NON-NLS-1$
-    private static final Image helpImage = Activator.getDefault().getImageFromPath("/icons/elcl16/help_button.gif"); //$NON-NLS-1$
+    private static final String TIMESTAMP_FORMAT_BUNDLE = "org.eclipse.linuxtools.lttng.help"; //$NON-NLS-1$
+    private static final String TIMESTAMP_FORMAT_PATH = "reference/api/org/eclipse/linuxtools/tmf/core/timestamp/TmfTimestampFormat.html"; //$NON-NLS-1$
+    private static final Image ELEMENT_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/element_icon.gif"); //$NON-NLS-1$
+    private static final Image ADD_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/add_button.gif"); //$NON-NLS-1$
+    private static final Image ADD_NEXT_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/addnext_button.gif"); //$NON-NLS-1$
+    private static final Image ADD_CHILD_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/addchild_button.gif"); //$NON-NLS-1$
+    private static final Image ADD_MANY_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/addmany_button.gif"); //$NON-NLS-1$
+    private static final Image DELETE_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/delete_button.gif"); //$NON-NLS-1$
+    private static final Image MOVE_UP_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/moveup_button.gif"); //$NON-NLS-1$
+    private static final Image MOVE_DOWN_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/movedown_button.gif"); //$NON-NLS-1$
+    private static final Image HELP_IMAGE = Activator.getDefault().getImageFromPath("/icons/elcl16/help_button.gif"); //$NON-NLS-1$
     private static final Color COLOR_LIGHT_RED = new Color(Display.getDefault(), 255, 192, 192);
-    private static final Color COLOR_TEXT_BACKGROUND = Display.getCurrent().getSystemColor(SWT.COLOR_WHITE);
-    private static final Color COLOR_WIDGET_BACKGROUND = Display.getCurrent().getSystemColor(SWT.COLOR_WIDGET_BACKGROUND);
+    private static final Color COLOR_TEXT_BACKGROUND = Display.getDefault().getSystemColor(SWT.COLOR_WHITE);
+    private static final Color COLOR_WIDGET_BACKGROUND = Display.getDefault().getSystemColor(SWT.COLOR_WIDGET_BACKGROUND);
 
     private final ISelection selection;
     private CustomXmlTraceDefinition definition;
@@ -105,11 +130,8 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
     private Button addNextButton;
     private Button moveUpButton;
     private Button moveDownButton;
-    private Button feelingLuckyButton;
-    private ScrolledComposite treeScrolledComposite;
     private ScrolledComposite elementScrolledComposite;
     private TreeViewer treeViewer;
-    private Composite treeContainer;
     private Composite elementContainer;
     private Text errorText;
     private StyledText inputText;
@@ -125,6 +147,14 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
     private int logEntriesCount;
     private boolean logEntryFound;
 
+    /**
+     * Constructor
+     *
+     * @param selection
+     *            Selection object
+     * @param definition
+     *            Trace definition
+     */
     protected CustomXmlParserInputWizardPage(ISelection selection, CustomXmlTraceDefinition definition) {
         super("CustomXmlParserWizardPage"); //$NON-NLS-1$
         if (definition == null) {
@@ -169,13 +199,20 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         timeStampOutputFormatText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
         timeStampOutputFormatText.setText(DEFAULT_TIMESTAMP_FORMAT);
 
-        Button dateFormatHelpButton = new Button(headerComposite, SWT.PUSH);
-        dateFormatHelpButton.setImage(helpImage);
-        dateFormatHelpButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_dateFormatHelp);
-        dateFormatHelpButton.addSelectionListener(new SelectionAdapter() {
+        Button timeStampFormatHelpButton = new Button(headerComposite, SWT.PUSH);
+        timeStampFormatHelpButton.setImage(HELP_IMAGE);
+        timeStampFormatHelpButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_timestampFormatHelp);
+        timeStampFormatHelpButton.addSelectionListener(new SelectionAdapter() {
             @Override
             public void widgetSelected(SelectionEvent e) {
-                openHelpShell(SIMPLE_DATE_FORMAT_URL);
+                Bundle plugin = Platform.getBundle(TIMESTAMP_FORMAT_BUNDLE);
+                IPath path = new Path(TIMESTAMP_FORMAT_PATH);
+                URL fileURL = FileLocator.find(plugin, path, null);
+                try {
+                    URL pageURL = FileLocator.toFileURL(fileURL);
+                    openHelpShell(pageURL.toString());
+                } catch (IOException e1) {
+                }
             }
         });
 
@@ -196,9 +233,9 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         SashForm hSash = new SashForm(vSash, SWT.HORIZONTAL);
         hSash.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
 
-        treeScrolledComposite = new ScrolledComposite(hSash, SWT.V_SCROLL | SWT.H_SCROLL);
+        ScrolledComposite treeScrolledComposite = new ScrolledComposite(hSash, SWT.V_SCROLL | SWT.H_SCROLL);
         treeScrolledComposite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
-        treeContainer = new Composite(treeScrolledComposite, SWT.NONE);
+        Composite treeContainer = new Composite(treeScrolledComposite, SWT.NONE);
         treeContainer.setLayout(new FillLayout());
         treeScrolledComposite.setContent(treeContainer);
         treeScrolledComposite.setExpandHorizontal(true);
@@ -298,7 +335,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         buttonBar.setLayout(buttonBarLayout);
 
         removeButton = new Button(buttonBar, SWT.PUSH);
-        removeButton.setImage(deleteImage);
+        removeButton.setImage(DELETE_IMAGE);
         removeButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_removeElement);
         removeButton.addSelectionListener(new SelectionAdapter() {
             @Override
@@ -330,7 +367,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         });
 
         addChildButton = new Button(buttonBar, SWT.PUSH);
-        addChildButton.setImage(addChildImage);
+        addChildButton.setImage(ADD_CHILD_IMAGE);
         addChildButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_addChildElement);
         addChildButton.addSelectionListener(new SelectionAdapter() {
             @Override
@@ -352,7 +389,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         });
 
         addNextButton = new Button(buttonBar, SWT.PUSH);
-        addNextButton.setImage(addNextImage);
+        addNextButton.setImage(ADD_NEXT_IMAGE);
         addNextButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_addNextElement);
         addNextButton.addSelectionListener(new SelectionAdapter() {
             @Override
@@ -376,8 +413,8 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
             }
         });
 
-        feelingLuckyButton = new Button(buttonBar, SWT.PUSH);
-        feelingLuckyButton.setImage(addManyImage);
+        Button feelingLuckyButton = new Button(buttonBar, SWT.PUSH);
+        feelingLuckyButton.setImage(ADD_MANY_IMAGE);
         feelingLuckyButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_feelingLucky);
         feelingLuckyButton.addSelectionListener(new SelectionAdapter() {
             @Override
@@ -404,7 +441,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         });
 
         moveUpButton = new Button(buttonBar, SWT.PUSH);
-        moveUpButton.setImage(moveUpImage);
+        moveUpButton.setImage(MOVE_UP_IMAGE);
         moveUpButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_moveUp);
         moveUpButton.addSelectionListener(new SelectionAdapter() {
             @Override
@@ -424,7 +461,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         });
 
         moveDownButton = new Button(buttonBar, SWT.PUSH);
-        moveDownButton.setImage(moveDownImage);
+        moveDownButton.setImage(MOVE_DOWN_IMAGE);
         moveDownButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_moveDown);
         moveDownButton.addSelectionListener(new SelectionAdapter() {
             @Override
@@ -509,7 +546,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
 
         @Override
         public Image getImage(Object element) {
-            return elementImage;
+            return ELEMENT_IMAGE;
         }
 
         @Override
@@ -526,8 +563,8 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
                 selectedElement.dispose();
             }
             if (!(event.getSelection().isEmpty()) && event.getSelection() instanceof IStructuredSelection) {
-                IStructuredSelection selection = (IStructuredSelection) event.getSelection();
-                InputElement inputElement = (InputElement) selection.getFirstElement();
+                IStructuredSelection sel = (IStructuredSelection) event.getSelection();
+                InputElement inputElement = (InputElement) sel.getFirstElement();
                 selectedElement = new ElementNode(elementContainer, inputElement);
                 elementContainer.layout();
                 elementScrolledComposite.setMinSize(elementContainer.computeSize(SWT.DEFAULT, SWT.DEFAULT).x,
@@ -560,11 +597,6 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.eclipse.jface.dialogs.DialogPage#dispose()
-     */
     @Override
     public void dispose() {
         if (fixedFont != null) {
@@ -597,11 +629,6 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         return getName(inputElement) + " : " + name; //$NON-NLS-1$
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.eclipse.jface.dialogs.DialogPage#setVisible(boolean)
-     */
     @Override
     public void setVisible(boolean visible) {
         if (visible) {
@@ -611,12 +638,24 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         super.setVisible(visible);
     }
 
+    /**
+     * Get the global list of input names.
+     *
+     * @return The list of input names
+     */
     public List<String> getInputNames() {
         return getInputNames(definition.rootInputElement);
     }
 
+    /**
+     * Get the list of input names for a given element.
+     *
+     * @param inputElement
+     *            The element
+     * @return The input names for this element
+     */
     public List<String> getInputNames(InputElement inputElement) {
-        List<String> inputs = new ArrayList<String>();
+        List<String> inputs = new ArrayList<>();
         if (inputElement.inputName != null && !inputElement.inputName.equals(CustomXmlTraceDefinition.TAG_IGNORE)) {
             String inputName = inputElement.inputName;
             if (!inputs.contains(inputName)) {
@@ -655,9 +694,9 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
     private String getSelectionText() {
         InputStream inputStream = null;
         if (this.selection instanceof IStructuredSelection) {
-            Object selection = ((IStructuredSelection) this.selection).getFirstElement();
-            if (selection instanceof IFile) {
-                IFile file = (IFile) selection;
+            Object sel = ((IStructuredSelection) this.selection).getFirstElement();
+            if (sel instanceof IFile) {
+                IFile file = (IFile) sel;
                 try {
                     inputStream = file.getContents();
                 } catch (CoreException e) {
@@ -666,16 +705,13 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
             }
         }
         if (inputStream != null) {
-            BufferedReader reader = null;
-            try {
-                reader = new BufferedReader(new InputStreamReader(inputStream));
+            try (BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream));) {
                 StringBuilder sb = new StringBuilder();
                 String line = null;
                 while ((line = reader.readLine()) != null) {
                     sb.append(line + "\n"); //$NON-NLS-1$
                 }
                 parseXmlInput(sb.toString());
-                reader.close();
                 return sb.toString();
             } catch (IOException e) {
                 return ""; //$NON-NLS-1$
@@ -736,10 +772,6 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         }
     }
 
-    private void updatePreviews() {
-        updatePreviews(false);
-    }
-
     private void initValues() {
         timeStampValue = null;
         timeStampFormat = null;
@@ -747,7 +779,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         logEntryFound = false;
     }
 
-    private void updatePreviews(boolean updateAll) {
+    private void updatePreviews() {
         if (inputText == null) {
             // early update during construction
             return;
@@ -763,10 +795,10 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
 
         if (timeStampValue != null && timeStampFormat != null) {
             try {
-                SimpleDateFormat dateFormat = new SimpleDateFormat(timeStampFormat);
-                Date date = dateFormat.parse(timeStampValue);
-                dateFormat = new SimpleDateFormat(timeStampOutputFormatText.getText().trim());
-                timeStampPreviewText.setText(dateFormat.format(date));
+                TmfTimestampFormat timestampFormat = new TmfTimestampFormat(timeStampFormat);
+                long timestamp = timestampFormat.parseValue(timeStampValue);
+                timestampFormat = new TmfTimestampFormat(timeStampOutputFormatText.getText().trim());
+                timeStampPreviewText.setText(timestampFormat.format(timestamp));
             } catch (ParseException e) {
                 timeStampPreviewText.setText("*parse exception* [" + timeStampValue + "] <> [" + timeStampFormat + "]"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
             } catch (IllegalArgumentException e) {
@@ -794,8 +826,10 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
                 helpShell.setText(event.title);
             }
         });
-        helpBrowser.setBounds(0, 0, 600, 400);
-        helpShell.pack();
+        Rectangle r = container.getBounds();
+        Point p = container.toDisplay(r.x, r.y);
+        Rectangle trim = helpShell.computeTrim(p.x + (r.width - 750) / 2, p.y + (r.height - 400) / 2, 750, 400);
+        helpShell.setBounds(trim);
         helpShell.open();
         helpBrowser.setUrl(url);
     }
@@ -823,23 +857,23 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
     }
 
     private class ElementNode {
-        final InputElement inputElement;
-        final Group group;
-        List<Attribute> attributes = new ArrayList<Attribute>();
-        List<ElementNode> childElements = new ArrayList<ElementNode>();
-        Text elementNameText;
-        Composite tagComposite;
-        Combo tagCombo;
-        Label tagLabel;
-        Text tagText;
-        Combo actionCombo;
-        Label previewLabel;
-        Text previewText;
-        Button logEntryButton;
-        Label fillerLabel;
-        Composite addAttributeComposite;
-        Button addAttributeButton;
-        Label addAttributeLabel;
+        private final InputElement inputElement;
+        private final Group group;
+        private List<Attribute> attributes = new ArrayList<>();
+        private List<ElementNode> childElements = new ArrayList<>();
+        private Text elementNameText;
+        private Composite tagComposite;
+        private Combo tagCombo;
+        private Label tagLabel;
+        private Text tagText;
+        private Combo actionCombo;
+        private Label previewLabel;
+        private Text previewText;
+        private Button logEntryButton;
+        private Label fillerLabel;
+        private Composite addAttributeComposite;
+        private Button addAttributeButton;
+        private Label addAttributeLabel;
 
         public ElementNode(Composite parent, InputElement inputElement) {
             this.inputElement = inputElement;
@@ -891,10 +925,10 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
 
                     @Override
                     public void widgetSelected(SelectionEvent e) {
-                        InputElement parent = ElementNode.this.inputElement.parentElement;
-                        while (parent != null) {
-                            parent.logEntry = false;
-                            parent = parent.parentElement;
+                        InputElement parentElem = ElementNode.this.inputElement.parentElement;
+                        while (parentElem != null) {
+                            parentElem.logEntry = false;
+                            parentElem = parentElem.parentElement;
                         }
                     }
                 });
@@ -1098,7 +1132,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
             addAttributeComposite.setLayout(addAttributeLayout);
 
             addAttributeButton = new Button(addAttributeComposite, SWT.PUSH);
-            addAttributeButton.setImage(addImage);
+            addAttributeButton.setImage(ADD_IMAGE);
             addAttributeButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_addAttribute);
             addAttributeButton.addSelectionListener(new SelectionAdapter() {
                 @Override
@@ -1128,9 +1162,10 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         }
 
         private void removeAttribute(int attributeNumber) {
-            if (--attributeNumber < attributes.size()) {
-                attributes.remove(attributeNumber).dispose();
-                for (int i = attributeNumber; i < attributes.size(); i++) {
+            int nb = attributeNumber;
+            if (--nb < attributes.size()) {
+                attributes.remove(nb).dispose();
+                for (int i = nb; i < attributes.size(); i++) {
                     attributes.get(i).setAttributeNumber(i + 1);
                 }
                 elementContainer.layout();
@@ -1158,7 +1193,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
                 }
                 inputElement.inputAction = actionCombo.getSelectionIndex();
             }
-            inputElement.attributes = new ArrayList<InputAttribute>(attributes.size());
+            inputElement.attributes = new ArrayList<>(attributes.size());
             for (int i = 0; i < attributes.size(); i++) {
                 Attribute attribute = attributes.get(i);
                 InputAttribute inputAttribute = new InputAttribute();
@@ -1178,27 +1213,27 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
     }
 
     private class Attribute {
-        ElementNode element;
-        int attributeNumber;
+        private ElementNode element;
+        private int attributeNumber;
 
         // children of parent (must be disposed)
-        Composite labelComposite;
-        Composite attributeComposite;
-        Label filler;
-        Composite tagComposite;
+        private Composite labelComposite;
+        private Composite attributeComposite;
+        private Label filler;
+        private Composite tagComposite;
 
         // children of labelComposite
-        Label attributeLabel;
+        private Label attributeLabel;
 
         // children of attributeComposite
-        Text attributeNameText;
-        Text previewText;
+        private Text attributeNameText;
+        private Text previewText;
 
         // children of tagComposite
-        Combo tagCombo;
-        Label tagLabel;
-        Text tagText;
-        Combo actionCombo;
+        private Combo tagCombo;
+        private Label tagLabel;
+        private Text tagText;
+        private Combo actionCombo;
 
         public Attribute(Composite parent, ElementNode element, InputAttribute inputAttribute, int attributeNumber) {
             this.element = element;
@@ -1213,7 +1248,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
 
             Button deleteButton = new Button(labelComposite, SWT.PUSH);
             deleteButton.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false));
-            deleteButton.setImage(deleteImage);
+            deleteButton.setImage(DELETE_IMAGE);
             deleteButton.setToolTipText(Messages.CustomXmlParserInputWizardPage_removeAttribute);
             deleteButton.addSelectionListener(new SelectionAdapter() {
                 @Override
@@ -1349,15 +1384,16 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
     }
 
     private Element getPreviewElement(InputElement inputElement) {
+        InputElement currentElement = inputElement;
         Element element = documentElement;
         if (element != null) {
             if (!documentElement.getNodeName().equals(definition.rootInputElement.elementName)) {
                 return null;
             }
-            ArrayList<String> elementNames = new ArrayList<String>();
-            while (inputElement != null) {
-                elementNames.add(inputElement.elementName);
-                inputElement = inputElement.parentElement;
+            ArrayList<String> elementNames = new ArrayList<>();
+            while (currentElement != null) {
+                elementNames.add(currentElement.elementName);
+                currentElement = currentElement.parentElement;
             }
             for (int i = elementNames.size() - 1; --i >= 0;) {
                 NodeList childList = element.getChildNodes();
@@ -1451,12 +1487,11 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         } else {
             logtypeText.setBackground(COLOR_TEXT_BACKGROUND);
             for (CustomXmlTraceDefinition def : CustomXmlTraceDefinition.loadAll()) {
-                if (definition.definitionName.equals(def.definitionName)) {
-                    if (editDefinitionName == null || !editDefinitionName.equals(definition.definitionName)) {
-                        errors.append(Messages.CustomXmlParserInputWizardPage_duplicatelogTypeError);
-                        logtypeText.setBackground(COLOR_LIGHT_RED);
-                        break;
-                    }
+                if (definition.definitionName.equals(def.definitionName) &&
+                        (editDefinitionName == null || !editDefinitionName.equals(definition.definitionName))) {
+                    errors.append(Messages.CustomXmlParserInputWizardPage_duplicatelogTypeError);
+                    logtypeText.setBackground(COLOR_LIGHT_RED);
+                    break;
                 }
             }
         }
@@ -1484,7 +1519,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
                         timeStampOutputFormatText.setBackground(COLOR_LIGHT_RED);
                     } else {
                         try {
-                            new SimpleDateFormat(timeStampOutputFormatText.getText().trim());
+                            new TmfTimestampFormat(timeStampOutputFormatText.getText().trim());
                             timeStampOutputFormatText.setBackground(COLOR_TEXT_BACKGROUND);
                         } catch (IllegalArgumentException e) {
                             errors.append(Messages.CustomXmlParserInputWizardPage_invalidTimestampFmtError);
@@ -1508,6 +1543,13 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         }
     }
 
+    /**
+     * Clean up the specified XML element.
+     *
+     * @param inputElement
+     *            The element to clean up
+     * @return The validated element
+     */
     public StringBuffer validateElement(InputElement inputElement) {
         StringBuffer errors = new StringBuffer();
         ElementNode elementNode = null;
@@ -1540,7 +1582,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
                     }
                 } else {
                     try {
-                        new SimpleDateFormat(inputElement.inputFormat);
+                        new TmfTimestampFormat(inputElement.inputFormat);
                         if (elementNode != null) {
                             elementNode.tagText.setBackground(COLOR_TEXT_BACKGROUND);
                         }
@@ -1604,7 +1646,7 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
                         }
                     } else {
                         try {
-                            new SimpleDateFormat(attribute.inputFormat);
+                            new TmfTimestampFormat(attribute.inputFormat);
                             if (elementNode != null) {
                                 elementNode.attributes.get(i).tagText.setBackground(COLOR_TEXT_BACKGROUND);
                             }
@@ -1681,10 +1723,20 @@ public class CustomXmlParserInputWizardPage extends WizardPage {
         return errors;
     }
 
+    /**
+     * Get the trace definition.
+     *
+     * @return The trace definition
+     */
     public CustomXmlTraceDefinition getDefinition() {
         return definition;
     }
 
+    /**
+     * Get the raw text input.
+     *
+     * @return The raw text input.
+     */
     public char[] getInputText() {
         return inputText.getText().toCharArray();
     }
