@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2012 Ericsson
+ * Copyright (c) 2010, 2014 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -12,7 +12,6 @@
 
 package org.eclipse.linuxtools.tmf.ui.editors;
 
-import org.eclipse.core.resources.IFile;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
 
 /**
@@ -29,11 +28,4 @@ public interface ITmfTraceEditor {
      * @return The trace
      */
     ITmfTrace getTrace();
-
-    /**
-     * Get the bookmark file associated to this trace
-     *
-     * @return The IFile object pointing to the bookmark file
-     */
-    IFile getBookmarksFile();
 }
