@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2013 Ericsson
+ * Copyright (c) 2010, 2014 Ericsson, École Polytechnique de Montréal
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -8,6 +8,7 @@
  *
  * Contributors:
  *   Patrick Tasse - Initial API and implementation
+ *   Geneviève Bastien - Experiment instantiated with experiment type
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.ui.editors;
@@ -38,9 +39,10 @@ import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.linuxtools.internal.tmf.ui.Activator;
 import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomEventsTable;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtTrace;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTrace;
 import org.eclipse.linuxtools.tmf.core.TmfCommonConstants;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTxtTrace;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTrace;
+import org.eclipse.linuxtools.tmf.core.project.model.TmfTraceType.TraceElementType;
 import org.eclipse.linuxtools.tmf.core.signal.TmfSignalHandler;
 import org.eclipse.linuxtools.tmf.core.signal.TmfTimestampFormatUpdateSignal;
 import org.eclipse.linuxtools.tmf.core.signal.TmfTraceClosedSignal;
@@ -50,15 +52,13 @@ import org.eclipse.linuxtools.tmf.core.trace.ITmfContext;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
 import org.eclipse.linuxtools.tmf.core.trace.TmfExperiment;
 import org.eclipse.linuxtools.tmf.core.trace.TmfTrace;
-import org.eclipse.linuxtools.tmf.ui.project.model.ITmfProjectModelElement;
 import org.eclipse.linuxtools.tmf.ui.project.model.Messages;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfExperimentElement;
-import org.eclipse.linuxtools.tmf.ui.project.model.TmfNavigatorContentProvider;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfOpenTraceHelper;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfProjectElement;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfProjectRegistry;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfTraceElement;
-import org.eclipse.linuxtools.tmf.ui.project.model.TmfTraceType;
+import org.eclipse.linuxtools.tmf.ui.project.model.TmfTraceTypeUIUtils;
 import org.eclipse.linuxtools.tmf.ui.viewers.events.TmfEventsTable;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Display;
@@ -125,32 +125,24 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
                 }
                 if (traceTypeId.equals(TmfExperiment.class.getCanonicalName())) {
                     // Special case: experiment bookmark resource
-                    final TmfNavigatorContentProvider ncp = new TmfNavigatorContentProvider();
-                    ncp.getChildren(fFile.getProject()); // force the model to be populated
-                    final TmfProjectElement project = TmfProjectRegistry.getProject(fFile.getProject());
+                    final TmfProjectElement project = TmfProjectRegistry.getProject(fFile.getProject(), true);
                     if (project == null) {
                         throw new PartInitException(Messages.TmfOpenTraceHelper_NoTraceType);
                     }
-                    for (final ITmfProjectModelElement projectElement : project.getExperimentsFolder().getChildren()) {
-                        final String traceName = fFile.getParent().getName();
-                        if (projectElement.getName().equals(traceName)) {
-                            final TmfExperimentElement experimentElement = (TmfExperimentElement) projectElement;
+                    for (final TmfExperimentElement experimentElement : project.getExperimentsFolder().getExperiments()) {
+                        if (experimentElement.getResource().equals(fFile.getParent())) {
                             setPartName(experimentElement.getName());
                             super.setSite(site);
                             super.setInput(fileEditorInput);
-                            TmfOpenTraceHelper.reopenExperimentFromElement(experimentElement, this);
+                            TmfOpenTraceHelper.reopenTraceFromElement(experimentElement, this);
                             return;
                         }
                     }
                 } else if (traceTypeId.equals(TmfTrace.class.getCanonicalName())) {
                     // Special case: trace bookmark resource
-                    final TmfNavigatorContentProvider ncp = new TmfNavigatorContentProvider();
-                    ncp.getChildren(fFile.getProject()); // force the model to be populated
-                    final TmfProjectElement project = TmfProjectRegistry.getProject(fFile.getProject());
-                    for (final ITmfProjectModelElement projectElement : project.getTracesFolder().getChildren()) {
-                        final String traceName = fFile.getParent().getName();
-                        if (projectElement.getName().equals(traceName)) {
-                            final TmfTraceElement traceElement = (TmfTraceElement) projectElement;
+                    final TmfProjectElement project = TmfProjectRegistry.getProject(fFile.getProject(), true);
+                    for (final TmfTraceElement traceElement : project.getTracesFolder().getTraces()) {
+                        if (traceElement.getResource().equals(fFile.getParent())) {
                             setPartName(traceElement.getName());
                             super.setSite(site);
                             super.setInput(fileEditorInput);
@@ -159,12 +151,9 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
                         }
                     }
                 } else {
-                    final TmfNavigatorContentProvider ncp = new TmfNavigatorContentProvider();
-                    ncp.getChildren(fFile.getProject()); // force the model to be populated
-                    final TmfProjectElement project = TmfProjectRegistry.getProject(fFile.getProject());
-                    for (final ITmfProjectModelElement projectElement : project.getTracesFolder().getChildren()) {
-                        if (projectElement.getResource().equals(fFile)) {
-                            final TmfTraceElement traceElement = (TmfTraceElement) projectElement;
+                    final TmfProjectElement project = TmfProjectRegistry.getProject(fFile.getProject(), true);
+                    for (final TmfTraceElement traceElement : project.getTracesFolder().getTraces()) {
+                        if (traceElement.getResource().equals(fFile)) {
                             setPartName(traceElement.getName());
                             super.setSite(site);
                             super.setInput(fileEditorInput);
@@ -209,7 +198,9 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
     @Override
     public void propertyChanged(final Object source, final int propId) {
         if (propId == IEditorPart.PROP_INPUT && getEditorInput() instanceof TmfEditorInput) {
-            broadcast(new TmfTraceClosedSignal(this, fTrace));
+            if (fTrace != null) {
+                broadcast(new TmfTraceClosedSignal(this, fTrace));
+            }
             fTraceSelected = false;
             fFile = ((TmfEditorInput) getEditorInput()).getFile();
             fTrace = ((TmfEditorInput) getEditorInput()).getTrace();
@@ -305,9 +296,6 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
     }
 
     private TmfEventsTable getEventsTable(final Composite parent, final int cacheSize) {
-        if (fTrace instanceof TmfExperiment) {
-            return getExperimentEventsTable((TmfExperiment) fTrace, parent, cacheSize);
-        }
         TmfEventsTable eventsTable = null;
         try {
             if (fTrace.getResource() == null) {
@@ -323,13 +311,18 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
             if (traceType.startsWith(CustomXmlTrace.class.getCanonicalName())) {
                 return new CustomEventsTable(((CustomXmlTrace) fTrace).getDefinition(), parent, cacheSize);
             }
-            for (final IConfigurationElement ce : TmfTraceType.getTypeElements()) {
-                if (ce.getAttribute(TmfTraceType.ID_ATTR).equals(traceType)) {
-                    final IConfigurationElement[] eventsTableTypeCE = ce.getChildren(TmfTraceType.EVENTS_TABLE_TYPE_ELEM);
+            TraceElementType type = TraceElementType.TRACE;
+            if (fTrace instanceof TmfExperiment) {
+                type = TraceElementType.EXPERIMENT;
+            }
+            for (final IConfigurationElement ce : TmfTraceTypeUIUtils.getTypeUIElements(type)) {
+                if (ce.getAttribute(TmfTraceTypeUIUtils.TRACETYPE_ATTR).equals(traceType)) {
+                    final IConfigurationElement[] eventsTableTypeCE = ce.getChildren(TmfTraceTypeUIUtils.EVENTS_TABLE_TYPE_ELEM);
+
                     if (eventsTableTypeCE.length != 1) {
                         break;
                     }
-                    final String eventsTableType = eventsTableTypeCE[0].getAttribute(TmfTraceType.CLASS_ATTR);
+                    final String eventsTableType = eventsTableTypeCE[0].getAttribute(TmfTraceTypeUIUtils.CLASS_ATTR);
                     if ((eventsTableType == null) || (eventsTableType.length() == 0)) {
                         break;
                     }
@@ -342,6 +335,9 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
                     break;
                 }
             }
+            if (fTrace instanceof TmfExperiment && (eventsTable == null)) {
+                eventsTable = getExperimentEventsTable((TmfExperiment) fTrace, parent, cacheSize);
+            }
         } catch (final InvalidRegistryObjectException e) {
             Activator.getDefault().logError("Error getting TmfEventsTable", e); //$NON-NLS-1$
         } catch (final CoreException e) {
@@ -402,13 +398,13 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
             if (commonTraceType.startsWith(CustomXmlTrace.class.getCanonicalName())) {
                 return new CustomEventsTable(((CustomXmlTrace) experiment.getTraces()[0]).getDefinition(), parent, cacheSize);
             }
-            for (final IConfigurationElement ce : TmfTraceType.getTypeElements()) {
-                if (ce.getAttribute(TmfTraceType.ID_ATTR).equals(commonTraceType)) {
-                    final IConfigurationElement[] eventsTableTypeCE = ce.getChildren(TmfTraceType.EVENTS_TABLE_TYPE_ELEM);
+            for (final IConfigurationElement ce : TmfTraceTypeUIUtils.getTypeUIElements(TraceElementType.TRACE)) {
+                if (ce.getAttribute(TmfTraceTypeUIUtils.TRACETYPE_ATTR).equals(commonTraceType)) {
+                    final IConfigurationElement[] eventsTableTypeCE = ce.getChildren(TmfTraceTypeUIUtils.EVENTS_TABLE_TYPE_ELEM);
                     if (eventsTableTypeCE.length != 1) {
                         break;
                     }
-                    final String eventsTableType = eventsTableTypeCE[0].getAttribute(TmfTraceType.CLASS_ATTR);
+                    final String eventsTableType = eventsTableTypeCE[0].getAttribute(TmfTraceTypeUIUtils.CLASS_ATTR);
                     if ((eventsTableType == null) || (eventsTableType.length() == 0)) {
                         break;
                     }
@@ -448,11 +444,6 @@ public class TmfEventsEditor extends TmfEditor implements ITmfTraceEditor, IReus
         return fTrace;
     }
 
-    @Override
-    public IFile getBookmarksFile() {
-        return fFile;
-    }
-
     @Override
     public void setFocus() {
         fEventsTable.setFocus();
