@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2013 Ericsson, École Polytechnique de Montréal
+ * Copyright (c) 2010, 2014 Ericsson, École Polytechnique de Montréal
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -14,12 +14,11 @@
  *   Patrick Tasse - Close editors to release resources
  *   Jean-Christian Kouame - added trace properties to be shown into
  *                           the properties view
+ *   Geneviève Bastien - Moved trace type related methods to parent class
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.ui.project.model;
 
-import java.io.ByteArrayInputStream;
-import java.io.InputStream;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.LinkedList;
@@ -34,15 +33,18 @@ import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.Platform;
+import org.eclipse.core.runtime.URIUtil;
 import org.eclipse.linuxtools.internal.tmf.ui.Activator;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtEvent;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtTrace;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtTraceDefinition;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlEvent;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTrace;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTraceDefinition;
 import org.eclipse.linuxtools.tmf.core.TmfCommonConstants;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTxtEvent;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTxtTrace;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTxtTraceDefinition;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlEvent;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTrace;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTraceDefinition;
+import org.eclipse.linuxtools.tmf.core.project.model.TmfTraceType;
+import org.eclipse.linuxtools.tmf.core.project.model.TraceTypeHelper;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
 import org.eclipse.linuxtools.tmf.core.trace.ITmfTraceProperties;
 import org.eclipse.linuxtools.tmf.core.trace.TmfTrace;
@@ -50,13 +52,6 @@ import org.eclipse.linuxtools.tmf.core.trace.TmfTraceManager;
 import org.eclipse.linuxtools.tmf.ui.editors.TmfEventsEditor;
 import org.eclipse.linuxtools.tmf.ui.properties.ReadOnlyTextPropertyDescriptor;
 import org.eclipse.ui.IActionFilter;
-import org.eclipse.ui.IEditorReference;
-import org.eclipse.ui.IWorkbench;
-import org.eclipse.ui.IWorkbenchPage;
-import org.eclipse.ui.IWorkbenchWindow;
-import org.eclipse.ui.PartInitException;
-import org.eclipse.ui.PlatformUI;
-import org.eclipse.ui.part.FileEditorInput;
 import org.eclipse.ui.views.properties.IPropertyDescriptor;
 import org.eclipse.ui.views.properties.IPropertySource2;
 
@@ -68,7 +63,7 @@ import org.eclipse.ui.views.properties.IPropertySource2;
  * @version 1.0
  * @author Francois Chouinard
  */
-public class TmfTraceElement extends TmfWithFolderElement implements IActionFilter, IPropertySource2 {
+public class TmfTraceElement extends TmfCommonProjectElement implements IActionFilter, IPropertySource2 {
 
     // ------------------------------------------------------------------------
     // Constants
@@ -89,18 +84,20 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
     private static final String sfName = Messages.TmfTraceElement_Name;
     private static final String sfPath = Messages.TmfTraceElement_Path;
     private static final String sfLocation = Messages.TmfTraceElement_Location;
-    private static final String sfEventType = Messages.TmfTraceElement_EventType;
+    private static final String sfTraceType = Messages.TmfTraceElement_EventType;
     private static final String sfIsLinked = Messages.TmfTraceElement_IsLinked;
+    private static final String sfSourceLocation = Messages.TmfTraceElement_SourceLocation;
     private static final String sfTracePropertiesCategory = Messages.TmfTraceElement_TraceProperties;
 
     private static final ReadOnlyTextPropertyDescriptor sfNameDescriptor = new ReadOnlyTextPropertyDescriptor(sfName, sfName);
     private static final ReadOnlyTextPropertyDescriptor sfPathDescriptor = new ReadOnlyTextPropertyDescriptor(sfPath, sfPath);
     private static final ReadOnlyTextPropertyDescriptor sfLocationDescriptor = new ReadOnlyTextPropertyDescriptor(sfLocation, sfLocation);
-    private static final ReadOnlyTextPropertyDescriptor sfTypeDescriptor = new ReadOnlyTextPropertyDescriptor(sfEventType, sfEventType);
+    private static final ReadOnlyTextPropertyDescriptor sfTypeDescriptor = new ReadOnlyTextPropertyDescriptor(sfTraceType, sfTraceType);
     private static final ReadOnlyTextPropertyDescriptor sfIsLinkedDescriptor = new ReadOnlyTextPropertyDescriptor(sfIsLinked, sfIsLinked);
+    private static final ReadOnlyTextPropertyDescriptor sfSourceLocationDescriptor = new ReadOnlyTextPropertyDescriptor(sfSourceLocation, sfSourceLocation);
 
     private static final IPropertyDescriptor[] sfDescriptors = { sfNameDescriptor, sfPathDescriptor, sfLocationDescriptor,
-            sfTypeDescriptor, sfIsLinkedDescriptor };
+            sfTypeDescriptor, sfIsLinkedDescriptor, sfSourceLocationDescriptor };
 
     static {
         sfNameDescriptor.setCategory(sfResourcePropertiesCategory);
@@ -108,40 +105,50 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         sfLocationDescriptor.setCategory(sfResourcePropertiesCategory);
         sfTypeDescriptor.setCategory(sfResourcePropertiesCategory);
         sfIsLinkedDescriptor.setCategory(sfResourcePropertiesCategory);
+        sfSourceLocationDescriptor.setCategory(sfResourcePropertiesCategory);
     }
 
-    private static final String BOOKMARKS_HIDDEN_FILE = ".bookmarks"; //$NON-NLS-1$
-
-    // ------------------------------------------------------------------------
-    // Attributes
-    // ------------------------------------------------------------------------
-
-    // This trace type ID as defined in plugin.xml
-    private String fTraceTypeId = null;
-
     // ------------------------------------------------------------------------
     // Static initialization
     // ------------------------------------------------------------------------
 
     // The mapping of available trace type IDs to their corresponding
     // configuration element
-    private static final Map<String, IConfigurationElement> sfTraceTypeAttributes = new HashMap<String, IConfigurationElement>();
-    private static final Map<String, IConfigurationElement> sfTraceCategories = new HashMap<String, IConfigurationElement>();
+    private static final Map<String, IConfigurationElement> sfTraceTypeAttributes = new HashMap<>();
+    private static final Map<String, IConfigurationElement> sfTraceTypeUIAttributes = new HashMap<>();
+    private static final Map<String, IConfigurationElement> sfTraceCategories = new HashMap<>();
 
     /**
      * Initialize statically at startup by getting extensions from the platform
      * extension registry.
      */
     public static void init() {
+        /* Read the tmf.core "tracetype" extension point */
         IConfigurationElement[] config = Platform.getExtensionRegistry().getConfigurationElementsFor(TmfTraceType.TMF_TRACE_TYPE_ID);
         for (IConfigurationElement ce : config) {
-            String elementName = ce.getName();
-            if (elementName.equals(TmfTraceType.TYPE_ELEM)) {
+            switch (ce.getName()) {
+            case TmfTraceType.TYPE_ELEM:
                 String traceTypeId = ce.getAttribute(TmfTraceType.ID_ATTR);
                 sfTraceTypeAttributes.put(traceTypeId, ce);
-            } else if (elementName.equals(TmfTraceType.CATEGORY_ELEM)) {
+                break;
+            case TmfTraceType.CATEGORY_ELEM:
                 String categoryId = ce.getAttribute(TmfTraceType.ID_ATTR);
                 sfTraceCategories.put(categoryId, ce);
+                break;
+            default:
+            }
+        }
+
+        /*
+         * Read the corresponding tmf.ui "tracetypeui" extension point for this
+         * trace type, if it exists.
+         */
+        config = Platform.getExtensionRegistry().getConfigurationElementsFor(TmfTraceTypeUIUtils.TMF_TRACE_TYPE_UI_ID);
+        for (IConfigurationElement ce : config) {
+            String elemName = ce.getName();
+            if (TmfTraceTypeUIUtils.TYPE_ELEM.equals(elemName)) {
+                String traceType = ce.getAttribute(TmfTraceTypeUIUtils.TRACETYPE_ATTR);
+                sfTraceTypeUIAttributes.put(traceType, ce);
             }
         }
     }
@@ -160,7 +167,7 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      *            The parent element (trace folder)
      */
     public TmfTraceElement(String name, IResource trace, TmfTraceFolder parent) {
-        this(name, trace, (TmfProjectModelElement) parent);
+        super(name, trace, parent);
     }
 
     /**
@@ -174,38 +181,12 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      *            The parent element (experiment folder)
      */
     public TmfTraceElement(String name, IResource trace, TmfExperimentElement parent) {
-        this(name, trace, (TmfProjectModelElement) parent);
-    }
-
-    private TmfTraceElement(String name, IResource trace, TmfProjectModelElement parent) {
         super(name, trace, parent);
-        parent.addChild(this);
-        refreshTraceType();
     }
 
     // ------------------------------------------------------------------------
     // Operations
     // ------------------------------------------------------------------------
-    /**
-     * Returns the trace type ID.
-     *
-     * @return trace type ID.
-     */
-    public String getTraceType() {
-        return fTraceTypeId;
-    }
-
-    /**
-     * Refreshes the trace type filed by reading the trace type persistent
-     * property of the resource referenece.
-     */
-    public void refreshTraceType() {
-        try {
-            fTraceTypeId = getResource().getPersistentProperty(TmfCommonConstants.TRACETYPE);
-        } catch (CoreException e) {
-            Activator.getDefault().logError("Error refreshing trace type pesistent property for trace " + getName(), e); //$NON-NLS-1$
-        }
-    }
 
     /**
      * Instantiate a <code>ITmfTrace</code> object based on the trace type and
@@ -213,28 +194,29 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      *
      * @return the <code>ITmfTrace</code> or <code>null</code> for an error
      */
+    @Override
     public ITmfTrace instantiateTrace() {
         try {
 
             // make sure that supplementary folder exists
             refreshSupplementaryFolder();
 
-            if (fTraceTypeId != null) {
-                if (fTraceTypeId.startsWith(CustomTxtTrace.class.getCanonicalName())) {
+            if (getTraceType() != null) {
+                if (getTraceType().startsWith(CustomTxtTrace.class.getCanonicalName())) {
                     for (CustomTxtTraceDefinition def : CustomTxtTraceDefinition.loadAll()) {
-                        if (fTraceTypeId.equals(CustomTxtTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
+                        if (getTraceType().equals(CustomTxtTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
                             return new CustomTxtTrace(def);
                         }
                     }
                 }
-                if (fTraceTypeId.startsWith(CustomXmlTrace.class.getCanonicalName())) {
+                if (getTraceType().startsWith(CustomXmlTrace.class.getCanonicalName())) {
                     for (CustomXmlTraceDefinition def : CustomXmlTraceDefinition.loadAll()) {
-                        if (fTraceTypeId.equals(CustomXmlTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
+                        if (getTraceType().equals(CustomXmlTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
                             return new CustomXmlTrace(def);
                         }
                     }
                 }
-                IConfigurationElement ce = sfTraceTypeAttributes.get(fTraceTypeId);
+                IConfigurationElement ce = sfTraceTypeAttributes.get(getTraceType());
                 if (ce == null) {
                     return null;
                 }
@@ -255,22 +237,22 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      */
     public ITmfEvent instantiateEvent() {
         try {
-            if (fTraceTypeId != null) {
-                if (fTraceTypeId.startsWith(CustomTxtTrace.class.getCanonicalName())) {
+            if (getTraceType() != null) {
+                if (getTraceType().startsWith(CustomTxtTrace.class.getCanonicalName())) {
                     for (CustomTxtTraceDefinition def : CustomTxtTraceDefinition.loadAll()) {
-                        if (fTraceTypeId.equals(CustomTxtTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
+                        if (getTraceType().equals(CustomTxtTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
                             return new CustomTxtEvent(def);
                         }
                     }
                 }
-                if (fTraceTypeId.startsWith(CustomXmlTrace.class.getCanonicalName())) {
+                if (getTraceType().startsWith(CustomXmlTrace.class.getCanonicalName())) {
                     for (CustomXmlTraceDefinition def : CustomXmlTraceDefinition.loadAll()) {
-                        if (fTraceTypeId.equals(CustomXmlTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
+                        if (getTraceType().equals(CustomXmlTrace.class.getCanonicalName() + ":" + def.definitionName)) { //$NON-NLS-1$
                             return new CustomXmlEvent(def);
                         }
                     }
                 }
-                IConfigurationElement ce = sfTraceTypeAttributes.get(fTraceTypeId);
+                IConfigurationElement ce = sfTraceTypeAttributes.get(getTraceType());
                 if (ce == null) {
                     return null;
                 }
@@ -283,21 +265,21 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         return null;
     }
 
-    /**
-     * Returns the optional editor ID from the trace type extension.
-     *
-     * @return the editor ID or <code>null</code> if not defined.
-     */
+    @Override
     public String getEditorId() {
-        if (fTraceTypeId != null) {
-            if (fTraceTypeId.startsWith(CustomTxtTrace.class.getCanonicalName())) {
+        if (getTraceType() != null) {
+            if (getTraceType().startsWith(CustomTxtTrace.class.getCanonicalName())) {
                 return TmfEventsEditor.ID;
             }
-            if (fTraceTypeId.startsWith(CustomXmlTrace.class.getCanonicalName())) {
+            if (getTraceType().startsWith(CustomXmlTrace.class.getCanonicalName())) {
                 return TmfEventsEditor.ID;
             }
-            IConfigurationElement ce = sfTraceTypeAttributes.get(fTraceTypeId);
-            IConfigurationElement[] defaultEditorCE = ce.getChildren(TmfTraceType.DEFAULT_EDITOR_ELEM);
+            IConfigurationElement ce = sfTraceTypeUIAttributes.get(getTraceType());
+            if (ce == null) {
+                /* This trace type does not define UI attributes */
+                return null;
+            }
+            IConfigurationElement[] defaultEditorCE = ce.getChildren(TmfTraceTypeUIUtils.DEFAULT_EDITOR_ELEM);
             if (defaultEditorCE.length == 1) {
                 return defaultEditorCE[0].getAttribute(TmfTraceType.ID_ATTR);
             }
@@ -316,20 +298,11 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      *             if the bookmarks file cannot be created
      * @since 2.0
      */
+    @Override
     public IFile createBookmarksFile() throws CoreException {
         IFile file = getBookmarksFile();
         if (fResource instanceof IFolder) {
-            if (!file.exists()) {
-                final IFile bookmarksFile = getProject().getTracesFolder().getResource().getFile(BOOKMARKS_HIDDEN_FILE);
-                if (!bookmarksFile.exists()) {
-                    final InputStream source = new ByteArrayInputStream(new byte[0]);
-                    bookmarksFile.create(source, true, null);
-                }
-                bookmarksFile.setHidden(true);
-                file.createLink(bookmarksFile.getLocation(), IResource.REPLACE, null);
-                file.setHidden(true);
-                file.setPersistentProperty(TmfCommonConstants.TRACETYPE, TmfTrace.class.getCanonicalName());
-            }
+            return createBookmarksFile(getProject().getTracesFolder().getResource(), TmfTrace.class.getCanonicalName());
         }
         return file;
     }
@@ -341,6 +314,7 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      * @return the bookmarks file
      * @since 2.0
      */
+    @Override
     public IFile getBookmarksFile() {
         IFile file = null;
         if (fResource instanceof IFile) {
@@ -367,7 +341,7 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         // traces folder
         if (getParent() instanceof TmfExperimentElement) {
             for (TmfTraceElement aTrace : getProject().getTracesFolder().getTraces()) {
-                if (aTrace.getName().equals(getName())) {
+                if (aTrace.getElementPath().equals(getElementPath())) {
                     return aTrace;
                 }
             }
@@ -375,6 +349,11 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         return this;
     }
 
+    @Override
+    public String getTypeName() {
+        return Messages.TmfTraceElement_TypeName;
+    }
+
     // ------------------------------------------------------------------------
     // IActionFilter
     // ------------------------------------------------------------------------
@@ -388,26 +367,6 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         return false;
     }
 
-    // ------------------------------------------------------------------------
-    // TmfTraceElement
-    // ------------------------------------------------------------------------
-
-    @Override
-    public TmfProjectElement getProject() {
-        if (getParent() instanceof TmfTraceFolder) {
-            TmfTraceFolder folder = (TmfTraceFolder) getParent();
-            TmfProjectElement project = (TmfProjectElement) folder.getParent();
-            return project;
-        }
-        if (getParent() instanceof TmfExperimentElement) {
-            TmfExperimentElement experiment = (TmfExperimentElement) getParent();
-            TmfExperimentFolder folder = (TmfExperimentFolder) experiment.getParent();
-            TmfProjectElement project = (TmfProjectElement) folder.getParent();
-            return project;
-        }
-        return null;
-    }
-
     // ------------------------------------------------------------------------
     // IPropertySource2
     // ------------------------------------------------------------------------
@@ -427,7 +386,7 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
     private Map<String, String> getTraceProperties() {
         for (ITmfTrace openedTrace : TmfTraceManager.getInstance().getOpenedTraces()) {
             for (ITmfTrace singleTrace : TmfTraceManager.getTraceSet(openedTrace)) {
-                if (this.getLocation().toString().endsWith(singleTrace.getPath())) {
+                if (this.getLocation().getPath().endsWith(singleTrace.getPath())) {
                     if (singleTrace instanceof ITmfTraceProperties) {
                         ITmfTraceProperties traceProperties = (ITmfTraceProperties) singleTrace;
                         return traceProperties.getTraceProperties();
@@ -435,7 +394,7 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
                 }
             }
         }
-        return new HashMap<String, String>();
+        return new HashMap<>();
     }
 
     @Override
@@ -471,24 +430,38 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         }
 
         if (sfLocation.equals(id)) {
-            return getLocation().toString();
+            return URIUtil.toUnencodedString(getLocation());
         }
 
         if (sfIsLinked.equals(id)) {
             return Boolean.valueOf(getResource().isLinked()).toString();
         }
 
-        if (sfEventType.equals(id)) {
-            if (fTraceTypeId != null) {
-                IConfigurationElement ce = sfTraceTypeAttributes.get(fTraceTypeId);
-                return (ce != null) ? (getCategory(ce) + " : " + ce.getAttribute(TmfTraceType.NAME_ATTR)) : ""; //$NON-NLS-1$ //$NON-NLS-2$
+        if (sfSourceLocation.equals(id)) {
+            try {
+                String sourceLocation = getElementUnderTraceFolder().getResource().getPersistentProperty(TmfCommonConstants.SOURCE_LOCATION);
+                if (sourceLocation != null) {
+                    return sourceLocation;
+                }
+            } catch (CoreException e) {
             }
+            return ""; //$NON-NLS-1$
+        }
+
+        if (sfTraceType.equals(id)) {
+            if (getTraceType() != null) {
+                TraceTypeHelper helper = TmfTraceType.getTraceTypeHelper(getTraceType());
+                if (helper != null) {
+                    return helper.getCategoryName() + " : " + helper.getName(); //$NON-NLS-1$
+                }
+            }
+            return ""; //$NON-NLS-1$
         }
 
         Map<String, String> traceProperties = getTraceProperties();
         if (id != null && !traceProperties.isEmpty()) {
             String key = (String) id;
-            key = key.replaceFirst(this.getName() + "_", ""); //$NON-NLS-1$ //$NON-NLS-2$
+            key = key.substring(this.getName().length() + 1); // remove name_
             String value = traceProperties.get(key);
             return value;
         }
@@ -496,17 +469,6 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         return null;
     }
 
-    private static String getCategory(IConfigurationElement ce) {
-        String categoryId = ce.getAttribute(TmfTraceType.CATEGORY_ATTR);
-        if (categoryId != null) {
-            IConfigurationElement category = sfTraceCategories.get(categoryId);
-            if (category != null) {
-                return category.getAttribute(TmfTraceType.NAME_ATTR);
-            }
-        }
-        return "[no category]"; //$NON-NLS-1$
-    }
-
     @Override
     public void resetPropertyValue(Object id) {
     }
@@ -529,15 +491,20 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      * Copy this trace in the trace folder. No other parameters are mentioned so
      * the trace is copied in this element's project trace folder
      *
-     * @param string
+     * @param newName
      *            The new trace name
      * @return the new Resource object
      * @since 2.0
      */
-    public TmfTraceElement copy(String string) {
-        TmfTraceFolder folder = this.getProject().getTracesFolder();
-        IResource res = super.copy(string, false);
-        return new TmfTraceElement(string, res, folder);
+    public TmfTraceElement copy(String newName) {
+        TmfTraceFolder folder = (TmfTraceFolder) getParent();
+        IResource res = super.copy(newName, false);
+        for (TmfTraceElement trace : folder.getTraces()) {
+            if (trace.getResource().equals(res)) {
+                return trace;
+            }
+        }
+        return null;
     }
 
     /**
@@ -545,32 +512,17 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
      *
      * @since 2.0
      */
+    @Override
     public void closeEditors() {
-        // Close the trace if open
-        IFile file = getBookmarksFile();
-        FileEditorInput input = new FileEditorInput(file);
-        IWorkbench wb = PlatformUI.getWorkbench();
-        for (IWorkbenchWindow wbWindow : wb.getWorkbenchWindows()) {
-            for (IWorkbenchPage wbPage : wbWindow.getPages()) {
-                for (IEditorReference editorReference : wbPage.getEditorReferences()) {
-                    try {
-                        if (editorReference.getEditorInput().equals(input)) {
-                            wbPage.closeEditor(editorReference.getEditor(false), false);
-                        }
-                    } catch (PartInitException e) {
-                        Activator.getDefault().logError("Error closing editor for trace " + getName(), e); //$NON-NLS-1$
-                    }
-                }
-            }
-        }
+        super.closeEditors();
 
         // Close experiments that contain the trace if open
         if (getParent() instanceof TmfTraceFolder) {
-            TmfExperimentFolder experimentFolder = getProject().getExperimentsFolder();
-            for (ITmfProjectModelElement experiment : experimentFolder.getChildren()) {
-                for (ITmfProjectModelElement child : experiment.getChildren()) {
-                    if (child.getName().equals(getName())) {
-                        ((TmfExperimentElement) experiment).closeEditors();
+            TmfExperimentFolder experimentsFolder = getProject().getExperimentsFolder();
+            for (TmfExperimentElement experiment : experimentsFolder.getExperiments()) {
+                for (TmfTraceElement trace : experiment.getTraces()) {
+                    if (trace.getElementPath().equals(getElementPath())) {
+                        experiment.closeEditors();
                         break;
                     }
                 }
@@ -579,6 +531,13 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
             TmfExperimentElement experiment = (TmfExperimentElement) getParent();
             experiment.closeEditors();
         }
+
+        /*
+         * We will be closing a trace shortly. Invoke GC to release
+         * MappedByteBuffer objects, which some trace types, like CTF, use.
+         * (see Java bug JDK-4724038)
+         */
+        System.gc();
     }
 
     /**
@@ -597,42 +556,34 @@ public class TmfTraceElement extends TmfWithFolderElement implements IActionFilt
         closeEditors();
 
         IPath path = fResource.getLocation();
-        if (path != null && (getParent() instanceof TmfTraceFolder)) {
-            TmfExperimentFolder experimentFolder = getProject().getExperimentsFolder();
+        if (path != null) {
+            if (getParent() instanceof TmfTraceFolder) {
+                TmfExperimentFolder experimentFolder = getProject().getExperimentsFolder();
 
-            // Propagate the removal to traces
-            for (ITmfProjectModelElement experiment : experimentFolder.getChildren()) {
-                List<ITmfProjectModelElement> toRemove = new LinkedList<ITmfProjectModelElement>();
-                for (ITmfProjectModelElement child : experiment.getChildren()) {
-                    if (child.getName().equals(getName())) {
-                        toRemove.add(child);
+                // Propagate the removal to traces
+                for (TmfExperimentElement experiment : experimentFolder.getExperiments()) {
+                    List<TmfTraceElement> toRemove = new LinkedList<>();
+                    for (TmfTraceElement trace : experiment.getTraces()) {
+                        if (trace.getElementPath().equals(getElementPath())) {
+                            toRemove.add(trace);
+                        }
+                    }
+                    for (TmfTraceElement child : toRemove) {
+                        experiment.removeTrace(child);
                     }
                 }
-                for (ITmfProjectModelElement child : toRemove) {
-                    ((TmfExperimentElement) experiment).removeTrace((TmfTraceElement) child);
-                }
-            }
 
-            // Delete supplementary files
-            deleteSupplementaryFolder();
+                // Delete supplementary files
+                deleteSupplementaryFolder();
+
+            } else if (getParent() instanceof TmfExperimentElement) {
+                TmfExperimentElement experimentElement = (TmfExperimentElement) getParent();
+                experimentElement.removeTrace(this);
+            }
         }
 
         // Finally, delete the trace
         fResource.delete(true, progressMonitor);
     }
 
-    /**
-     * Get the instantiated trace associated with this element.
-     *
-     * @return The instantiated trace or null if trace is not (yet) available
-     * @since 2.1
-     */
-    public ITmfTrace getTrace() {
-        for (ITmfTrace trace : TmfTraceManager.getInstance().getOpenedTraces()) {
-            if (trace.getResource().equals(getResource())) {
-                return trace;
-            }
-        }
-        return null;
-    }
 }
