@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011, 2013 Ericsson
+ * Copyright (c) 2011, 2014 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -32,7 +32,6 @@ import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.linuxtools.internal.tmf.ui.Activator;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfExperimentElement;
 import org.eclipse.linuxtools.tmf.ui.project.model.TmfExperimentFolder;
-import org.eclipse.linuxtools.tmf.ui.project.model.TmfProjectElement;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.layout.GridData;
@@ -64,7 +63,6 @@ public class RenameExperimentDialog extends SelectionStatusDialog {
     private final TmfExperimentElement fExperiment;
     private Text fNewExperimentName;
     private final IContainer fExperimentFolder;
-    private final TmfProjectElement fProject;
 
     // ------------------------------------------------------------------------
     // Constructor
@@ -83,7 +81,6 @@ public class RenameExperimentDialog extends SelectionStatusDialog {
         fExperiment = experiment;
         TmfExperimentFolder folder = (TmfExperimentFolder) experiment.getParent();
         fExperimentFolder = folder.getResource();
-        fProject = experiment.getProject();
         setTitle(Messages.RenameExperimentDialog_DialogTitle);
         setStatusLineAboveButtons(true);
     }
@@ -190,10 +187,6 @@ public class RenameExperimentDialog extends SelectionStatusDialog {
         }
         setSelectionResult(new IFolder[] { folder });
         super.okPressed();
-
-        if (fProject != null) {
-            fProject.refresh();
-        }
     }
 
     private IFolder renameExperiment(final String newName) {
