@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010 Ericsson
+ * Copyright (c) 2010, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -26,5 +26,5 @@ public interface IColorSettingsListener {
      * @param colorSettings
      *            The new color settings
      */
-    public void colorSettingsChanged(ColorSetting[] colorSettings);
+    void colorSettingsChanged(ColorSetting[] colorSettings);
 }
