@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2013 Ericsson
+ * Copyright (c) 2010, 2014 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -8,6 +8,8 @@
  *
  * Contributors:
  *   Patrick Tasse - Initial API and implementation
+ *   Xavier Raynaud - add cut/copy/paste/dnd support
+ *   Vincent Perot - Add subfield filtering
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.ui.views.filter;
@@ -24,6 +26,7 @@ import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
+import org.eclipse.jface.util.LocalSelectionTransfer;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
@@ -31,11 +34,6 @@ import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.linuxtools.internal.tmf.ui.Messages;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTraceDefinition.OutputColumn;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtEvent;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomTxtTraceDefinition;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlEvent;
-import org.eclipse.linuxtools.internal.tmf.ui.parsers.custom.CustomXmlTraceDefinition;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEvent;
 import org.eclipse.linuxtools.tmf.core.event.ITmfEventType;
 import org.eclipse.linuxtools.tmf.core.filter.model.ITmfFilterTreeNode;
@@ -50,9 +48,18 @@ import org.eclipse.linuxtools.tmf.core.filter.model.TmfFilterNode;
 import org.eclipse.linuxtools.tmf.core.filter.model.TmfFilterOrNode;
 import org.eclipse.linuxtools.tmf.core.filter.model.TmfFilterRootNode;
 import org.eclipse.linuxtools.tmf.core.filter.model.TmfFilterTreeNode;
-import org.eclipse.linuxtools.tmf.ui.project.model.TmfTraceType;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTraceDefinition.OutputColumn;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTxtEvent;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomTxtTraceDefinition;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlEvent;
+import org.eclipse.linuxtools.tmf.core.parsers.custom.CustomXmlTraceDefinition;
+import org.eclipse.linuxtools.tmf.core.project.model.TmfTraceType;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.SashForm;
+import org.eclipse.swt.dnd.DND;
+import org.eclipse.swt.dnd.DragSource;
+import org.eclipse.swt.dnd.DropTarget;
+import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
 import org.eclipse.swt.events.ModifyEvent;
@@ -76,11 +83,10 @@ import org.eclipse.swt.widgets.TreeItem;
 
 class FilterViewer extends Composite {
 
-    private static final String CUSTOM_TXT_CATEGORY = "Custom Text"; //$NON-NLS-1$
-    private static final String CUSTOM_XML_CATEGORY = "Custom XML"; //$NON-NLS-1$
-
     private TreeViewer fViewer;
+
     private Composite fComposite;
+    private MenuManager fMenuManager;
 
     public FilterViewer(Composite parent, int style) {
         super(parent, style);
@@ -132,6 +138,14 @@ class FilterViewer extends Composite {
                 }
             }
         });
+
+        int operations = DND.DROP_MOVE | DND.DROP_COPY;
+        DragSource dragSource = new org.eclipse.swt.dnd.DragSource(fViewer.getTree(), operations);
+        dragSource.setTransfer(new Transfer[] { LocalSelectionTransfer.getTransfer() });
+        dragSource.addDragListener(new FilterDragSourceAdapter(this));
+        DropTarget dropTarget = new DropTarget(fViewer.getTree(), operations);
+        dropTarget.setTransfer(new Transfer[] { LocalSelectionTransfer.getTransfer() });
+        dropTarget.addDropListener(new FilterDropTargetAdapter(this));
     }
 
     /**
@@ -139,9 +153,9 @@ class FilterViewer extends Composite {
      */
     private void createContextMenu() {
         // Adds root context menu
-        MenuManager menuManager = new MenuManager();
-        menuManager.setRemoveAllWhenShown(true);
-        menuManager.addMenuListener(new IMenuListener() {
+        fMenuManager = new MenuManager();
+        fMenuManager.setRemoveAllWhenShown(true);
+        fMenuManager.addMenuListener(new IMenuListener() {
             @Override
             public void menuAboutToShow(IMenuManager manager) {
                 fillContextMenu(manager);
@@ -149,12 +163,16 @@ class FilterViewer extends Composite {
         });
 
         // Context
-        Menu contextMenu = menuManager.createContextMenu(fViewer.getTree());
+        Menu contextMenu = fMenuManager.createContextMenu(fViewer.getTree());
 
         // Publish it
         fViewer.getTree().setMenu(contextMenu);
     }
 
+    public MenuManager getMenuManager() {
+        return fMenuManager;
+    }
+
     /**
      * Fill the context menu for the tree viewer.
      *
@@ -171,32 +189,15 @@ class FilterViewer extends Composite {
             }
         }
 
-        final ITmfFilterTreeNode selectedNode = filterTreeNode;
-
-        if (selectedNode != null) {
-
-            fillContextMenuForNode(selectedNode, manager);
-
-            if (selectedNode.getValidChildren().size() > 0) {
-                manager.add(new Separator());
-            }
-
-            Action deleteAction = new Action() {
-                @Override
-                public void run() {
-                    selectedNode.remove();
-                    fViewer.refresh();
-                }
-            };
-            deleteAction.setText(Messages.FilterViewer_DeleteActionText);
-            manager.add(deleteAction);
-
-            manager.add(new Separator());
+        if (filterTreeNode != null) {
+            fillContextMenuForNode(filterTreeNode, manager);
         }
+        manager.add(new Separator("delete")); //$NON-NLS-1$
+        manager.add(new Separator("edit")); //$NON-NLS-1$
 
-        if (fViewer.getInput() instanceof TmfFilterRootNode || selectedNode == null) {
-            final ITmfFilterTreeNode root = (ITmfFilterTreeNode) fViewer.getInput();
-
+        if (fViewer.getInput() instanceof TmfFilterRootNode || filterTreeNode == null) {
+            manager.add(new Separator());
+            ITmfFilterTreeNode root = (ITmfFilterTreeNode) fViewer.getInput();
             fillContextMenuForNode(root, manager);
         }
     }
@@ -343,6 +344,15 @@ class FilterViewer extends Composite {
         fViewer.removeSelectionChangedListener(listener);
     }
 
+    /**
+     * Gets the TreeViewer displaying filters
+     *
+     * @return a {@link TreeViewer}
+     */
+    TreeViewer getTreeViewer() {
+        return fViewer;
+    }
+
     private class FilterBaseNodeComposite extends Composite {
 
         FilterBaseNodeComposite(Composite parent) {
@@ -353,7 +363,7 @@ class FilterViewer extends Composite {
         }
 
         protected String[] getFieldsList(ITmfFilterTreeNode node) {
-            ArrayList<String> fieldsList = new ArrayList<String>();
+            ArrayList<String> fieldsList = new ArrayList<>();
             ITmfFilterTreeNode curNode = node;
             while (curNode != null) {
                 if (curNode instanceof TmfFilterEventTypeNode) {
@@ -416,9 +426,14 @@ class FilterViewer extends Composite {
                 try {
                     ITmfEvent event = (ITmfEvent) ce.createExecutableExtension(TmfTraceType.EVENT_TYPE_ATTR);
                     ITmfEventType eventType = event.getType();
-                    if (eventType != null && eventType.getFieldNames().length > 0) {
-                        fieldsList.add("[" + TmfTraceType.getCategoryName(ce.getAttribute(TmfTraceType.CATEGORY_ATTR)) + //$NON-NLS-1$
-                                " : " + ce.getAttribute(TmfTraceType.NAME_ATTR) + "]"); //$NON-NLS-1$ //$NON-NLS-2$
+                    if (eventType != null && eventType.getFieldNames().size() > 0) {
+                        String categoryId = ce.getAttribute(TmfTraceType.CATEGORY_ATTR);
+                        if (categoryId != null) {
+                            fieldsList.add('[' + TmfTraceType.getCategoryName(categoryId) + " : " //$NON-NLS-1$
+                                    + ce.getAttribute(TmfTraceType.NAME_ATTR) + ']');
+                        } else {
+                            fieldsList.add('[' + ce.getAttribute(TmfTraceType.NAME_ATTR) + ']');
+                        }
                         for (String field : eventType.getFieldNames()) {
                             fieldsList.add(field);
                         }
@@ -429,7 +444,7 @@ class FilterViewer extends Composite {
             }
             for (CustomTxtTraceDefinition def : CustomTxtTraceDefinition.loadAll()) {
                 if (def.outputs.size() > 0) {
-                    fieldsList.add("[" + CUSTOM_TXT_CATEGORY + //$NON-NLS-1$
+                    fieldsList.add("[" + TmfTraceType.CUSTOM_TXT_CATEGORY + //$NON-NLS-1$
                             " : " + def.definitionName + "]"); //$NON-NLS-1$ //$NON-NLS-2$
                     for (OutputColumn output : def.outputs) {
                         fieldsList.add(output.name);
@@ -439,7 +454,7 @@ class FilterViewer extends Composite {
             }
             for (CustomXmlTraceDefinition def : CustomXmlTraceDefinition.loadAll()) {
                 if (def.outputs.size() > 0) {
-                    fieldsList.add("[" + CUSTOM_XML_CATEGORY + //$NON-NLS-1$
+                    fieldsList.add("[" + TmfTraceType.CUSTOM_XML_CATEGORY + //$NON-NLS-1$
                             " : " + def.definitionName + "]"); //$NON-NLS-1$ //$NON-NLS-2$
                     for (OutputColumn output : def.outputs) {
                         fieldsList.add(output.name);
@@ -479,6 +494,7 @@ class FilterViewer extends Composite {
                         fNameText.setText(Messages.FilterViewer_FilterNameHint);
                     }
                 }
+
                 @Override
                 public void focusGained(FocusEvent e) {
                     if (fNameText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
@@ -490,7 +506,7 @@ class FilterViewer extends Composite {
             fNameText.addModifyListener(new ModifyListener() {
                 @Override
                 public void modifyText(ModifyEvent e) {
-                    if (! fNameText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
+                    if (!fNameText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
                         fNode.setFilterName(fNameText.getText());
                         fViewer.refresh(fNode);
                     }
@@ -517,7 +533,7 @@ class FilterViewer extends Composite {
             fTypeCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
             fTypeCombo.setItems(fEventsTypeMap.keySet().toArray(new String[0]));
             if (fNode.getEventType() != null) {
-                for (Entry <String, Object> eventTypeEntry : fEventsTypeMap.entrySet()) {
+                for (Entry<String, Object> eventTypeEntry : fEventsTypeMap.entrySet()) {
                     Object value = eventTypeEntry.getValue();
                     if (value instanceof IConfigurationElement) {
                         IConfigurationElement ce = (IConfigurationElement) value;
@@ -542,7 +558,7 @@ class FilterViewer extends Composite {
             fTypeCombo.addModifyListener(new ModifyListener() {
                 @Override
                 public void modifyText(ModifyEvent e) {
-                    for (Entry <String, Object> eventTypeEntry : fEventsTypeMap.entrySet()) {
+                    for (Entry<String, Object> eventTypeEntry : fEventsTypeMap.entrySet()) {
                         if (eventTypeEntry.getKey().equals(fTypeCombo.getText())) {
                             Object value = eventTypeEntry.getValue();
                             if (value instanceof IConfigurationElement) {
@@ -567,18 +583,22 @@ class FilterViewer extends Composite {
         }
 
         protected Map<String, Object> getEventsTypeMap() {
-            Map<String, Object> eventsTypeMap = new LinkedHashMap<String, Object>();
+            Map<String, Object> eventsTypeMap = new LinkedHashMap<>();
             for (IConfigurationElement ce : TmfTraceType.getTypeElements()) {
-                String categoryName = TmfTraceType.getCategoryName(ce.getAttribute(TmfTraceType.CATEGORY_ATTR));
-                String text = categoryName + " : " + ce.getAttribute(TmfTraceType.NAME_ATTR); //$NON-NLS-1$
+                String categoryPrefix = ""; //$NON-NLS-1$
+                String categoryId = ce.getAttribute(TmfTraceType.CATEGORY_ATTR);
+                if (categoryId != null) {
+                    categoryPrefix = TmfTraceType.getCategoryName(categoryId) + " : "; //$NON-NLS-1$
+                }
+                String text = categoryPrefix + ce.getAttribute(TmfTraceType.NAME_ATTR);
                 eventsTypeMap.put(text, ce);
             }
             for (CustomTxtTraceDefinition def : CustomTxtTraceDefinition.loadAll()) {
-                String text = CUSTOM_TXT_CATEGORY + " : " + def.definitionName; //$NON-NLS-1$
+                String text = TmfTraceType.CUSTOM_TXT_CATEGORY + " : " + def.definitionName; //$NON-NLS-1$
                 eventsTypeMap.put(text, def);
             }
             for (CustomXmlTraceDefinition def : CustomXmlTraceDefinition.loadAll()) {
-                String text = CUSTOM_XML_CATEGORY + " : " + def.definitionName; //$NON-NLS-1$
+                String text = TmfTraceType.CUSTOM_XML_CATEGORY + " : " + def.definitionName; //$NON-NLS-1$
                 eventsTypeMap.put(text, def);
             }
             return eventsTypeMap;
@@ -668,6 +688,7 @@ class FilterViewer extends Composite {
             fFieldCombo = new Combo(this, SWT.DROP_DOWN);
             fFieldCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
             fFieldCombo.setItems(getFieldsList(fNode));
+            fFieldCombo.setToolTipText(Messages.FilterViewer_Subfilter_ToolTip);
             if (fNode.getField() != null) {
                 fFieldCombo.setText(fNode.getField());
             }
@@ -699,6 +720,7 @@ class FilterViewer extends Composite {
                         fValueText.setText(Messages.FilterViewer_ValueHint);
                     }
                 }
+
                 @Override
                 public void focusGained(FocusEvent e) {
                     if (fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
@@ -710,7 +732,7 @@ class FilterViewer extends Composite {
             fValueText.addModifyListener(new ModifyListener() {
                 @Override
                 public void modifyText(ModifyEvent e) {
-                    if (! fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
+                    if (!fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
                         fNode.setValue(fValueText.getText());
                         fViewer.refresh(fNode);
                     }
@@ -767,6 +789,7 @@ class FilterViewer extends Composite {
             fFieldCombo = new Combo(this, SWT.DROP_DOWN);
             fFieldCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
             fFieldCombo.setItems(getFieldsList(fNode));
+            fFieldCombo.setToolTipText(Messages.FilterViewer_Subfilter_ToolTip);
             if (fNode.getField() != null) {
                 fFieldCombo.setText(fNode.getField());
             }
@@ -798,6 +821,7 @@ class FilterViewer extends Composite {
                         fValueText.setText(Messages.FilterViewer_ValueHint);
                     }
                 }
+
                 @Override
                 public void focusGained(FocusEvent e) {
                     if (fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
@@ -809,7 +833,7 @@ class FilterViewer extends Composite {
             fValueText.addModifyListener(new ModifyListener() {
                 @Override
                 public void modifyText(ModifyEvent e) {
-                    if (! fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
+                    if (!fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
                         fNode.setValue(fValueText.getText());
                         fViewer.refresh(fNode);
                     }
@@ -865,6 +889,7 @@ class FilterViewer extends Composite {
             fFieldCombo = new Combo(this, SWT.DROP_DOWN);
             fFieldCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
             fFieldCombo.setItems(getFieldsList(fNode));
+            fFieldCombo.setToolTipText(Messages.FilterViewer_Subfilter_ToolTip);
             if (fNode.getField() != null) {
                 fFieldCombo.setText(fNode.getField());
             }
@@ -896,6 +921,7 @@ class FilterViewer extends Composite {
                         fRegexText.setText(Messages.FilterViewer_RegexHint);
                     }
                 }
+
                 @Override
                 public void focusGained(FocusEvent e) {
                     if (fRegexText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
@@ -907,7 +933,7 @@ class FilterViewer extends Composite {
             fRegexText.addModifyListener(new ModifyListener() {
                 @Override
                 public void modifyText(ModifyEvent e) {
-                    if (! fRegexText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
+                    if (!fRegexText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
                         fNode.setRegex(fRegexText.getText());
                         fViewer.refresh(fNode);
                     }
@@ -954,6 +980,7 @@ class FilterViewer extends Composite {
             fFieldCombo = new Combo(this, SWT.DROP_DOWN);
             fFieldCombo.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
             fFieldCombo.setItems(getFieldsList(fNode));
+            fFieldCombo.setToolTipText(Messages.FilterViewer_Subfilter_ToolTip);
             if (fNode.getField() != null) {
                 fFieldCombo.setText(fNode.getField());
             }
@@ -1091,6 +1118,7 @@ class FilterViewer extends Composite {
                         fValueText.setText(Messages.FilterViewer_ValueHint);
                     }
                 }
+
                 @Override
                 public void focusGained(FocusEvent e) {
                     if (fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
@@ -1102,7 +1130,7 @@ class FilterViewer extends Composite {
             fValueText.addModifyListener(new ModifyListener() {
                 @Override
                 public void modifyText(ModifyEvent e) {
-                    if (! fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
+                    if (!fValueText.getForeground().equals(Display.getCurrent().getSystemColor(SWT.COLOR_GRAY))) {
                         fNode.setValue(fValueText.getText());
                         fViewer.refresh(fNode);
                     }
