@@ -18,7 +18,6 @@ package org.eclipse.linuxtools.tmf.ui.views.histogram;
 import java.text.ParseException;
 
 import org.eclipse.linuxtools.tmf.core.signal.TmfSignalHandler;
-import org.eclipse.linuxtools.tmf.core.signal.TmfSignalManager;
 import org.eclipse.linuxtools.tmf.core.signal.TmfTimestampFormatUpdateSignal;
 import org.eclipse.linuxtools.tmf.core.timestamp.ITmfTimestamp;
 import org.eclipse.linuxtools.tmf.core.timestamp.TmfTimeRange;
@@ -52,12 +51,6 @@ public class HistogramCurrentTimeControl extends HistogramTextControl {
             String label, long value)
     {
         super(parentView, parent, label, value);
-        TmfSignalManager.register(this);
-    }
-
-    @Override
-    public void dispose() {
-        TmfSignalManager.deregister(this);
     }
 
     // ------------------------------------------------------------------------
