@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011, 2012 Ericsson
+ * Copyright (c) 2011, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -7,7 +7,7 @@
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- *   Mathieu Denis      (mathieu.denis@polymtl.ca)  - Initial API and Implementation
+ *   Mathieu Denis <mathieu.denis@polymtl.ca> - Initial API and Implementation
  *******************************************************************************/
 
 package org.eclipse.linuxtools.tmf.ui.views.statistics;
@@ -17,31 +17,20 @@ import org.eclipse.osgi.util.NLS;
 /**
  * Messages file for statistics view strings.
  *
- * @version 1.0
+ * @version 2.0
  * @author Mathieu Denis
+ * @since 2.0
  */
 public class Messages extends NLS {
+
     private static final String BUNDLE_NAME = "org.eclipse.linuxtools.tmf.ui.views.statistics.messages"; //$NON-NLS-1$
+
     /**
-     * Level column name
+     * String for the global tab name
+     * @since 2.0
      */
-    public static String TmfStatisticsView_LevelColumn;
-    /**
-     * Level column tool tip.
-     */
-    public static String TmfStatisticsView_LevelColumnTip;
-    /**
-     * Number of events column name.
-     */
-    public static String TmfStatisticsView_NbEventsColumn;
-    /**
-     * Number of events column tool tip.
-     */
-    public static String TmfStatisticsView_NbEventsTip;
-    /**
-     * String for unknown trace name.
-     */
-    public static String TmfStatisticsView_UnknownTraceName;
+    public static String TmfStatisticsView_GlobalTabName;
+
     static {
         // initialize resource bundle
         NLS.initializeMessages(BUNDLE_NAME, Messages.class);
