@@ -258,7 +258,7 @@ public class SDWidget extends ScrollView implements SelectionListener,
     public SDWidget(Composite c, int s) {
         super(c, s | SWT.NO_BACKGROUND, true);
         setOverviewEnabled(true);
-        fSelectedNodeList = new ArrayList<GraphNode>();
+        fSelectedNodeList = new ArrayList<>();
         fSelProvider = new SDWidgetSelectionProvider();
         SDViewPref.getInstance().addPropertyChangeListener(this);
         fToolTip = new DiagramToolTip(getViewControl());
@@ -363,7 +363,7 @@ public class SDWidget extends ScrollView implements SelectionListener,
         fCollapaseCaretImg = Activator.getDefault().getImageFromPath(ITmfImageConstants.IMG_UI_ARROW_COLLAPSE_OBJ);
         fArrowUpCaretImg = Activator.getDefault().getImageFromPath(ITmfImageConstants.IMG_UI_ARROW_UP_OBJ);
 
-        fReorderList = new ArrayList<Lifeline[]>();
+        fReorderList = new ArrayList<>();
         getViewControl().addTraverseListener(new LocalTraverseListener());
 
         addTraverseListener(new LocalTraverseListener());
@@ -1405,7 +1405,7 @@ public class SDWidget extends ScrollView implements SelectionListener,
         }
         if (event.keyCode == SWT.SHIFT) {
             fShiftSelection = true;
-            fPrevList = new ArrayList<GraphNode>();
+            fPrevList = new ArrayList<>();
             fPrevList.addAll(getSelection());
         }
 
