@@ -1,22 +1,21 @@
 /**********************************************************************
- * Copyright (c) 2005, 2008 IBM Corporation and others.
- * Copyright (c) 2011, 2012 Ericsson.
- *
+ * Copyright (c) 2005, 2013 IBM Corporation, Ericsson
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- * IBM - Initial API and implementation
- * Bernd Hufmann - Updated for TMF
+ *     IBM - Initial API and implementation
+ *     Bernd Hufmann - Updated for TMF
  **********************************************************************/
+
 package org.eclipse.linuxtools.tmf.ui.views.uml2sd;
 
 import java.util.Timer;
 import java.util.TimerTask;
 
-import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.SDMessages;
+import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.Messages;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.FocusEvent;
@@ -58,12 +57,10 @@ import org.eclipse.swt.widgets.Shell;
  * @version 1.0
  */
 public class ScrollView extends Composite {
-
     // ------------------------------------------------------------------------
-    // Attributes
+    // Constants
     // ------------------------------------------------------------------------
 
-    // Value for scroll bar mode, default is AUTO
     /**
      * Scroll bar mode AUTO
      */
@@ -84,104 +81,113 @@ public class ScrollView extends Composite {
      * Bit mask for visible horizontal scroll bar
      */
     public static final int HBAR = 0x02;
+
+    private static final int DEFAULT_H_SCROLL_INCREMENT = 10;
+    private static final int DEFAULT_V_SCROLL_INCREMENT = 10;
+    private static final int DEFAULT_AUTO_SCROLL_PERIOD = 75;
+    private static final int DEFAULT_OVERVIEW_SIZE = 100;
+
+    // ------------------------------------------------------------------------
+    // Attributes
+    // ------------------------------------------------------------------------
+
     /**
      * Value of the contents height property.
      */
-    protected int fContentsHeight = 0;
+    private int fContentsHeight = 0;
     /**
      * Value of the contents width property.
      */
-    protected int fContentsWidth = 0;
+    private int fContentsWidth = 0;
     /**
      * Value of the contents x coordinate property
      */
-    protected int fContentsX = 0;
+    private int fContentsX = 0;
     /**
      * Value of the contents y coordinate property
      */
-    protected int fContentsY = 0;
+    private int fContentsY = 0;
     /**
      * Scroll bar mode of horizontal scroll bar.
      */
-    protected int fHorScrollbarMode = AUTO;
+    private int fHorScrollbarMode = AUTO;
     /**
      * Scroll bar mode of vertical scroll bar.
      */
-    protected int fVertScrollbarMode = AUTO;
+    private int fVertScrollbarMode = AUTO;
     /**
      * Increment for the horizontal scroll bar.
      */
-    protected int fHorScrollbarIncrement = 10;
+    private int fHorScrollbarIncrement = DEFAULT_H_SCROLL_INCREMENT;
     /**
      * Increment for the vertical scroll bar.
      */
-    protected int fVertScrollbarIncrement = 10;
+    private int fVertScrollbarIncrement = DEFAULT_V_SCROLL_INCREMENT;
     /**
      * Flag whether auto scroll is enabled or not.
      */
-    protected boolean fAutoScrollEnabled = true;
+    private boolean fAutoScrollEnabled = true;
     /**
      * Value of the auto scroll period.
      */
-    protected int fAutoScrollPeriod = 75;
+    private int fAutoScrollPeriod = DEFAULT_AUTO_SCROLL_PERIOD;
     /**
      * The local paint listener reference.
      */
-    protected PaintListener fLocalPaintListener = null;
+    private PaintListener fLocalPaintListener = null;
     /**
      * The local mouse move listener reference.
      */
-    protected MouseMoveListener fLocalMouseMoveListener = null;
+    private MouseMoveListener fLocalMouseMoveListener = null;
     /**
      * The local mouse listener reference.
      */
-    protected MouseListener fLocalMouseListener = null;
+    private MouseListener fLocalMouseListener = null;
     /**
      * The local control listener reference.
      */
-    protected ControlListener fLocalControlListener = null;
+    private ControlListener fLocalControlListener = null;
     /**
      * The local key listener reference.
      */
-    protected KeyListener fLocalKeyListener = null;
+    private KeyListener fLocalKeyListener = null;
     // Canvas for vertical/horizontal Scroll Bar only ... because new ScrollBar() does works.
     /**
      * Canvas for horizontal scroll bar.
      */
-    protected Canvas fHorScrollBar;
+    private Canvas fHorScrollBar;
     /**
      * Canvas for vertical scroll bar.
      */
-    protected Canvas fVertScrollBar;
+    private Canvas fVertScrollBar;
     /**
      * Canvas for the view control.
      */
-    protected Canvas fViewControl;
+    private Canvas fViewControl;
     /**
      * Control used in the bottom right corner @see setCornerControl() and @see setOverviewEnabled(true)
      */
-    protected Control fCornerControl;
+    private Control fCornerControl;
     /**
      * Size of overview widget.
      */
-    protected int fOverviewSize = 100; // default size for overview
+    private int fOverviewSize = DEFAULT_OVERVIEW_SIZE; // default size for overview
     /**
      * Timer for auto_scroll feature
      */
-    protected AutoScroll fAutoScroll = null;
+    private AutoScroll fAutoScroll = null;
     /**
      * TimerTask for auto_scroll feature !=null when auto scroll is running
      */
-    protected Timer fAutoScrollTimer = null;
+    private Timer fAutoScrollTimer = null;
     /**
      * where mouse down appear on contents area (x coordinate)
      */
-    protected int fMouseDownX = -1;
+    private int fMouseDownX = -1;
     /**
      * where mouse down appear on contents area (y coordinate)
      */
-    protected int fMousDownY = -1;
-
+    private int fMousDownY = -1;
 
     // ------------------------------------------------------------------------
     // Constructors
@@ -207,7 +213,7 @@ public class ScrollView extends Composite {
      * @param mouseWheel Flag to force scrollView to handles mouse wheel
      */
     public ScrollView(Composite c, int style, boolean mouseWheel) {
-        super(c, SWT.NONE); // style&(~(SWT.H_SCROLL|SWT.V_SCROLL)));
+        super(c, SWT.NONE);
 
         fHorScrollBar = new Canvas(this, SWT.H_SCROLL);
         if (mouseWheel) {
@@ -223,10 +229,6 @@ public class ScrollView extends Composite {
             fViewControl.getHorizontalBar().setVisible(false);
         }
         fVertScrollBar = new Canvas(this, SWT.V_SCROLL);
-        // make fVerScrollBar able to receive mouse wheel
-        // does not help as we can't set a MouseListener on fVerScrollBar.getVerticalBar()
-        // to set focus on viewcontrol_
-        // fVerScrollBar.addKeyListener( new KeyAdapter() {});
 
         setLayout(new SVLayout());
 
@@ -305,8 +307,10 @@ public class ScrollView extends Composite {
             @Override
             public void mouseDown(MouseEvent e) {
                 int ox = e.x, oy = e.y;
-                e.x = fMouseDownX = viewToContentsX(e.x);
-                e.y = fMousDownY = viewToContentsY(e.y);
+                e.x = viewToContentsX(e.x);
+                fMouseDownX = e.x;
+                e.y = viewToContentsY(e.y);
+                fMousDownY = e.y;
                 contentsMouseDownEvent(e);
                 e.x = ox;
                 e.y = oy;
@@ -320,8 +324,9 @@ public class ScrollView extends Composite {
                 contentsMouseUpEvent(e);
                 e.x = ox;
                 e.y = oy;
-                // here because class extenting me can catch mouse Up and want to scroll...
-                fMouseDownX = fMousDownY = -1;
+                // here because class extending me can catch mouse Up and want to scroll...
+                fMouseDownX = -1;
+                fMousDownY = -1;
             }
         };
         fViewControl.addMouseListener(fLocalMouseListener);
@@ -408,30 +413,16 @@ public class ScrollView extends Composite {
     // Methods
     // ------------------------------------------------------------------------
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Composite#setFocus()
-     */
     @Override
     public boolean setFocus() {
         return fViewControl.forceFocus();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Control#setCursor(org.eclipse.swt.graphics.Cursor)
-     */
     @Override
     public void setCursor(Cursor cursor) {
         fViewControl.setCursor(cursor);
     }
 
-    /*
-     * Dispose controls used in scroll view
-     *
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Widget#dispose()
-     */
     @Override
     public void dispose() {
         if (fAutoScroll != null) {
@@ -461,29 +452,21 @@ public class ScrollView extends Composite {
         super.dispose();
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Composite#getClientArea()
-     */
     @Override
     public Rectangle getClientArea() {
-        return fViewControl.getClientArea();
+        Rectangle area = fViewControl.getClientArea();
+        /* Clamp the size of the returned area to 1x1 minimum */
+        area.width = Math.max(area.width, 1);
+        area.height = Math.max(area.height, 1);
+        return area;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Control#setBackground(org.eclipse.swt.graphics.Color)
-     */
     @Override
     public void setBackground(Color c) {
         super.setBackground(c);
         fViewControl.setBackground(c);
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Control#setToolTipText(java.lang.String)
-     */
     @Override
     public void setToolTipText(String text) {
         fViewControl.setToolTipText(text);
@@ -759,7 +742,7 @@ public class ScrollView extends Composite {
             ovr.useControl(b);
             b.setData(ovr);
             cc = b;
-            b.setToolTipText(SDMessages._78);
+            b.setToolTipText(Messages.SequenceDiagram_OpenOverviewTooltip);
         }
         setCornerControl(cc);
     }
@@ -813,14 +796,17 @@ public class ScrollView extends Composite {
      * Called when the mouse enter the ScrollView area
      *
      * @param e
+     *            Mouse event
      */
     protected void contentsMouseExit(MouseEvent e) {
     }
 
     /**
-     * Called when the mouse enter the ScrollView area after and system defined time
+     * Called when the mouse enter the ScrollView area after and system defined
+     * time
      *
      * @param e
+     *            Mouse event
      */
     protected void contentsMouseHover(MouseEvent e) {
     }
@@ -829,6 +815,7 @@ public class ScrollView extends Composite {
      * Called when the mouse enter the ScrollView area
      *
      * @param e
+     *            Mouse event
      */
     protected void contentsMouseEnter(MouseEvent e) {
     }
@@ -837,6 +824,7 @@ public class ScrollView extends Composite {
      * Called when user double on contents area.
      *
      * @param e
+     *            Mouse event
      */
     protected void contentsMouseDoubleClickEvent(MouseEvent e) {
     }
@@ -845,6 +833,7 @@ public class ScrollView extends Composite {
      * Called when mouse is on contents area and button is pressed.
      *
      * @param e
+     *            Mouse event
      */
     protected void contentsMouseDownEvent(MouseEvent e) {
         fMouseDownX = e.x;
@@ -855,10 +844,26 @@ public class ScrollView extends Composite {
      * TimerTask for auto scroll feature.
      */
     protected static class AutoScroll extends TimerTask {
-        public int deltaX;
-        public int deltaY;
-        public ScrollView scrollView;
 
+        /** X delta */
+        private int deltaX;
+
+        /** Y delta */
+        private int deltaY;
+
+        /** ScrollView object */
+        private ScrollView scrollView;
+
+        /**
+         * Constructor.
+         *
+         * @param sv
+         *            ScrollView object to use
+         * @param dx
+         *            X delta
+         * @param dy
+         *            Y delta
+         */
         public AutoScroll(ScrollView sv, int dx, int dy) {
             scrollView = sv;
             deltaX = dx;
@@ -867,10 +872,16 @@ public class ScrollView extends Composite {
 
         @Override
         public void run() {
-            Display.getDefault().asyncExec(new Runnable() {
+            final Display display = Display.getDefault();
+            if ((display == null) || display.isDisposed()) {
+                return;
+            }
+            display.asyncExec(new Runnable() {
                 @Override
                 public void run() {
-                    scrollView.scrollBy(deltaX, deltaY);
+                    if (!scrollView.isDisposed()) {
+                        scrollView.scrollBy(deltaX, deltaY);
+                    }
                 }
             });
         }
@@ -880,6 +891,7 @@ public class ScrollView extends Composite {
      * Called when mouse is on contents area and mode.
      *
      * @param event
+     *            Mouse event
      */
     protected void contentsMouseMoveEvent(MouseEvent event) {
         if ((event.stateMask & SWT.BUTTON_MASK) != 0) {
@@ -890,23 +902,23 @@ public class ScrollView extends Composite {
 
             int sx = 0, sy = 0;
 
-            int v_right = getContentsX() + getVisibleWidth();
-            int v_bottom = getContentsY() + getVisibleHeight();
+            int vRight = getContentsX() + getVisibleWidth();
+            int vBottom = getContentsY() + getVisibleHeight();
 
             // auto scroll... ?
             if (event.x < getContentsX()) {
                 sx = (getContentsX() - event.x);
                 fMouseDownX = getContentsX();
-            } else if (event.x > v_right) {
-                sx = -event.x + v_right;
-                fMouseDownX = v_right;
+            } else if (event.x > vRight) {
+                sx = -event.x + vRight;
+                fMouseDownX = vRight;
             }
             if (event.y < getContentsY()) {
                 sy = (getContentsY() - event.y);
                 fMousDownY = getContentsY();
-            } else if (event.y > v_bottom) {
-                sy = -event.y + v_bottom;
-                fMousDownY = v_bottom;
+            } else if (event.y > vBottom) {
+                sy = -event.y + vBottom;
+                fMousDownY = vBottom;
             }
 
             if (sx != 0 || sy != 0) {
@@ -936,6 +948,7 @@ public class ScrollView extends Composite {
      * Called when mouse is on contents area and button is released
      *
      * @param event
+     *            Mouse event
      */
     protected void contentsMouseUpEvent(MouseEvent event) {
         // reset auto scroll if it's engaged
@@ -946,14 +959,20 @@ public class ScrollView extends Composite {
     }
 
     /**
-     * Responsible to draw contents area. At least rectangle clipX must be redrawn. This rectangle is given in contents
-     * coordinates. By default, no paint is produced.
+     * Responsible to draw contents area. At least rectangle clipX must be
+     * redrawn. This rectangle is given in contents coordinates. By default, no
+     * paint is produced.
      *
      * @param gc
+     *            Graphics context
      * @param clipx
+     *            X clip
      * @param clipy
+     *            Y clip
      * @param clipw
+     *            W clip
      * @param cliph
+     *            H clip
      */
     protected void drawContents(GC gc, int clipx, int clipy, int clipw, int cliph) {
     }
@@ -991,13 +1010,13 @@ public class ScrollView extends Composite {
             oldW = s;
         }
 
-        int vis_width = getVisibleWidth();
-        int vis_height = getVisibleHeight();
-        if (oldW < vis_width) {
-            if (localWidth > vis_width) {
-                localWidth = vis_width;
+        int visWidth = getVisibleWidth();
+        int visHeight = getVisibleHeight();
+        if (oldW < visWidth) {
+            if (localWidth > visWidth) {
+                localWidth = visWidth;
             }
-            fViewControl.redraw(getContentsX() + oldW, 0, localWidth - oldW, vis_height, true);
+            fViewControl.redraw(getContentsX() + oldW, 0, localWidth - oldW, visHeight, true);
         }
 
         if (oldH > localHeight) {
@@ -1006,11 +1025,11 @@ public class ScrollView extends Composite {
             oldH = s;
         }
 
-        if (oldH < vis_height) {
-            if (localHeight > vis_height) {
-                localHeight = vis_height;
+        if (oldH < visHeight) {
+            if (localHeight > visHeight) {
+                localHeight = visHeight;
             }
-            fViewControl.redraw(0, getContentsY() + oldH, vis_width, localHeight - oldH, true);
+            fViewControl.redraw(0, getContentsY() + oldH, visWidth, localHeight - oldH, true);
         }
         if (updateScrollBarVisiblity()) {
             layout();
@@ -1106,7 +1125,7 @@ public class ScrollView extends Composite {
         int cy = getContentsY();
         int right = getContentsX() + getVisibleWidth() - vbar;
         int bottom = getContentsY() + getVisibleHeight() - hbar;
-        boolean align_h = false, align_v = false;
+        boolean alignH = false, alignV = false;
 
         if (localX < getContentsX()) {
             cx = localX;
@@ -1120,13 +1139,13 @@ public class ScrollView extends Composite {
         }
 
         if (localWidth > getVisibleWidth()) {
-            align_h = true;
+            alignH = true;
         }
         if (localHeight > getVisibleHeight()) {
-            align_v = true;
+            alignV = true;
         }
         // compute alignment on visible area horizontally
-        if (align_h || (forceAlign && localX + localWidth > right)) {
+        if (alignH || (forceAlign && localX + localWidth > right)) {
             // use align flags
             if ((align & SWT.LEFT) != 0) {
                 cx = localX;
@@ -1137,7 +1156,7 @@ public class ScrollView extends Composite {
             }
         }
         // compute alignment on visible area vertically
-        if (align_v || (forceAlign && localY + localHeight > bottom)) {
+        if (alignV || (forceAlign && localY + localHeight > bottom)) {
             // use align flags
             if ((align & SWT.TOP) != 0) {
                 cy = localY;
@@ -1287,21 +1306,11 @@ public class ScrollView extends Composite {
         return true;
     }
 
-    // redefined to return our vertical bar
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Scrollable#getVerticalBar()
-     */
     @Override
     public ScrollBar getVerticalBar() {
         return fVertScrollBar.getVerticalBar();
     }
 
-    // redefined to return out horizontal bar
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Scrollable#getHorizontalBar()
-     */
     @Override
     public ScrollBar getHorizontalBar() {
         return fHorScrollBar.getHorizontalBar();
@@ -1361,7 +1370,9 @@ public class ScrollView extends Composite {
     }
 
     /**
-     * setup scroll bars visibility, return true if one of visibility changed.
+     * Setup scroll bars visibility.
+     *
+     * @return True if one of visibility changed.
      */
     protected boolean updateScrollBarVisiblity() {
         boolean change = false;
@@ -1540,7 +1551,11 @@ public class ScrollView extends Composite {
     }
 
     /**
-     * Add support for arrow key, scroll the ... scroll view. But you can redefine this method for your convenience.
+     * Add support for arrow key, scroll the ... scroll view. But you can
+     * redefine this method for your convenience.
+     *
+     * @param event
+     *            Keyboard event
      */
     protected void keyPressedEvent(KeyEvent event) {
         switch (event.keyCode) {
@@ -1592,18 +1607,14 @@ public class ScrollView extends Composite {
         return bh + 1;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see org.eclipse.swt.widgets.Scrollable#computeTrim(int, int, int, int)
-     */
     @Override
     public Rectangle computeTrim(int x, int y, int w, int h) {
         Rectangle r = new Rectangle(x, y, w, h);
-        int bar_vis = computeBarVisibility(w, h, false, false);
-        if ((bar_vis & VBAR) != 0) {
+        int barVis = computeBarVisibility(w, h, false, false);
+        if ((barVis & VBAR) != 0) {
             r.width += getVerticalBarWidth();
         }
-        if ((bar_vis & HBAR) != 0) {
+        if ((barVis & HBAR) != 0) {
             r.height += getHorizontalBarHeight();
         }
         return r;
@@ -1613,22 +1624,24 @@ public class ScrollView extends Composite {
      *  Internal layout for ScrollView, handle scrollbars, drawzone and corner control
      */
     protected class SVLayout extends Layout {
+
+        private static final int DEFAULT_X = 250;
+        private static final int DEFAULT_Y = 250;
+        private static final int MAX_SEEK = 10;
+        private static final int MIN_SEEK = 0;
+
         /**
          * The seek value
          */
-        int seek = 0;
+        private int seek = 0;
         /**
          * The do-it-not flag
          */
-        boolean dontLayout = false;
+        private boolean dontLayout = false;
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.swt.widgets.Layout#computeSize(org.eclipse.swt.widgets.Composite, int, int, boolean)
-         */
         @Override
         protected Point computeSize(Composite composite, int wHint, int hHint, boolean flushCache) {
-            Point p = new Point(250, 250);
+            Point p = new Point(DEFAULT_X, DEFAULT_Y);
             if (fContentsWidth < p.x) {
                 p.x = fContentsWidth;
             }
@@ -1638,33 +1651,29 @@ public class ScrollView extends Composite {
             return p;
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.swt.widgets.Layout#layout(org.eclipse.swt.widgets.Composite, boolean)
-         */
         @Override
         protected void layout(Composite composite, boolean flushCache) {
             if (dontLayout) {
                 return;
             }
             seek++;
-            if (seek > 10) {
+            if (seek > MAX_SEEK) {
                 dontLayout = true;
             }
 
             Point cs = composite.getSize();
-            int bar_vis = computeBarVisibility(cs.x, cs.y, false, false);
-            boolean vb_vis = (bar_vis & VBAR) != 0;
-            boolean hb_vis = (bar_vis & HBAR) != 0;
-            fVertScrollBar.setVisible(vb_vis);
-            fHorScrollBar.setVisible(hb_vis);
+            int barVis = computeBarVisibility(cs.x, cs.y, false, false);
+            boolean vbVis = (barVis & VBAR) != 0;
+            boolean hbVis = (barVis & HBAR) != 0;
+            fVertScrollBar.setVisible(vbVis);
+            fHorScrollBar.setVisible(hbVis);
             int vbw = getVerticalBarWidth();
             int hbh = getHorizontalBarHeight();
-            int wb = vb_vis ? vbw : 0;
-            int hb = hb_vis ? hbh : 0;
+            int wb = vbVis ? vbw : 0;
+            int hb = hbVis ? hbh : 0;
             int cww = 0, cwh = 0;
 
-            if (fCornerControl != null && (vb_vis || hb_vis)) { // corner_control_.getVisible())
+            if (fCornerControl != null && (vbVis || hbVis)) { // corner_control_.getVisible())
                 fCornerControl.setVisible(true);
                 cww = vbw;
                 cwh = hbh;
@@ -1674,28 +1683,28 @@ public class ScrollView extends Composite {
                 if (hb == 0) {
                     hb = hbh;
                 }
-            } else if (vb_vis && hb_vis) {
+            } else if (vbVis && hbVis) {
                 if (fCornerControl != null) {
                     fCornerControl.setVisible(false);
                 }
                 cww = vbw;
                 cwh = hbh;
             }
-            if (vb_vis || hb_vis) {
+            if (vbVis || hbVis) {
                 updateScrollBarsValues();
             }
 
-            int vw = cs.x - (vb_vis ? vbw : 0);
-            int vh = cs.y - (hb_vis ? hbh : 0);
+            int vw = cs.x - (vbVis ? vbw : 0);
+            int vh = cs.y - (hbVis ? hbh : 0);
             int vbx = cs.x - wb;
             int hby = cs.y - hb;
 
             fViewControl.setBounds(0, 0, vw, vh);
 
-            if (vb_vis) {
+            if (vbVis) {
                 fVertScrollBar.setBounds(vbx, 0, wb, cs.y - cwh);
             }
-            if (hb_vis) {
+            if (hbVis) {
                 fHorScrollBar.setBounds(0, hby, cs.x - cww, hb);
             }
             if (fCornerControl != null && fCornerControl.getVisible()) {
@@ -1704,39 +1713,49 @@ public class ScrollView extends Composite {
             updateScrollBarsValues();
 
             seek--;
-            if (seek == 0) {
+            if (seek == MIN_SEEK) {
                 dontLayout = false;
             }
         }
+
+        boolean isDontLayout() {
+            return dontLayout;
+        }
+
+        void setSontLayout(boolean dontLayout) {
+            this.dontLayout = dontLayout;
+        }
     }
 
     // static must take place here... cursor is created once.
-    volatile static Cursor fOverviewCursor;
+    private volatile static Cursor fOverviewCursor;
 
     /** Support for click-and-see overview shell on this ScrollView */
     protected class Overview {
 
+        private static final  int REFRESH_FREQ = 4;
+
         /**
          *  factor for X from real and overview sizes, for mouse move speed.
          */
-        protected float fOverviewFactorX;
+        private float fOverviewFactorX;
 
         /**
          *  factor for Y from real and overview sizes, for mouse move speed.
          */
-        protected float fOverviewFactorY;
+        private float fOverviewFactorY;
         /**
          *  shell use to show overview
          */
-        protected Shell fOverview;
+        private Shell fOverview;
         /**
          * save mouse X cursor location for disappear();
          */
-        protected int fSaveCursorX;
+        private int fSaveCursorX;
         /**
          * save mouse Y cursor location for disappear();
          */
-        protected int fSaveCursorY;
+        private int fSaveCursorY;
 
         /**
          * Apply overview support on a control. Replace existing corner_widget
@@ -1812,7 +1831,7 @@ public class ScrollView extends Composite {
                 public void mouseMove(MouseEvent event) {
                     if (overviewing()) {
                         // Slow down the refresh
-                        if (refReshCount % 4 == 0) {
+                        if (refReshCount % REFRESH_FREQ == 0) {
                             overviewMove(event);
                         }
                         refReshCount++;
@@ -1839,6 +1858,11 @@ public class ScrollView extends Composite {
 
         /**
          * Process overview appear
+         *
+         * @param mx
+         *            X coordinate
+         * @param my
+         *            Y coordinate
          */
         protected void overviewAppear(int mx, int my) {
             if (fOverview == null) {
@@ -1851,7 +1875,6 @@ public class ScrollView extends Composite {
                 });
             }
             // always the same..
-            // overview.setBackground( viewcontrol_.getBackground() );
             fOverview.setForeground(fViewControl.getForeground());
 
             // get location of shell (in screeen coordinates)
@@ -1859,7 +1882,8 @@ public class ScrollView extends Composite {
             int x = p.x;
             int y = p.y;
             int w, h;
-            w = h = fOverviewSize;
+            h = fOverviewSize;
+            w = h;
             Rectangle scr = getDisplay().getBounds();
             Point ccs = fCornerControl.getSize();
             try {
@@ -1888,9 +1912,6 @@ public class ScrollView extends Composite {
             }
 
             // try pop-up on button, extending to bottom right,
-            // if outside screen, extend pop-up to top left
-            // if( x+w > scr.width ) x = scr.width-w; //x += corner_control_.getSize().x-w;
-            // if( y+h > scr.height ) y = scr.height-h;//y += corner_control_.getSize().y-h;
             if (x <= 0) {
                 x = 1;
             }
@@ -2016,26 +2037,29 @@ public class ScrollView extends Composite {
         /**
          * Convert overview coordinates to global coordinates.
          *
-         * @param loc the control reference
-         * @param x The x coordinate to convert
-         * @param y The y coordinate to convert
-         * @return
+         * @param loc
+         *            the control reference
+         * @param x
+         *            The x coordinate to convert
+         * @param y
+         *            The y coordinate to convert
+         * @return The new converted Point
          */
         protected Point toGlobalCoordinates(Control loc, int x, int y) {
             Point p = new Point(x, y);
             for (Control c = loc; c != null; c = c.getParent()) {
                 // control might have client area with 'decorations'
-                int trim_x = 0, trim_y = 0;
+                int trimX = 0, trimY = 0;
                 // other kind of widget with trimming ??
                 if (c instanceof Scrollable) {
                     Scrollable s = (Scrollable) c;
                     Rectangle rr = s.getClientArea();
                     Rectangle tr = s.computeTrim(rr.x, rr.y, rr.width, rr.height);
-                    trim_x = rr.x - tr.x;
-                    trim_y = rr.y - tr.y;
+                    trimX = rr.x - tr.x;
+                    trimY = rr.y - tr.y;
                 }
-                p.x += c.getLocation().x + trim_x;
-                p.y += c.getLocation().y + trim_y;
+                p.x += c.getLocation().x + trimX;
+                p.y += c.getLocation().y + trimY;
             }
             return p;
         }
