@@ -1,16 +1,15 @@
 /**********************************************************************
- * Copyright (c) 2005, 2008 IBM Corporation and others.
- * Copyright (c) 2011, 2012 Ericsson.
- *
+ * Copyright (c) 2005, 2013 IBM Corporation, Ericsson
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- * IBM - Initial API and implementation
- * Bernd Hufmann - Updated for TMF
+ *     IBM - Initial API and implementation
+ *     Bernd Hufmann - Updated for TMF
  **********************************************************************/
+
 package org.eclipse.linuxtools.tmf.ui.views.uml2sd.dialogs;
 
 import java.text.MessageFormat;
@@ -21,7 +20,7 @@ import org.eclipse.jface.wizard.WizardPage;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.DiagramToolTip;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.NGC;
 import org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDWidget;
-import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.SDMessages;
+import org.eclipse.linuxtools.tmf.ui.views.uml2sd.util.Messages;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
@@ -66,167 +65,184 @@ public class SDPrintDialogUI {
     /**
      * The set horizontal pages number.
      */
-    protected Button fSetHPagesNumber;
+    private Button fSetHPagesNumber;
     /**
      * The set vertical pages number.
      */
-    protected Button fSetVPagesNumber;
+    private Button fSetVPagesNumber;
     /**
      * Flag whether to use current zoom or not.
      */
-    protected Button fUseCurrentZoom;
+    private Button fUseCurrentZoom;
     /**
      * Flag whether to print all pages or not
      */
-    protected Button fAllPages;
+    private Button fAllPages;
     /**
      * Flag whether to print current page only
      */
-    protected Button fCurrentPage;
+    private Button fCurrentPage;
     /**
      * Button to select a page list.
      */
-    protected Button fPageList;
+    private Button fPageList;
     /**
      * Button to select a page range.
      */
-    protected Button fPageRange;
+    private Button fPageRange;
     /**
      * Text field to enter from page.
      */
-    protected Text fFromPage;
+    private Text fFromPage;
     /**
      * Text field to enter to page.
      */
-    protected Text fToPage;
+    private Text fToPage;
     /**
      *  The sequence diagram widget reference.
      */
-    protected SDWidget fSdView;
+    private SDWidget fSdView;
     /**
      * Text field for number of horizontal pages
      */
-    protected Text fHorPagesNum;
+    private Text fHorPagesNum;
     /**
      * Text field for number of vertical pages
      */
-    protected Text fVertPagesNum;
+    private Text fVertPagesNum;
     /**
      * Text field for toal number of pages
      */
-    protected Text fTotalPages;
+    private Text fTotalPages;
     /**
      * A modify listener implementation to handle modifications.
      */
-    protected ModifyListener fModifyListener;
+    private ModifyListener fModifyListener;
     /**
      * A selection listener implementation to handle selections.
      */
-    protected SelectionListener fSelectionListener;
+    private SelectionListener fSelectionListener;
     /**
      * Local canvas displaying sequence diagram overview.
      */
-    protected LocalSD fOverviewCanvas;
+    private LocalSD fOverviewCanvas;
     /**
      * Number of pages
      */
-    protected int fNbPages = 0;
+    private int fNbPages = 0;
     /**
      * Number of selected pages.
      */
-    protected int fPageNum = -1;
+    private int fPageNum = -1;
     /**
      * Number of first page.
      */
-    protected int fFirstPage = -1;
+    private int fFirstPage = -1;
     /**
      * List of pages to print.
      */
-    protected int fPagesList[];
+    private int fPagesList[];
+
     /**
-     * Values for dividing sequence diagram into pages.
+     * Value for dividing the sequence diagram into pages
      */
-    protected float fStepX, fStepY, sTX, sTY;
+    private float fStepX;
+
+    /**
+     * Value for dividing the sequence diagram into pages
+     */
+    private float fStepY;
+
+    /**
+     * Value for dividing the sequence diagram into pages
+     */
+    private float sTX;
+
+    /**
+     * Value for dividing the sequence diagram into pages
+     */
+    private float sTY;
+
     /**
      * Page which to print from.
      */
-    protected int fFrom;
+    private int fFrom;
     /**
      * Page which to print to.
      */
-    protected int fTo;
+    private int fTo;
     /**
      * Flag for enabling multi-selection.
      */
-    protected boolean fMultiSelection = false;
+    private boolean fMultiSelection = false;
     /**
      * Flag for enabling area selection.
      */
-    protected boolean fAreaSelection = false;
+    private boolean fAreaSelection = false;
     /**
      * Flag for printing all.
      */
-    protected boolean fPrintAll;
+    private boolean fPrintAll;
     /**
      * Flag for printing current page only.
      */
-    protected boolean fPrintCurrent;
+    private boolean fPrintCurrent;
     /**
      * Flag for printing a selection of pages.
      */
-    protected boolean fPrintSelection;
+    private boolean fPrintSelection;
     /**
      * Flag for printing a range of pages.
      */
-    protected boolean fPrintRange;
+    private boolean fPrintRange;
     /**
      * Number of selected rows
      */
-    protected int fNbRows;
+    private int fNbRows;
     /**
      * Number of selected lines
      */
-    protected int fNbLines;
+    private int fNbLines;
     /**
      * The zoom factor.
      */
-    protected float fZoomFactor;
+    private float fZoomFactor;
     /**
      * The printer data reference.
      */
-    protected PrinterData fPrinterData;
+    private PrinterData fPrinterData;
     /**
      * The diagram tooltip to show if necessary.
      */
-    protected DiagramToolTip fToolTip = null;
+    private DiagramToolTip fToolTip = null;
     /**
      * Label for current selection.
      */
-    protected Label fCurrentSelection;
+    private Label fCurrentSelection;
     /**
      * The shell reference.
      */
-    protected Shell fShell;
+    private Shell fShell;
     /**
      * Button to open printer dialog from OS.
      */
-    protected Button fPrinterDialog;
+    private Button fPrinterDialog;
     /**
      * Flag for showing print button.
      */
-    protected boolean fShowPrintButton;
+    private boolean fShowPrintButton;
     /**
      * Test value
      */
-    protected int fTest = 3;
+    private int fTest = 3;
     /**
      * Parent wizard page if used as wizard
      */
-    protected WizardPage fParentWizardPage = null;
+    private WizardPage fParentWizardPage = null;
     /**
      * Reference to parent print dialog.
      */
-    protected SDPrintDialog fParentDialog = null;
+    private SDPrintDialog fParentDialog = null;
 
     // ------------------------------------------------------------------------
     // Helper Class
@@ -235,7 +251,7 @@ public class SDPrintDialogUI {
      * Local sequence diagram widget used to display overview of sequence diagram to print.
      * @version 1.0
      */
-    protected class LocalSD extends SDWidget {
+    private class LocalSD extends SDWidget {
 
         /**
          * Constructor
@@ -246,34 +262,22 @@ public class SDPrintDialogUI {
             super(c, s);
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.ScrollView#getContentsHeight()
-         */
         @Override
         public int getContentsHeight() {
             if (fSdView.getContentsHeight() > fSdView.getContentsHeight()) {
-                return (int) (fSdView.getVisibleHeight() / (float) fTest / fSdView.fZoomValue);
+                return (int) (fSdView.getVisibleHeight() / (float) fTest / fSdView.getZoomValue());
             }
             return super.getContentsHeight();
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.ScrollView#getContentsWidth()
-         */
         @Override
         public int getContentsWidth() {
             if (fSdView.getVisibleWidth() > fSdView.getContentsWidth()) {
-                return (int) (fSdView.getVisibleWidth() / (float) fTest / fSdView.fZoomValue);
+                return (int) (fSdView.getVisibleWidth() / (float) fTest / fSdView.getZoomValue());
             }
             return super.getContentsWidth();
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDWidget#contentsMouseHover(org.eclipse.swt.events.MouseEvent)
-         */
         @Override
         protected void contentsMouseHover(MouseEvent event) {
         }
@@ -310,11 +314,11 @@ public class SDPrintDialogUI {
 
                     Image toDel = over;
                     if (fOverviewCanvas.isFocusControl()) {
-                        over = new Image(super.getShell().getDisplay(), drawRegionSelected(toDel, new Rectangle(contentsToViewX((int) (row * stepX * fOverviewCanvas.fZoomValue)), contentsToViewY((int) (line * stepY * fOverviewCanvas.fZoomValue)),
-                                ((int) (stepX * fOverviewCanvas.fZoomValue)), ((int) (stepY * fOverviewCanvas.fZoomValue))), new RGB(0, 0, 128)));
+                        over = new Image(super.getShell().getDisplay(), drawRegionSelected(toDel, new Rectangle(contentsToViewX((int) (row * stepX * fOverviewCanvas.getZoomValue())), contentsToViewY((int) (line * stepY * fOverviewCanvas.getZoomValue())),
+                                ((int) (stepX * fOverviewCanvas.getZoomValue())), ((int) (stepY * fOverviewCanvas.getZoomValue()))), new RGB(0, 0, 128)));
                     } else {
-                        over = new Image(super.getShell().getDisplay(), drawRegionSelected(toDel, new Rectangle(contentsToViewX((int) (row * stepX * fOverviewCanvas.fZoomValue)), contentsToViewY((int) (line * stepY * fOverviewCanvas.fZoomValue)),
-                                ((int) (stepX * fOverviewCanvas.fZoomValue)), ((int) (stepY * fOverviewCanvas.fZoomValue))), new RGB(221, 208, 200)));
+                        over = new Image(super.getShell().getDisplay(), drawRegionSelected(toDel, new Rectangle(contentsToViewX((int) (row * stepX * fOverviewCanvas.getZoomValue())), contentsToViewY((int) (line * stepY * fOverviewCanvas.getZoomValue())),
+                                ((int) (stepX * fOverviewCanvas.getZoomValue())), ((int) (stepY * fOverviewCanvas.getZoomValue()))), new RGB(221, 208, 200)));
                     }
                     toDel.dispose();
                 }
@@ -335,8 +339,8 @@ public class SDPrintDialogUI {
                 row--;
 
                 Image toDel = over;
-                over = new Image(super.getShell().getDisplay(), drawRegionSelected(toDel, new Rectangle(contentsToViewX((int) (row * stepX * fOverviewCanvas.fZoomValue)), contentsToViewY((int) (line * stepY * fOverviewCanvas.fZoomValue)),
-                        ((int) (stepX * fOverviewCanvas.fZoomValue)), ((int) (stepY * fOverviewCanvas.fZoomValue))), new RGB(221, 208, 200)));
+                over = new Image(super.getShell().getDisplay(), drawRegionSelected(toDel, new Rectangle(contentsToViewX((int) (row * stepX * fOverviewCanvas.getZoomValue())), contentsToViewY((int) (line * stepY * fOverviewCanvas.getZoomValue())),
+                        ((int) (stepX * fOverviewCanvas.getZoomValue())), ((int) (stepY * fOverviewCanvas.getZoomValue()))), new RGB(221, 208, 200)));
                 toDel.dispose();
             }
 
@@ -356,10 +360,6 @@ public class SDPrintDialogUI {
             return over;
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDWidget#drawContents(org.eclipse.swt.graphics.GC, int, int, int, int)
-         */
         @Override
         protected void drawContents(GC gc, int clipx, int clipy, int clipw, int cliph) {
 
@@ -367,14 +367,14 @@ public class SDPrintDialogUI {
             computeStepXY();
             Image d;
 
-            int lw = (int) (getContentsWidth() / fZoomValue);
+            int lw = (int) (getContentsWidth() / getZoomValue());
             if (getContentsWidth() < getVisibleWidth()) {
-                lw = (int) (getVisibleWidth() / fZoomValue);
+                lw = (int) (getVisibleWidth() / getZoomValue());
             }
 
-            int lh = (int) (getContentsHeight() / fZoomValue);
+            int lh = (int) (getContentsHeight() / getZoomValue());
             if (getContentsHeight() < getVisibleHeight()) {
-                lh = (int) (getVisibleHeight() / fZoomValue);
+                lh = (int) (getVisibleHeight() / getZoomValue());
             }
             d = createPagesSelectionImages(dbuffer, lw, fStepX, lh, fStepY);
 
@@ -394,13 +394,8 @@ public class SDPrintDialogUI {
             dbuffer.dispose();
             d.dispose();
             gc.dispose();
-
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDWidget#keyPressedEvent(org.eclipse.swt.events.KeyEvent)
-         */
         @Override
         protected void keyPressedEvent(KeyEvent e) {
             if (e.keyCode == SWT.CTRL) {
@@ -418,8 +413,8 @@ public class SDPrintDialogUI {
                 if (row == 0) {
                     line--;
                 }
-                if ((line + 1) * fStepY > (fOverviewCanvas.getContentsY() + fOverviewCanvas.getVisibleHeight()) / fOverviewCanvas.fZoomValue) {
-                    fOverviewCanvas.scrollBy(0, (int) (fStepY * fOverviewCanvas.fZoomValue));
+                if ((line + 1) * fStepY > (fOverviewCanvas.getContentsY() + fOverviewCanvas.getVisibleHeight()) / fOverviewCanvas.getZoomValue()) {
+                    fOverviewCanvas.scrollBy(0, (int) (fStepY * fOverviewCanvas.getZoomValue()));
                 }
             }
             if (e.keyCode == SWT.ARROW_UP) {
@@ -431,8 +426,8 @@ public class SDPrintDialogUI {
                 if (row == 0) {
                     line--;
                 }
-                if ((line) * fStepY <= fOverviewCanvas.getContentsY() / fOverviewCanvas.fZoomValue) {
-                    fOverviewCanvas.scrollBy(0, -(int) (fStepY * fOverviewCanvas.fZoomValue));
+                if ((line) * fStepY <= fOverviewCanvas.getContentsY() / fOverviewCanvas.getZoomValue()) {
+                    fOverviewCanvas.scrollBy(0, -(int) (fStepY * fOverviewCanvas.getZoomValue()));
                 }
             }
             if (e.keyCode == SWT.ARROW_LEFT) {
@@ -440,8 +435,8 @@ public class SDPrintDialogUI {
                     fPageNum--;
                 }
                 int row = fPageNum % getNbRow();
-                if ((row - 1) * fStepX < (fOverviewCanvas.getContentsX()) / fOverviewCanvas.fZoomValue) {
-                    fOverviewCanvas.scrollBy(-(int) (fStepX * fOverviewCanvas.fZoomValue), 0);
+                if ((row - 1) * fStepX < (fOverviewCanvas.getContentsX()) / fOverviewCanvas.getZoomValue()) {
+                    fOverviewCanvas.scrollBy(-(int) (fStepX * fOverviewCanvas.getZoomValue()), 0);
                 }
             }
             if (e.keyCode == SWT.ARROW_RIGHT) {
@@ -452,8 +447,8 @@ public class SDPrintDialogUI {
                 if (row == 0) {
                     row = getNbRow();
                 }
-                if ((row) * fStepX > (fOverviewCanvas.getContentsX() + fOverviewCanvas.getVisibleWidth()) / fOverviewCanvas.fZoomValue) {
-                    fOverviewCanvas.scrollBy((int) (fStepX * fOverviewCanvas.fZoomValue), 0);
+                if ((row) * fStepX > (fOverviewCanvas.getContentsX() + fOverviewCanvas.getVisibleWidth()) / fOverviewCanvas.getZoomValue()) {
+                    fOverviewCanvas.scrollBy((int) (fStepX * fOverviewCanvas.getZoomValue()), 0);
                 }
             }
 
@@ -512,10 +507,6 @@ public class SDPrintDialogUI {
             fOverviewCanvas.redraw();
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDWidget#keyReleasedEvent(org.eclipse.swt.events.KeyEvent)
-         */
         @Override
         protected void keyReleasedEvent(KeyEvent e) {
             if (e.keyCode == SWT.CTRL) {
@@ -526,16 +517,12 @@ public class SDPrintDialogUI {
             }
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDWidget#contentsMouseDownEvent(org.eclipse.swt.events.MouseEvent)
-         */
         @Override
         protected void contentsMouseDownEvent(MouseEvent event) {
 
             computeStepXY();
-            int x1 = (int) ((event.x / fOverviewCanvas.fZoomValue) / fStepX);
-            int x2 = (int) ((event.y / fOverviewCanvas.fZoomValue) / fStepY);
+            int x1 = (int) ((event.x / fOverviewCanvas.getZoomValue()) / fStepX);
+            int x2 = (int) ((event.y / fOverviewCanvas.getZoomValue()) / fStepY);
 
             int oldPage = fPageNum;
 
@@ -607,19 +594,11 @@ public class SDPrintDialogUI {
             redraw();
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.SDWidget#contentsMouseMoveEvent(org.eclipse.swt.events.MouseEvent)
-         */
         @Override
         protected void contentsMouseMoveEvent(MouseEvent e) {
             fToolTip.hideToolTip();
         }
 
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.linuxtools.tmf.ui.views.uml2sd.ScrollView#resizeContents(int, int)
-         */
         @Override
         public void resizeContents(int w, int h) {
             super.resizeContents(w, h);
@@ -631,10 +610,6 @@ public class SDPrintDialogUI {
      * A traverse listener implementation.
      */
     protected static class LocalTraverseListener implements TraverseListener {
-        /*
-         * (non-Javadoc)
-         * @see org.eclipse.swt.events.TraverseListener#keyTraversed(org.eclipse.swt.events.TraverseEvent)
-         */
         @Override
         public void keyTraversed(TraverseEvent e) {
             if ((e.detail == SWT.TRAVERSE_TAB_NEXT) || (e.detail == SWT.TRAVERSE_TAB_PREVIOUS)) {
@@ -739,10 +714,6 @@ public class SDPrintDialogUI {
                 fOverviewCanvas.update();
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
-             */
             @Override
             public void widgetDefaultSelected(SelectionEvent e) {
                 fPagesList = new int[0];
@@ -753,10 +724,6 @@ public class SDPrintDialogUI {
         };
 
         fModifyListener = new ModifyListener() {
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.ModifyListener#modifyText(org.eclipse.swt.events.ModifyEvent)
-             */
             @Override
             public void modifyText(ModifyEvent e) {
                 fPagesList = new int[0];
@@ -797,19 +764,19 @@ public class SDPrintDialogUI {
         parent.setLayout(parentLayout);
 
         Group g1 = new Group(parent, SWT.SHADOW_NONE);
-        g1.setText(SDMessages._113);
+        g1.setText(Messages.SequenceDiagram_ZoomOption);
         g1.setLayoutData(newGridData(3));
         GridLayout g1layout = new GridLayout();
         g1layout.numColumns = 2;
         g1.setLayout(g1layout);
 
         fUseCurrentZoom = new Button(g1, SWT.RADIO);
-        fUseCurrentZoom.setText(SDMessages._112);
+        fUseCurrentZoom.setText(Messages.SequenceDiagram_UseCurrentZoom);
         fUseCurrentZoom.setLayoutData(newGridData(2));
         fUseCurrentZoom.addSelectionListener(fSelectionListener);
 
         fSetHPagesNumber = new Button(g1, SWT.RADIO);
-        fSetHPagesNumber.setText(SDMessages._110);
+        fSetHPagesNumber.setText(Messages.SequenceDiagram_NumberOfHorizontalPages);
         fSetHPagesNumber.setLayoutData(newGridData(1));
         fSetHPagesNumber.addSelectionListener(fSelectionListener);
 
@@ -817,7 +784,7 @@ public class SDPrintDialogUI {
         fHorPagesNum.addModifyListener(fModifyListener);
 
         fSetVPagesNumber = new Button(g1, SWT.RADIO);
-        fSetVPagesNumber.setText(SDMessages._111);
+        fSetVPagesNumber.setText(Messages.SequenceDiagram_NumberOfVerticalPages);
         fSetVPagesNumber.setLayoutData(newGridData(1));
         fSetVPagesNumber.addSelectionListener(fSelectionListener);
 
@@ -825,14 +792,14 @@ public class SDPrintDialogUI {
         fVertPagesNum.addModifyListener(fModifyListener);
 
         Label nbTotal = new Label(g1, SWT.SHADOW_NONE | SWT.RIGHT);
-        nbTotal.setText(SDMessages._109);
+        nbTotal.setText(Messages.TotalNumberOfPages);
         // nbTotal.setLayoutData(newGridData(1));
 
         fTotalPages = new Text(g1, SWT.SINGLE | SWT.BORDER | SWT.READ_ONLY);
         // nbHV.addModifyListener(modifListener);
 
         Group g2 = new Group(parent, SWT.SHADOW_NONE);
-        g2.setText(SDMessages._119);
+        g2.setText(Messages.SequenceDiagram_Preview);
         GridData data = new GridData(GridData.GRAB_VERTICAL | GridData.VERTICAL_ALIGN_FILL | GridData.GRAB_HORIZONTAL | GridData.HORIZONTAL_ALIGN_FILL);
         data.horizontalSpan = 3;
         data.verticalSpan = 2;
@@ -857,7 +824,7 @@ public class SDPrintDialogUI {
             fTest = 10;
         }
         fOverviewCanvas.setFrame(fSdView.getFrame(), true);
-        fOverviewCanvas.fZoomValue = (float) 1 / fTest;
+        fOverviewCanvas.setZoomValue((float) 1 / fTest);
         fOverviewCanvas.setCornerControl(null);
         seqDiagLayoutData.widthHint = fOverviewCanvas.getContentsWidth() / fTest;
         seqDiagLayoutData.widthHint = fOverviewCanvas.getFrame().getWidth() / fTest + 15;
@@ -886,70 +853,58 @@ public class SDPrintDialogUI {
         fCurrentSelection.setLayoutData(newGridData(1));
 
         Group g3 = new Group(parent, SWT.SHADOW_NONE);
-        g3.setText(SDMessages._118);
+        g3.setText(Messages.SequenceDiagram_PrintRange);
         g3.setLayoutData(newGridData(3));
         GridLayout g3layout = new GridLayout();
         g3layout.numColumns = 4;
         g3.setLayout(g3layout);
 
         fAllPages = new Button(g3, SWT.RADIO);
-        fAllPages.setText(SDMessages._108);
+        fAllPages.setText(Messages.SequenceDiagram_AllPages);
         fAllPages.setLayoutData(newGridData(4));
         fAllPages.addSelectionListener(fSelectionListener);
 
         fCurrentPage = new Button(g3, SWT.RADIO);
-        fCurrentPage.setText(SDMessages._107);
+        fCurrentPage.setText(Messages.SequenceDiagram_CurrentView);
         fCurrentPage.setLayoutData(newGridData(4));
         fCurrentPage.setEnabled(true);
         fCurrentPage.setSelection(true);
         fCurrentPage.addSelectionListener(fSelectionListener);
 
         fPageList = new Button(g3, SWT.RADIO);
-        fPageList.setText(SDMessages._106);
+        fPageList.setText(Messages.SequenceDiagram_SelectedPages);
         fPageList.setLayoutData(newGridData(4));
         fPageList.addSelectionListener(fSelectionListener);
 
         fPageRange = new Button(g3, SWT.RADIO);
-        fPageRange.setText(SDMessages._103);
+        fPageRange.setText(Messages.SequenceDiagram_FromPage);
         fPageRange.setLayoutData(newGridData(1));
         fPageRange.addSelectionListener(fSelectionListener);
 
         fFromPage = new Text(g3, SWT.SINGLE | SWT.BORDER);
 
         Label labelTo = new Label(g3, SWT.CENTER);
-        labelTo.setText(SDMessages._105);
+        labelTo.setText(Messages.SequenceDiagram_to);
 
         fToPage = new Text(g3, SWT.SINGLE | SWT.BORDER);
 
         fToolTip = new DiagramToolTip(fOverviewCanvas);
 
         fOverviewCanvas.getViewControl().addMouseTrackListener(new MouseTrackListener() {
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.MouseTrackListener#mouseEnter(org.eclipse.swt.events.MouseEvent)
-             */
             @Override
             public void mouseEnter(MouseEvent e) {
                 fToolTip.hideToolTip();
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.MouseTrackListener#mouseExit(org.eclipse.swt.events.MouseEvent)
-             */
             @Override
             public void mouseExit(MouseEvent e) {
                 fToolTip.hideToolTip();
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.MouseTrackListener#mouseHover(org.eclipse.swt.events.MouseEvent)
-             */
             @Override
             public void mouseHover(MouseEvent e) {
-                int x1 = (int) (fOverviewCanvas.viewToContentsX(e.x) / fOverviewCanvas.fZoomValue / fStepX);
-                int x2 = (int) (fOverviewCanvas.viewToContentsY(e.y) / fOverviewCanvas.fZoomValue / fStepY);
+                int x1 = (int) (fOverviewCanvas.viewToContentsX(e.x) / fOverviewCanvas.getZoomValue() / fStepX);
+                int x2 = (int) (fOverviewCanvas.viewToContentsY(e.y) / fOverviewCanvas.getZoomValue() / fStepY);
                 int num = x1 + x2 * getNbRow() + 1;
                 if (num > maxNumOfPages()) {
                     return;
@@ -968,19 +923,11 @@ public class SDPrintDialogUI {
         fOverviewCanvas.addTraverseListener(new LocalTraverseListener());
 
         fOverviewCanvas.addFocusListener(new FocusListener() {
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.FocusListener#focusGained(org.eclipse.swt.events.FocusEvent)
-             */
             @Override
             public void focusGained(FocusEvent e) {
                 fOverviewCanvas.redraw();
             }
 
-            /*
-             * (non-Javadoc)
-             * @see org.eclipse.swt.events.FocusListener#focusLost(org.eclipse.swt.events.FocusEvent)
-             */
             @Override
             public void focusLost(FocusEvent e) {
                 fOverviewCanvas.redraw();
@@ -999,23 +946,14 @@ public class SDPrintDialogUI {
             Label label = new Label(printerDlg, SWT.NONE);
             label.setLayoutData(new GridData(SWT.FILL, SWT.DEFAULT, true, false));
             fPrinterDialog = new Button(printerDlg, SWT.PUSH);
-            fPrinterDialog.setText(SDMessages._115);
+            fPrinterDialog.setText(Messages.SequenceDiagram_Printer);
 
             fPrinterDialog.addSelectionListener(new SelectionListener() {
-
-                /*
-                 * (non-Javadoc)
-                 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
-                 */
                 @Override
                 public void widgetSelected(SelectionEvent e) {
                     printButtonSelected();
                 }
 
-                /*
-                 * (non-Javadoc)
-                 * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
-                 */
                 @Override
                 public void widgetDefaultSelected(SelectionEvent e) {
                 }
@@ -1051,22 +989,22 @@ public class SDPrintDialogUI {
                 fFrom = Integer.valueOf(fFromPage.getText()).intValue();
                 fTo = Integer.valueOf(fToPage.getText()).intValue();
                 if (fFrom > maxNumOfPages() || fTo > maxNumOfPages() || fFrom <= 0 || fTo <= 0) {
-                    MessageDialog.openError(getShell(), SDMessages._98, SDMessages._99);
+                    MessageDialog.openError(getShell(), Messages.SequenceDiagram_Error, Messages.SequenceDiagram_InvalidRange);
                     return false;
                 }
             } else if (fSetHPagesNumber.getSelection() && fNbPages <= 0) {
-                MessageDialog.openError(getShell(), SDMessages._98, SDMessages._101);
+                MessageDialog.openError(getShell(), Messages.SequenceDiagram_Error, Messages.SequenceDiagram_InvalidNbHorizontal);
                 return false;
             } else if (fSetVPagesNumber.getSelection() && fNbPages <= 0) {
-                MessageDialog.openError(getShell(), SDMessages._98, SDMessages._100);
+                MessageDialog.openError(getShell(), Messages.SequenceDiagram_Error, Messages.SequenceDiagram_InvalidNbVertical);
                 return false;
             } else if (fPrintSelection && getPageList().length <= 0) {
-                MessageDialog.openError(getShell(), SDMessages._98, SDMessages._102);
+                MessageDialog.openError(getShell(), Messages.SequenceDiagram_Error, Messages.SequenceDiagram_NoPageSelected);
                 return false;
             }
 
         } catch (Exception e) {
-            MessageDialog.openError(getShell(), SDMessages._98, SDMessages._99);
+            MessageDialog.openError(getShell(), Messages.SequenceDiagram_Error, Messages.SequenceDiagram_InvalidRange);
             fFrom = 0;
             fTo = 0;
             return false;
@@ -1127,8 +1065,8 @@ public class SDPrintDialogUI {
      * Computes value for X coordinates step and Y coordinates step.
      */
     protected void computeStepXY() {
-        float cw = fOverviewCanvas.getContentsWidth() / fOverviewCanvas.fZoomValue;
-        float ch = fOverviewCanvas.getContentsHeight() / fOverviewCanvas.fZoomValue;
+        float cw = fOverviewCanvas.getContentsWidth() / fOverviewCanvas.getZoomValue();
+        float ch = fOverviewCanvas.getContentsHeight() / fOverviewCanvas.getZoomValue();
         try {
             if (fPrinterData == null) {
                 fStepX = 0;
@@ -1230,7 +1168,7 @@ public class SDPrintDialogUI {
      */
     public int getNbRow() {
         if (!fSetHPagesNumber.isDisposed()) {
-            int cw = (int) (fOverviewCanvas.getContentsWidth() / fOverviewCanvas.fZoomValue);
+            int cw = (int) (fOverviewCanvas.getContentsWidth() / fOverviewCanvas.getZoomValue());
             int row = 1;
             if (fStepX != 0) {
                 row = (int) (cw / fStepX);
@@ -1252,7 +1190,7 @@ public class SDPrintDialogUI {
      */
     public int getNbLines() {
         if (!fSetVPagesNumber.isDisposed()) {
-            int ch = (int) (fOverviewCanvas.getContentsHeight() / fOverviewCanvas.fZoomValue);
+            int ch = (int) (fOverviewCanvas.getContentsHeight() / fOverviewCanvas.getZoomValue());
             int line = 1;
             if (fStepY != 0) {
                 line = (int) (ch / fStepY);
@@ -1362,7 +1300,7 @@ public class SDPrintDialogUI {
      */
     protected void displayPageNum() {
         if (fPageNum > 0) {
-            String message = MessageFormat.format(SDMessages._117, new Object[] { Integer.valueOf(fPageNum) });
+            String message = MessageFormat.format(Messages.SequenceDiagram_Page, new Object[] { Integer.valueOf(fPageNum) });
             fCurrentSelection.setText(message);
             fCurrentSelection.getParent().layout();
         }
@@ -1462,7 +1400,7 @@ public class SDPrintDialogUI {
             // used in the wizard dialog
             if (fPrinterData == null) {
                 // show error message and disable Finish button
-                fParentWizardPage.setErrorMessage(SDMessages._135);
+                fParentWizardPage.setErrorMessage(Messages.SequenceDiagram_NoPrinterSelected);
                 fParentWizardPage.setPageComplete(false);
             } else {
                 // clear error message and enable Finish button
@@ -1473,7 +1411,7 @@ public class SDPrintDialogUI {
             // used in the print dialog
             if (fPrinterData == null) {
                 // show error message and disable OK button
-                fParentDialog.setErrorMessage(SDMessages._135);
+                fParentDialog.setErrorMessage(Messages.SequenceDiagram_NoPrinterSelected);
                 fParentDialog.setPageComplete(false);
             } else {
                 // clear error message and enable OK button
