@@ -163,4 +163,15 @@ public interface ITimeGraphPresentationProvider {
      */
     Map<String, String> getEventHoverToolTipInfo(ITimeEvent event, long hoverTime);
 
-}
\ No newline at end of file
+    /**
+     * Check whether time and duration should be displayed in tooltip (after items from
+     * {@link #getEventHoverToolTipInfo(ITimeEvent)}).
+     *
+     * @return <code>true</code> if times and duration should be displayed on tooltip, <code>false</code> otherwise.
+     *
+     * @since 3.0
+     */
+    public boolean displayTimesInTooltip();
+
+
+}
