@@ -40,4 +40,23 @@ public interface ITimeGraphPresentationProvider2 extends ITimeGraphPresentationP
      */
     void setDrawingHelper(ITmfTimeGraphDrawingHelper helper);
 
+    /**
+     * Adds a color settings listener, to be notified when the presentation
+     * provider's state colors change.
+     *
+     * @param listener
+     *            The new listener for color settings changes
+     * @since 3.0
+     */
+    public void addColorListener(ITimeGraphColorListener listener);
+
+    /**
+     * Removes a color settings listener.
+     *
+     * @param listener
+     *            The color settings listener to remove
+     * @since 3.0
+     */
+    public void removeColorListener(ITimeGraphColorListener listener);
+
 }
\ No newline at end of file
