@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson
+ * Copyright (c) 2012, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -27,5 +27,5 @@ public interface ITimeGraphRangeListener extends EventListener {
      *
      * @param event event object describing details
      */
-    public void timeRangeUpdated(TimeGraphRangeUpdateEvent event);
+    void timeRangeUpdated(TimeGraphRangeUpdateEvent event);
 }
