@@ -14,6 +14,8 @@
 
 package org.eclipse.linuxtools.tmf.ui.widgets.timegraph;
 
+import java.util.ArrayList;
+import java.util.List;
 import java.util.Map;
 
 import org.eclipse.linuxtools.internal.tmf.ui.Messages;
@@ -36,6 +38,9 @@ public class TimeGraphPresentationProvider implements ITimeGraphPresentationProv
     private ITmfTimeGraphDrawingHelper fDrawingHelper;
     private final String fStateTypeName;
 
+    // The list of listeners for graph color changes
+    private final List<ITimeGraphColorListener> fListeners = new ArrayList<>();
+
     // ------------------------------------------------------------------------
     // Constants
     // ------------------------------------------------------------------------
@@ -145,4 +150,40 @@ public class TimeGraphPresentationProvider implements ITimeGraphPresentationProv
         return getEventHoverToolTipInfo(event);
     }
 
-}
\ No newline at end of file
+    /**
+     * @since 3.0
+     */
+    @Override
+    public boolean displayTimesInTooltip() {
+        return true;
+    }
+
+    /**
+     * @since 3.0
+     */
+    @Override
+    public void addColorListener(ITimeGraphColorListener listener) {
+        if (!fListeners.contains(listener)) {
+            fListeners.add(listener);
+        }
+    }
+
+    /**
+     * @since 3.0
+     */
+    @Override
+    public void removeColorListener(ITimeGraphColorListener listener) {
+        fListeners.remove(listener);
+    }
+
+    /**
+     * Notifies listeners of the state table change
+     * @since 3.0
+     */
+    protected void fireColorSettingsChanged() {
+        for (ITimeGraphColorListener listener : fListeners) {
+            listener.colorSettingsChanged(getStateTable());
+        }
+    }
+
+}
