@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson
+ * Copyright (c) 2012, 2014 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -15,7 +15,7 @@ package org.eclipse.linuxtools.tmf.ui.widgets.timegraph;
 import java.util.EventObject;
 
 /**
- * Event for the time graph view
+ * Time selection event
  *
  * @version 1.0
  * @author Patrick Tasse
@@ -29,28 +29,46 @@ public class TimeGraphTimeEvent extends EventObject {
     private static final long serialVersionUID = 1L;
 
     /**
-     * The selected time.
+     * The selection begin time.
      */
-    private final long fTime;
+    private final long fBeginTime;
+
+    /**
+     * The selection end time.
+     */
+    private final long fEndTime;
 
     /**
      * Standard constructor
      *
      * @param source
      *            The source of this event
-     * @param time
-     *            The time that was requested
+     * @param beginTime
+     *            The selection begin time
+     * @param endTime
+     *            The selection end time
+     * @since 2.1
      */
-    public TimeGraphTimeEvent(Object source, long time) {
+    public TimeGraphTimeEvent(Object source, long beginTime, long endTime) {
         super(source);
-        fTime = time;
+        fBeginTime = beginTime;
+        fEndTime = endTime;
     }
 
     /**
-     * @return the selected time
+     * @return the selection begin time
+     * @since 2.1
      */
-    public long getTime() {
-        return fTime;
+    public long getBeginTime() {
+        return fBeginTime;
+    }
+
+    /**
+     * @return the selection end time
+     * @since 2.1
+     */
+    public long getEndTime() {
+        return fEndTime;
     }
 
 }
