@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2012 Ericsson
+ * Copyright (c) 2009, 2013 Ericsson
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v1.0 which
@@ -27,14 +27,14 @@ public interface ITimeEvent {
      *
      * @return The time graph entry
      */
-    public ITimeGraphEntry getEntry();
+    ITimeGraphEntry getEntry();
 
     /**
      * Get the timestamp of this event.
      *
      * @return The event's time
      */
-    public long getTime();
+    long getTime();
 
     /**
      * @return
@@ -45,6 +45,6 @@ public interface ITimeEvent {
      * </list>
      * <p>
      */
-    public long getDuration();
+    long getDuration();
 
 }
\ No newline at end of file
