@@ -463,16 +463,22 @@ public class Utils {
     }
 
     /**
-     * N means: <list> <li>-1: Previous Event</li> <li>0: Current Event</li> <li>
-     * 1: Next Event</li> <li>2: Previous Event when located in a non Event Area
-     * </list>
+     * Gets the {@link ITimeEvent} at the given time from the given
+     * {@link ITimeGraphEntry}.
      *
      * @param entry
+     *            a {@link ITimeGraphEntry}
      * @param time
+     *            a timestamp
      * @param n
-     * @return
+     *            this parameter means: <list> <li>-1: Previous Event</li> <li>
+     *            0: Current Event</li> <li>
+     *            1: Next Event</li> <li>2: Previous Event when located in a non
+     *            Event Area </list>
+     * @return a {@link ITimeEvent}, or <code>null</code>.
+     * @since 3.0
      */
-    static ITimeEvent findEvent(ITimeGraphEntry entry, long time, int n) {
+    public static ITimeEvent findEvent(ITimeGraphEntry entry, long time, int n) {
         if (null == entry || ! entry.hasTimeEvents()) {
             return null;
         }
