@@ -81,7 +81,7 @@ public class TmfVirtualTable extends Composite {
     private int     fSelectedBeginRank = -1;     // Global rank of the selected begin event
     private boolean fPendingSelection  = false;  // Pending selection update
 
-    private int       fTableItemCount  = 0;
+    private int     fTableItemCount    = 0;
 
     // The slider
     private Slider fSlider;
@@ -173,25 +173,25 @@ public class TmfVirtualTable extends Composite {
 
         // Implement a "fake" tooltip
         final String TOOLTIP_DATA_KEY = "_TABLEITEM"; //$NON-NLS-1$
-        final Listener labelListener = new Listener () {
+        final Listener labelListener = new Listener() {
             @Override
             public void handleEvent (Event event) {
-                Label label = (Label)event.widget;
-                Shell shell = label.getShell ();
+                Label label = (Label) event.widget;
+                Shell shell = label.getShell();
                 switch (event.type) {
                 case SWT.MouseDown:
-                    Event e = new Event ();
-                    e.item = (TableItem) label.getData (TOOLTIP_DATA_KEY);
+                    Event e = new Event();
+                    e.item = (TableItem) label.getData(TOOLTIP_DATA_KEY);
                     // Assuming table is single select, set the selection as if
                     // the mouse down event went through to the table
-                    fTable.setSelection (new TableItem [] {(TableItem) e.item});
-                    fTable.notifyListeners (SWT.Selection, e);
-                    shell.dispose ();
+                    fTable.setSelection(new TableItem [] {(TableItem) e.item});
+                    fTable.notifyListeners(SWT.Selection, e);
+                    shell.dispose();
                     fTable.setFocus();
                     break;
                 case SWT.MouseExit:
                 case SWT.MouseWheel:
-                    shell.dispose ();
+                    shell.dispose();
                     break;
                 default:
                     break;
@@ -199,11 +199,11 @@ public class TmfVirtualTable extends Composite {
             }
         };
 
-        Listener tableListener = new Listener () {
+        Listener tableListener = new Listener() {
             Shell tip = null;
             Label label = null;
             @Override
-            public void handleEvent (Event event) {
+            public void handleEvent(Event event) {
                 switch (event.type) {
                 case SWT.Dispose:
                 case SWT.KeyDown:
@@ -211,17 +211,17 @@ public class TmfVirtualTable extends Composite {
                     if (tip == null) {
                         break;
                     }
-                    tip.dispose ();
+                    tip.dispose();
                     tip = null;
                     label = null;
                     break;
                 }
                 case SWT.MouseHover: {
-                    TableItem item = fTable.getItem (new Point(event.x, event.y));
+                    TableItem item = fTable.getItem(new Point(event.x, event.y));
                     if (item != null) {
-                        for (int i=0; i < fTable.getColumnCount(); i++) {
+                        for (int i = 0; i < fTable.getColumnCount(); i++) {
                             Rectangle bounds = item.getBounds(i);
-                            if (bounds.contains(event.x,event.y)){
+                            if (bounds.contains(event.x, event.y)) {
                                 if (tip != null && !tip.isDisposed()) {
                                     tip.dispose();
                                 }
@@ -250,6 +250,9 @@ public class TmfVirtualTable extends Composite {
                                 Point pt = fTable.toDisplay(bounds.x, bounds.y);
                                 tip.setBounds(pt.x, pt.y, size.x, size.y);
                                 tip.setVisible(true);
+
+                                // Item found, leave loop.
+                                break;
                             }
                         }
                     }
@@ -318,11 +321,11 @@ public class TmfVirtualTable extends Composite {
                     @Override
                     public void handleEvent(Event event) {
                         if (doubleClickListener != null) {
-                            TableItem item = fTable.getItem (new Point (event.x, event.y));
+                            TableItem item = fTable.getItem(new Point (event.x, event.y));
                             if (item != null) {
-                                for(int i=0;i<fTable.getColumnCount();i++){
+                                for (int i = 0; i < fTable.getColumnCount(); i++){
                                     Rectangle bounds = item.getBounds(i);
-                                    if (bounds.contains(event.x,event.y)){
+                                    if (bounds.contains(event.x, event.y)){
                                         doubleClickListener.handleDoubleClick(TmfVirtualTable.this, item, i);
                                         break;
                                     }
@@ -576,7 +579,6 @@ public class TmfVirtualTable extends Composite {
                 switch (event.detail) {
                 case SWT.ARROW_DOWN:
                 case SWT.ARROW_UP:
-                case SWT.NONE:
                 case SWT.END:
                 case SWT.HOME:
                 case SWT.PAGE_DOWN:
@@ -585,17 +587,62 @@ public class TmfVirtualTable extends Composite {
                     refreshTable();
                     break;
                 }
+                // Not handled because of bug on Linux described below.
+                case SWT.NONE:
                 default:
                     break;
                 }
             }
         });
+
+        /*
+         * In Linux, the selection event above has event.detail set to SWT.NONE
+         * instead of SWT.DRAG during dragging of the thumb. To prevent refresh
+         * overflow, only update the table when the mouse button is released.
+         */
+        fSlider.addMouseListener(new MouseAdapter() {
+            @Override
+            public void mouseUp(MouseEvent e) {
+                fTableTopEventRank = fSlider.getSelection();
+                refreshTable();
+            }
+        });
+
     }
 
     // ------------------------------------------------------------------------
     // Simulated Table API
     // ------------------------------------------------------------------------
 
+    /**
+     * Constructs a new TableColumn instance given a style value describing its
+     * alignment behavior. The column is added to the end of the columns
+     * maintained by the table.
+     *
+     * @param style
+     *            the alignment style
+     * @return the new TableColumn
+     *
+     * @see SWT#LEFT
+     * @see SWT#RIGHT
+     * @see SWT#CENTER
+     *
+     * @since 3.1
+     */
+    public TableColumn newTableColumn(int style) {
+        TableColumn column = new TableColumn(fTable, style);
+
+        /*
+         * In Linux the table does not receive a control resized event when
+         * a table column resize causes the horizontal scroll bar to become
+         * visible or invisible, so a resize listener must be added to every
+         * table column to properly update the number of fully visible rows.
+         */
+        column.addControlListener(fResizeListener);
+
+        return column;
+    }
+
     /**
      * Method setHeaderVisible.
      * @param b boolean
@@ -652,7 +699,6 @@ public class TmfVirtualTable extends Composite {
         fTable.addKeyListener(listener);
     }
 
-
     /**
      * Method addMouseListener.
      * @param listener MouseListener
@@ -698,7 +744,7 @@ public class TmfVirtualTable extends Composite {
     /**
      * Method setItemCount
      * @param nbItems int the number of items in the table
-	 *
+     *
      */
     public void setItemCount(int nbItems) {
         final int nb = Math.max(0, nbItems);
@@ -858,7 +904,7 @@ public class TmfVirtualTable extends Composite {
         if (!done) {
             return;
         }
-        if (fPendingSelection && done) {
+        if (fPendingSelection) {
             fPendingSelection = false;
             TableItem item = null;
             if (fSelectedEventRank >= 0 && fSelectedEventRank < fFrozenRowCount) {
@@ -876,25 +922,13 @@ public class TmfVirtualTable extends Composite {
 
     /**
      * Method setColumnHeaders.
-     * @param columnData ColumnData[] the columndata array.
+     *
+     * @param columnData
+     *            ColumnData[] the columndata array.
      */
+    @Deprecated
     public void setColumnHeaders(ColumnData columnData[]) {
-        for (int i = 0; i < columnData.length; i++) {
-            TableColumn column = new TableColumn(fTable, columnData[i].alignment, i);
-            column.setText(columnData[i].header);
-            /*
-             * In Linux the table does not receive a control resized event when
-             * a table column resize causes the horizontal scroll bar to become
-             * visible or invisible, so a resize listener must be added to every
-             * table column to properly update the number of fully visible rows.
-             */
-            column.addControlListener(fResizeListener);
-            if (columnData[i].width > 0) {
-                column.setWidth(columnData[i].width);
-            } else {
-                column.pack();
-            }
-        }
+        /* No-op */
     }
 
     /**
@@ -1002,7 +1036,6 @@ public class TmfVirtualTable extends Composite {
             }
 
             refreshTable();
-
         }
     }
 
@@ -1068,7 +1101,7 @@ public class TmfVirtualTable extends Composite {
 
     /**
      * @return the tooltipProvider
-	 */
+     */
     public TooltipProvider getTooltipProvider() {
         return tooltipProvider;
     }
@@ -1082,7 +1115,7 @@ public class TmfVirtualTable extends Composite {
 
     /**
      * @return the doubleClickListener
-	 */
+     */
     public IDoubleClickListener getDoubleClickListener() {
         return doubleClickListener;
     }
