@@ -13,18 +13,18 @@ package org.eclipse.linuxtools.internal.oprofile.launch;
 import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 
-public class OprofileLaunchMessages {
-	private static final String BUNDLE_NAME = "org.eclipse.linuxtools.internal.oprofile.launch.oprofilelaunch"; //$NON-NLS-1$
-	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(BUNDLE_NAME);
+public final class OprofileLaunchMessages {
+    private static final String BUNDLE_NAME = "org.eclipse.linuxtools.internal.oprofile.launch.oprofilelaunch"; //$NON-NLS-1$
+    private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(BUNDLE_NAME);
 
-	private OprofileLaunchMessages() {
-	}
+    private OprofileLaunchMessages() {
+    }
 
-	public static String getString(String key) {
-		try {
-			return RESOURCE_BUNDLE.getString(key);
-		} catch (MissingResourceException e) {
-			return '!' + key + '!';
-		}
-	}
+    public static String getString(String key) {
+        try {
+            return RESOURCE_BUNDLE.getString(key);
+        } catch (MissingResourceException e) {
+            return '!' + key + '!';
+        }
+    }
 }
