@@ -11,19 +11,19 @@
 package org.eclipse.linuxtools.internal.perf.model;
 
 public class PMLineRef extends TreeParent {
-	protected int ln;
+    protected int ln;
 
-	public PMLineRef(int lineNum, float percent) {
-		super(""+lineNum, percent);
-		ln = lineNum;
-	}
+    public PMLineRef(int lineNum, float percent) {
+        super(""+lineNum, percent); //$NON-NLS-1$
+        ln = lineNum;
+    }
 
-	public void addPercent(Float addpc) {
-		setPercent(getPercent() + addpc);
-	}
+    public void addPercent(Float addpc) {
+        setPercent(getPercent() + addpc);
+    }
 
-	@Override
-	public String toString() {
-		return getPercent() + "% (" + getFormattedSamples() + " samples) on line " + ln;
-	}
+    @Override
+    public String toString() {
+        return getPercent() + "% (" + getFormattedSamples() + " samples) on line " + ln; //$NON-NLS-1$ //$NON-NLS-2$
+    }
 }
