@@ -17,9 +17,9 @@ import org.eclipse.swt.widgets.Composite;
 
 public class ReportComparisonViewCreator implements IViewerCreator {
 
-	@Override
-	public Viewer createViewer(Composite parent, CompareConfiguration config) {
-		return new ReportComparisonView(parent, config);
-	}
+    @Override
+    public Viewer createViewer(Composite parent, CompareConfiguration config) {
+        return new ReportComparisonView(parent);
+    }
 
 }
