@@ -11,8 +11,10 @@
 package org.eclipse.linuxtools.internal.rpm.core;
 
 import org.eclipse.core.runtime.preferences.AbstractPreferenceInitializer;
+import org.eclipse.core.runtime.preferences.InstanceScope;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.linuxtools.rpm.core.IRPMConstants;
+import org.eclipse.ui.preferences.ScopedPreferenceStore;
 
 /**
  * Initialize preferences.
@@ -22,16 +24,15 @@ public class RPMCoreInitializer extends AbstractPreferenceInitializer {
 
 	@Override
 	public void initializeDefaultPreferences() {
-		IPreferenceStore store = RPMCorePlugin.getDefault()
-				.getPreferenceStore();
-		String user_name = System.getProperty("user.name"); //$NON-NLS-1$
+		IPreferenceStore store = new ScopedPreferenceStore(InstanceScope.INSTANCE,IRPMConstants.RPM_CORE_ID);
+		String userName = System.getProperty("user.name"); //$NON-NLS-1$
 		store.setDefault(IRPMConstants.RPM_DISPLAYED_LOG_NAME, ".logfilename_" //$NON-NLS-1$
-				+ user_name);
+				+ userName);
 		store.setDefault(IRPMConstants.RPM_LOG_NAME, "rpmbuild.log"); //$NON-NLS-1$
 
-		store.setDefault(IRPMConstants.RPM_CMD, "/bin/rpm"); //$NON-NLS-1$
-		store.setDefault(IRPMConstants.RPMBUILD_CMD, "/usr/bin/rpmbuild"); //$NON-NLS-1$
-		store.setDefault(IRPMConstants.DIFF_CMD, "/usr/bin/diff"); //$NON-NLS-1$
+		store.setDefault(IRPMConstants.RPM_CMD, "rpm"); //$NON-NLS-1$
+		store.setDefault(IRPMConstants.RPMBUILD_CMD, "rpmbuild"); //$NON-NLS-1$
+		store.setDefault(IRPMConstants.DIFF_CMD, "diff"); //$NON-NLS-1$
 	}
 
 }
