@@ -19,6 +19,8 @@ public class Messages extends NLS {
 	private static final String BUNDLE_NAME = "org.eclipse.linuxtools.internal.rpm.core.utils.messages"; //$NON-NLS-1$
 	/** Download + name  message	 */
 	public static String DownloadJob_0;
+	/** Message shown when trying to export a RPM project that doesn't have a specfile*/
+	public static String Specfile_not_found;
 	static {
 		// initialize resource bundle
 		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
