@@ -11,10 +11,10 @@
 
 package org.eclipse.linuxtools.rpm.ui.editor.tests;
 
-import org.eclipse.linuxtools.rpm.ui.editor.tests.actions.ActionsAllTests;
-import org.eclipse.linuxtools.rpm.ui.editor.tests.hyperlink.HyperlinkAllTests;
+import org.eclipse.linuxtools.internal.rpm.ui.editor.actions.tests.ActionsAllTests;
+import org.eclipse.linuxtools.internal.rpm.ui.editor.hyperlink.tests.HyperlinkAllTests;
+import org.eclipse.linuxtools.internal.rpm.ui.editor.scanners.tests.ScannersAllTests;
 import org.eclipse.linuxtools.rpm.ui.editor.tests.parser.ParserAllTests;
-import org.eclipse.linuxtools.rpm.ui.editor.tests.scanners.ScannersAllTests;
 import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
@@ -25,6 +25,6 @@ import org.junit.runners.Suite;
 		LinePositionTest.class, RpmMacroProposalsListTest.class,
 		RpmPackageProposalsListTest.class, ActionsAllTests.class,
 		ScannersAllTests.class, ParserAllTests.class, HyperlinkAllTests.class,
-		SpecfileCompletionProcessorTest.class })
+		SpecfileCompletionProcessorTest.class, LabelProviderTest.class })
 public class AllTests {
 }
