@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007 Alphonse Van Assche.
+ * Copyright (c) 2007, 2013 Alphonse Van Assche.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,7 @@
  *
  * Contributors:
  *    Alphonse Van Assche - initial API and implementation
+ *    Neil Guzman - autocomplete with "." and "+" in name (B#375195)
  *******************************************************************************/
 
 package org.eclipse.linuxtools.internal.rpm.ui.editor;
@@ -46,12 +47,12 @@ import org.eclipse.linuxtools.rpm.ui.editor.parser.SpecfileSection;
 
 /**
  * Content assist processor
- * 
+ *
  * @author Alphonse Van Assche
  *
  */
 public class SpecfileCompletionProcessor implements IContentAssistProcessor {
-	
+
 	private static final String SOURCE = "SOURCE"; //$NON-NLS-1$
 
 	private static final String EMPTY_STRING = ""; //$NON-NLS-1$
@@ -62,7 +63,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 */
 	private static final class TemplateProposalComparator implements Comparator<TemplateProposal>, Serializable {
 		private static final long serialVersionUID = 1L;
-
+		@Override
 		public int compare(TemplateProposal t1, TemplateProposal t2) {
 			return (t2.getRelevance() - t1.getRelevance());
 		}
@@ -73,7 +74,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 * @author Sami Wagiaalla
 	 */
 	private static final class ProposalComparator implements Comparator<ICompletionProposal>{
-
+		@Override
 		public int compare(ICompletionProposal a, ICompletionProposal b){
 			return a.getDisplayString().compareToIgnoreCase(b.getDisplayString());
 		}
@@ -82,9 +83,9 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	private static final String TEMPLATE_ICON = "icons/template_obj.gif"; //$NON-NLS-1$
 
 	private static final String MACRO_ICON = "icons/macro_obj.gif"; //$NON-NLS-1$
-	
+
 	private static final String PATCH_ICON = "icons/macro_obj.gif"; //$NON-NLS-1$
-	
+
 	private static final String PACKAGE_ICON = "icons/rpm.gif"; //$NON-NLS-1$
 
 	private static final String PREAMBLE_SECTION_TEMPLATE = "org.eclipse.linuxtools.rpm.ui.editor.preambleSection"; //$NON-NLS-1$
@@ -98,7 +99,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	private static final String CHANGELOG_SECTION_TEMPLATE = "org.eclipse.linuxtools.rpm.ui.editor.changelogSection"; //$NON-NLS-1$
 
 	private final SpecfileEditor editor;
-	
+
 	private static final Comparator<ICompletionProposal> PROPOSAL_COMPARATOR = new ProposalComparator();
 	private static final Comparator<TemplateProposal> TEMPLATE_PROPOSAL_COMPARATOR = new TemplateProposalComparator();
 
@@ -108,21 +109,24 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	public SpecfileCompletionProcessor(SpecfileEditor editor) {
 		this.editor = editor;
 	}
-	
+
 	/* (non-Javadoc)
 	 * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#computeCompletionProposals(org.eclipse.jface.text.ITextViewer, int)
 	 */
+	@Override
 	public ICompletionProposal[] computeCompletionProposals(ITextViewer viewer,
 			int offset) {
 		List<ICompletionProposal> result = new ArrayList<ICompletionProposal>();
 		Specfile specfile = editor.getSpecfile();
-		if (specfile == null)
+		if (specfile == null) {
 			return null;
+		}
 		ITextSelection selection = (ITextSelection) viewer
 				.getSelectionProvider().getSelection();
 		// adjust offset to start of normalized selection
-		if (selection.getOffset() != offset)
+		if (selection.getOffset() != offset) {
 			offset = selection.getOffset();
+		}
 		String prefix = getPrefix(viewer, offset);
 		Region region = new Region(offset - prefix.length(), prefix.length()
 				+ selection.getLength());
@@ -134,13 +138,13 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 				region, specfile, prefix);
 		result.addAll(sourcesProposals);
 		// Get the current content type
-		String currentContentType = editor.getInputDocument().getDocumentPartitioner().getContentType(region.getOffset());
+		String currentContentType = ((IDocument)editor.getAdapter(IDocument.class)).getDocumentPartitioner().getContentType(region.getOffset());
 		if (currentContentType.equals(SpecfilePartitionScanner.SPEC_PREP)){
 			List<ICompletionProposal> patchesProposals = computePatchesProposals(
 					region, specfile, prefix);
 			result.addAll(patchesProposals);
 		}
-		
+
 		if (currentContentType.equals(SpecfilePartitionScanner.SPEC_PACKAGES)) {
 			// don't show template in the RPM packages content type.
 			// (when the line begin with Requires, BuildRequires etc...)
@@ -149,7 +153,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 			result.addAll(rpmPackageProposals);
 			result.addAll(rpmMacroProposals);
 		} else {
-			// don't show RPM packages proposals in all others content type. 
+			// don't show RPM packages proposals in all others content type.
 			List<? extends ICompletionProposal> templateProposals = computeTemplateProposals(
 					viewer, region, specfile, prefix);
 			result.addAll(templateProposals);
@@ -173,11 +177,11 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 		return result
 				.toArray(new ICompletionProposal[result.size()]);
 	}
-	
+
 	/**
 	 * Compute the templates proposals, these proposals are contextual on sections.
 	 * Return an array of template proposals for the given viewer, region, specfile, prefix.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param region
@@ -187,7 +191,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 * 			  the specfile element
 	 * @param prefix
 	 * 			  the prefix string
-	 * @return 
+	 * @return
 	 *            a ICompletionProposal[]
 	 */
 	private List<? extends ICompletionProposal> computeTemplateProposals(ITextViewer viewer,
@@ -222,7 +226,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/**
 	 * Compute RPM macro proposals, these proposals are usable in the whole document.
 	 * Return an array of RPM macro proposals for the given viewer, region, prefix.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param region
@@ -230,16 +234,16 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 *            is created
 	 * @param prefix
 	 * 			  the prefix string to find
-	 * @return 
+	 * @return
 	 *            a ICompletionProposal[]
 	 */
-	private List<ICompletionProposal> computeRpmMacroProposals(IRegion region, 
+	private List<ICompletionProposal> computeRpmMacroProposals(IRegion region,
 			Specfile specfile, String prefix) {
 		Map<String, String> rpmMacroProposalsMap = Activator.getDefault().getRpmMacroList().getProposals(prefix);
-		
+
 		// grab defines and put them into the proposals map
 		rpmMacroProposalsMap.putAll(getDefines(specfile, prefix));
-		
+
 		ArrayList<ICompletionProposal> proposals = new ArrayList<ICompletionProposal>();
 		if (rpmMacroProposalsMap != null) {
 			for (Map.Entry<String, String> entry : rpmMacroProposalsMap
@@ -256,11 +260,11 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 		}
 		return proposals;
 	}
-	
+
 	/**
 	 * Compute patches proposals, these proposals are usable in the whole document.
 	 * Return an array of patches proposals for the given viewer, region, prefix.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param region
@@ -268,10 +272,10 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 *            is created
 	 * @param prefix
 	 * 			  the prefix string to find
-	 * @return 
+	 * @return
 	 *            a ICompletionProposal[]
 	 */
-	private List<ICompletionProposal> computePatchesProposals(IRegion region, 
+	private List<ICompletionProposal> computePatchesProposals(IRegion region,
 			Specfile specfile, String prefix) {
 		// grab patches and put them into the proposals map
 		Map<String, String> patchesProposalsMap = getPatches(specfile, prefix);
@@ -287,11 +291,11 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 		}
 		return proposals;
 	}
-	
+
 	/**
 	 * Compute sources proposals, these proposals are usable in the whole document.
 	 * Return an array of sources proposals for the given viewer, region, prefix.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param region
@@ -299,10 +303,10 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 *            is created
 	 * @param prefix
 	 * 			  the prefix string to find
-	 * @return 
+	 * @return
 	 *            a ICompletionProposal[]
 	 */
-	private List<ICompletionProposal> computeSourcesProposals(IRegion region, 
+	private List<ICompletionProposal> computeSourcesProposals(IRegion region,
 			Specfile specfile, String prefix) {
 		// grab patches and put them into the proposals map
 		Map<String, String> sourcesProposalsMap = getSources(specfile, prefix);
@@ -322,7 +326,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/**
 	 * Compute RPM package proposals, these proposals are usable only in the preambule section.
 	 * Return an array of RPM macro proposals for the given viewer, region, specfile, prefix.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param region
@@ -330,10 +334,10 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 *            is created
 	 * @param prefix
 	 * 			  the prefix string
-	 * @return 
+	 * @return
 	 *            a ICompletionProposal[]
 	 */
-	private List<ICompletionProposal> computeRpmPackageProposals(IRegion region, 
+	private List<ICompletionProposal> computeRpmPackageProposals(IRegion region,
 			String prefix) {
 		List<String[]> rpmPkgProposalsList = Activator.getDefault().getRpmPackageList().getProposals(prefix);
 		ArrayList<ICompletionProposal> proposals = new ArrayList<ICompletionProposal>();
@@ -349,7 +353,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 		Collections.sort(proposals, PROPOSAL_COMPARATOR);
 		return proposals;
 	}
-	
+
 	private List<ICompletionProposal> computeRpmGroupProposals(IRegion region,
 			String prefix) {
 		List<String> rpmGroupProposalsList = Activator.getDefault()
@@ -368,7 +372,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 
 	/**
 	 * Create a template context for the givens Specfile, offset.
-	 * 
+	 *
 	 * @param specfile
 	 *            the sepcfile element
 	 * @param offset
@@ -393,12 +397,12 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 				return Activator.getDefault().getContextTypeRegistry()
 						.getContextType(CHANGELOG_SECTION_TEMPLATE);
 			}
-		
+
 	}
 
 	/**
 	 * Create a template context for the given Specfile and offset.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param region
@@ -419,7 +423,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 		}
 		return null;
 	}
-	
+
 	/**
 	 * Get relevance on templates for the given template and prefix.
 	 * @param template
@@ -430,14 +434,15 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	 * 			a relevant code (90 if <code>true</code> and 0 if not)
 	 */
 	private int getRelevance(Template template, String prefix) {
-		if (template.getName().startsWith(prefix))
+		if (template.getName().startsWith(prefix)) {
 			return 90;
+		}
 		return 0;
 	}
 
 	/**
 	 * Get the prefix for a given viewer, offset.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param offset
@@ -448,14 +453,16 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	private String getPrefix(ITextViewer viewer, int offset) {
 		int i = offset;
 		IDocument document = viewer.getDocument();
-		if (i > document.getLength())
+		if (i > document.getLength()) {
 			return EMPTY_STRING;
+		}
 
 		try {
 			while (i > 0) {
 				char ch = document.getChar(i - 1);
-				if (!Character.isLetterOrDigit(ch) && (ch != '%') && (ch != '_') && (ch != '-') && (ch != '{'))
+				if (!Character.isLetterOrDigit(ch) && (ch != '%') && (ch != '_') && (ch != '-') && (ch != '{') && (ch != '.') && (ch != '+')) {
 					break;
+				}
 				i--;
 			}
 			return document.get(i, offset - i);
@@ -463,10 +470,10 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 			return EMPTY_STRING;
 		}
 	}
-	
+
 	/**
 	 * Get the prefix for a given viewer, offset.
-	 * 
+	 *
 	 * @param viewer
 	 *            the viewer for which the context is created
 	 * @param offset
@@ -477,14 +484,16 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	private String getGroupPrefix(ITextViewer viewer, int offset) {
 		int i = offset;
 		IDocument document = viewer.getDocument();
-		if (i > document.getLength())
+		if (i > document.getLength()) {
 			return EMPTY_STRING;
+		}
 
 		try {
 			while (i > 0) {
 				char ch = document.getChar(i - 1);
-				if (!Character.isLetterOrDigit(ch) && (ch != '/'))
+				if (!Character.isLetterOrDigit(ch) && (ch != '/')) {
 					break;
+				}
 				i--;
 			}
 			return document.get(i, offset - i);
@@ -496,13 +505,13 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/**
 	 * Get defines as a String key->value pair for a given specfile
 	 * and prefix.
-	 * 
+	 *
 	 * @param specfile
 	 *            to get defines from.
 	 * @param prefix
 	 *            used to find defines.
 	 * @return a <code>HashMap</code> of defines.
-	 * 
+	 *
 	 */
 	private Map<String, String> getDefines(Specfile specfile, String prefix) {
 		Collection<SpecfileDefine> defines = specfile.getDefines();
@@ -510,22 +519,23 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 		String defineName;
 		for (SpecfileDefine define: defines) {
 			defineName = "%" + define.getName(); //$NON-NLS-1$
-			if (defineName.startsWith(prefix.replaceFirst("\\{", EMPTY_STRING))) //$NON-NLS-1$
+			if (defineName.startsWith(prefix.replaceFirst("\\{", EMPTY_STRING))) {//$NON-NLS-1$
 				ret.put(defineName, define.getStringValue());
+			}
 		}
 		return ret;
 	}
-	
+
 	/**
 	 * Get patches as a String key->value pair for a given specfile
 	 * and prefix.
-	 * 
+	 *
 	 * @param specfile
 	 *            to get defines from.
 	 * @param prefix
 	 *            used to find defines.
 	 * @return a <code>HashMap</code> of defines.
-	 * 
+	 *
 	 */
 	private Map<String, String> getPatches(Specfile specfile, String prefix) {
 		Collection<SpecfileSource> patches = specfile.getPatches();
@@ -533,24 +543,25 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 		String patchName;
 		for (SpecfileSource patch: patches) {
 			patchName = "%patch" + patch.getNumber(); //$NON-NLS-1$
-			if (patchName.startsWith(prefix))
+			if (patchName.startsWith(prefix)) {
 				ret.put(patchName.toLowerCase(), SpecfileHover
 						.getSourceOrPatchValue(specfile, "patch" //$NON-NLS-1$
 								+ patch.getNumber()));
+			}
 		}
 		return ret;
 	}
-	
+
 	/**
 	 * Get sources as a String key->value pair for a given specfile
 	 * and prefix.
-	 * 
+	 *
 	 * @param specfile
 	 *            to get defines from.
 	 * @param prefix
 	 *            used to find defines.
 	 * @return a <code>HashMap</code> of defines.
-	 * 
+	 *
 	 */
 	private Map<String, String> getSources(Specfile specfile, String prefix) {
 		Collection<SpecfileSource> sources = specfile.getSources();
@@ -560,9 +571,10 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 			sourceName = ISpecfileSpecialSymbols.MACRO_START_LONG + SOURCE
 					+ source.getNumber()
 					+ ISpecfileSpecialSymbols.MACRO_END_LONG;
-			if (sourceName.startsWith(prefix))
+			if (sourceName.startsWith(prefix)) {
 				ret.put(sourceName, SpecfileHover.getSourceOrPatchValue(
 						specfile, SOURCE + source.getNumber()));
+			}
 		}
 		return ret;
 	}
@@ -570,6 +582,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/* (non-Javadoc)
 	 * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#computeContextInformation(org.eclipse.jface.text.ITextViewer, int)
 	 */
+	@Override
 	public IContextInformation[] computeContextInformation(ITextViewer viewer,
 			int offset) {
 		return null;
@@ -578,6 +591,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/* (non-Javadoc)
 	 * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#getCompletionProposalAutoActivationCharacters()
 	 */
+	@Override
 	public char[] getCompletionProposalAutoActivationCharacters() {
 		return null;
 	}
@@ -585,6 +599,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/* (non-Javadoc)
 	 * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#getContextInformationAutoActivationCharacters()
 	 */
+	@Override
 	public char[] getContextInformationAutoActivationCharacters() {
 		return null;
 	}
@@ -592,6 +607,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/* (non-Javadoc)
 	 * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#getErrorMessage()
 	 */
+	@Override
 	public String getErrorMessage() {
 		return null;
 	}
@@ -599,6 +615,7 @@ public class SpecfileCompletionProcessor implements IContentAssistProcessor {
 	/* (non-Javadoc)
 	 * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#getContextInformationValidator()
 	 */
+	@Override
 	public IContextInformationValidator getContextInformationValidator() {
 		return null;
 	}
