@@ -15,34 +15,35 @@ import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 
 import java.util.ArrayList;
+import java.util.List;
 
 import org.eclipse.linuxtools.systemtap.structures.Copier;
 import org.junit.Test;
 
 public class CopierTest {
 
-	@Test
-	public void testCopy() {
-		ArrayList<String> list = new ArrayList<String>();
-		@SuppressWarnings("unchecked")
-		ArrayList<Integer>[] lists = new ArrayList[3];
-		int listsSize = 3;
+    @Test
+    public void testCopy() {
+        ArrayList<String> list = new ArrayList<>();
+        @SuppressWarnings("unchecked")
+        ArrayList<Integer>[] lists = new ArrayList[3];
+        int listsSize = 3;
 
-		for(int i=0; i<listsSize; i++) {
-			list.add("" + i);
-			for(int j=0; j<5; j++){
-				lists[i] = new ArrayList<Integer>();
-				lists[i].add(new Integer(j));
-			}
-		}
+        for(int i=0; i<listsSize; i++) {
+            list.add("" + i);
+            for(int j=0; j<5; j++){
+                lists[i] = new ArrayList<>();
+                lists[i].add(new Integer(j));
+            }
+        }
 
-		ArrayList<String> list2 = Copier.copy(list);
-		for(int i=0; i<list.size(); i++) {
-			assertEquals(list2.get(i), list.get(i));
-		}
+        List<String> list2 = Copier.copy(list);
+        for(int i=0; i<list.size(); i++) {
+            assertEquals(list2.get(i), list.get(i));
+        }
 
-		ArrayList<?>[] lists2 = Copier.copy(lists);
-		assertArrayEquals(lists, lists2);
-	}
+        List<?>[] lists2 = Copier.copy(lists);
+        assertArrayEquals(lists, lists2);
+    }
 
 }
