@@ -1,4 +1,5 @@
 /*******************************************************************************
+ * Copyright (c) 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -14,6 +15,7 @@ package org.eclipse.linuxtools.internal.systemtap.ui.consolelog.actions;
 import java.net.URL;
 
 import org.eclipse.jface.action.Action;
+import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.linuxtools.systemtap.ui.consolelog.structures.ScriptConsole;
 
@@ -24,16 +26,25 @@ import org.eclipse.linuxtools.systemtap.ui.consolelog.structures.ScriptConsole;
  */
 public abstract class ConsoleAction extends Action {
 
-	protected ScriptConsole console;
+    protected ScriptConsole console;
 
-	protected ConsoleAction(ScriptConsole fConsole,
-			URL imagePath,
-			String text,
-			String toolTip){
-		this.console = fConsole;
+    protected ConsoleAction(ScriptConsole fConsole,
+            URL imagePath,
+            String text,
+            String toolTip) {
+        this(fConsole, imagePath, text, toolTip, IAction.AS_PUSH_BUTTON);
+    }
 
-		setImageDescriptor(ImageDescriptor.createFromURL(imagePath));
-		setToolTipText(text);
-		setText(toolTip);
-	}
+    protected ConsoleAction(ScriptConsole fConsole,
+            URL imagePath,
+            String text,
+            String toolTip,
+            int style) {
+        super(null, style);
+        console = fConsole;
+
+        setImageDescriptor(ImageDescriptor.createFromURL(imagePath));
+        setToolTipText(text);
+        setText(toolTip);
+    }
 }
