@@ -1,13 +1,13 @@
 /*******************************************************************************
  * Copyright (c) 2008 Phil Muldoon <pkmuldoon@picobot.org>.
- * 
+ *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors:
- *    Phil Muldoon <pkmuldoon@picobot.org> - initial API and implementation. 
+ *    Phil Muldoon <pkmuldoon@picobot.org> - initial API and implementation.
  *******************************************************************************/
 
 package org.eclipse.linuxtools.systemtap.ui.editor;
@@ -22,20 +22,20 @@ import org.eclipse.swt.widgets.Display;
 
 public class ColorManager {
 
-	protected Map<RGB, Color> colorTable = new HashMap<RGB, Color>(10);
+    private Map<RGB, Color> colorTable = new HashMap<>(10);
 
-	public void dispose() {
-		Iterator<Color> e = colorTable.values().iterator();
-		while (e.hasNext())
-			e.next().dispose();
-	}
+    public void dispose() {
+        Iterator<Color> e = colorTable.values().iterator();
+        while (e.hasNext())
+            e.next().dispose();
+    }
 
-	public Color getColor(RGB rgb) {
-		Color color = colorTable.get(rgb);
-		if (color == null) {
-			color = new Color(Display.getCurrent(), rgb);
-			colorTable.put(rgb, color);
-		}
-		return color;
-	}
+    public Color getColor(RGB rgb) {
+        Color color = colorTable.get(rgb);
+        if (color == null) {
+            color = new Color(Display.getCurrent(), rgb);
+            colorTable.put(rgb, color);
+        }
+        return color;
+    }
 }
