@@ -23,28 +23,26 @@ import org.junit.Test;
 
 public class SignalTest extends AbstractMemcheckTest {
 
-	@Override
-	@Before
-	public void setUp() throws Exception {
-		super.setUp();
-		proj = createProjectAndBuild("segvtest"); //$NON-NLS-1$
-	}
+    @Before
+    public void prep() throws Exception {
+        proj = createProjectAndBuild("segvtest"); //$NON-NLS-1$
+    }
 
-	@Override
-	@After
-	public void tearDown() throws CoreException {
-		deleteProject(proj);
-		super.tearDown();
-	}
+    @Override
+    @After
+    public void tearDown() throws CoreException {
+        deleteProject(proj);
+        super.tearDown();
+    }
 
-	@Test
-	public void testSegfaultHandle() throws Exception {
-		ILaunchConfiguration config = createConfiguration(proj.getProject());
-		doLaunch(config, "testSegfault"); //$NON-NLS-1$
+    @Test
+    public void testSegfaultHandle() throws Exception {
+        ILaunchConfiguration config = createConfiguration(proj.getProject());
+        doLaunch(config, "testSegfault"); //$NON-NLS-1$
 
-		ValgrindViewPart view = ValgrindUIPlugin.getDefault().getView();
-		IValgrindMessage[] messages = view.getMessages();
-		assertTrue(messages.length > 0);
-		assertTrue(messages[0].getText().contains("SIGSEGV")); //$NON-NLS-1$
-	}
+        ValgrindViewPart view = ValgrindUIPlugin.getDefault().getView();
+        IValgrindMessage[] messages = view.getMessages();
+        assertTrue(messages.length > 0);
+        assertTrue(messages[0].getText().contains("SIGSEGV")); //$NON-NLS-1$
+    }
 }
