@@ -7,7 +7,7 @@
  *
  * Contributors:
  *    Red Hat Inc. - initial API and implementation
- *******************************************************************************/ 
+ *******************************************************************************/
 package org.eclipse.linuxtools.internal.valgrind.memcheck;
 
 import org.eclipse.debug.ui.AbstractLaunchConfigurationTab;
@@ -15,13 +15,13 @@ import org.eclipse.linuxtools.internal.valgrind.launch.ValgrindSingleToolOptions
 import org.eclipse.linuxtools.profiling.launch.ProfileLaunchConfigurationTabGroup;
 
 public class MemcheckLaunchConfigurationTabGroup extends
-		ProfileLaunchConfigurationTabGroup {
+        ProfileLaunchConfigurationTabGroup {
+
+    @Override
+    public AbstractLaunchConfigurationTab[] getProfileTabs() {
+        return new AbstractLaunchConfigurationTab[] {
+            new ValgrindSingleToolOptionsTab(MemcheckPlugin.TOOL_ID)
+        };
+    }
 
-	@Override
-	public AbstractLaunchConfigurationTab[] getProfileTabs() {
-		return new AbstractLaunchConfigurationTab[] {
-			new ValgrindSingleToolOptionsTab("org.eclipse.linuxtools.valgrind.launch.memcheck"), //$NON-NLS-1$
-		};
-	}	
-	
 }
