@@ -17,19 +17,18 @@ import org.eclipse.linuxtools.internal.valgrind.core.ValgrindCommand;
 
 public class ValgrindStubCommand extends ValgrindCommand {
 
-	@Override
-	public String whichVersion(IProject project) {
-		return "valgrind-3.4.0"; //$NON-NLS-1$
-	}
+    @Override
+    public String whichVersion(IProject project) {
+        return "valgrind-3.4.0"; //$NON-NLS-1$
+    }
 
-	@Override
-	public void execute(String[] commandArray, Object env, File wd, String exeFile,
-			boolean usePty, IProject project) {
-		args = commandArray;
-	}
+    @Override
+    public void execute(String[] commandArray, Object env, File wd, boolean usePty, IProject project) {
+        args = commandArray;
+    }
 
-	@Override
-	public Process getProcess() {
-		return null;
-	}
+    @Override
+    public Process getProcess() {
+        return null;
+    }
 }
